﻿local Cartographer = Cartographer
local revision = tonumber(string.sub("$Revision: 29798 $", 12, -3))
if revision > Cartographer.revision then
	Cartographer.version = "r" .. revision
	Cartographer.revision = revision
	Cartographer.date = string.sub("$Date: 2007-03-09 00:09:33 -0500 (Fri, 09 Mar 2007) $", 8, 17)
end

local L = AceLibrary("AceLocale-2.2"):new("Cartographer-InstanceMaps")

L:RegisterTranslations("enUS", function() return {
	["Instance Maps"] = true,
	["Module which provides maps of instances."] = true,
	
	["Instances"] = true,
} end)

L:RegisterTranslations("deDE", function() return {
	["Instance Maps"] = "Instanzkarten",
	["Module which provides maps of instances."] = "Modul, das Instanzkarten zur Verfügung stellt.",
  
	["Instances"] = "Instanzen",
} end)

L:RegisterTranslations("frFR", function() return {
	["Instance Maps"] = "Cartes d'instance",
	["Module which provides maps of instances."] = "Module fournissant des cartes pour les instances.",

	--["Instances"] = true,
} end)

L:RegisterTranslations("koKR", function() return {
	["Instance Maps"] = "인스턴스 던전",
	["Module which provides maps of instances."] = "인스턴스 던전을 보여줍니다.",
	
	["Instances"] = "인스턴스",
} end)

L:RegisterTranslations("zhTW", function() return {
	["Instance Maps"] = "副本地圖",
	["Module which provides maps of instances."] = "提供副本地圖的模組。",

--	["Instances"] = true,
} end)

L:RegisterTranslations("zhCN", function() return {
--	["Instance Maps"] = true,
--	["Module which provides maps of instances."] = true,

--	["Instances"] = true,
} end)

L:RegisterTranslations("esES", function() return {
	["Instance Maps"] = "Mapas de Instancia",
	["Module which provides maps of instances."] = "M\195\179dulo que provee mapas de instancias",
	
	["Instances"] = "Instancias",
} end)

local MapData, Rotations, Floors

Cartographer_InstanceMaps = Cartographer:NewModule("InstanceMaps", "AceHook-2.1", "AceEvent-2.0")
local Cartographer_InstanceMaps = Cartographer_InstanceMaps

local BZ = AceLibrary("Babble-Zone-2.2")
local Tourist = AceLibrary("Tourist-2.0")

local instanceToTexture = {
	["Dire Maul (East)"] = "DireMaulEast", -- ?
	["Dire Maul (North)"] = "DireMaulNorth", -- ?
	["Dire Maul (West)"] = "DireMaulWest", -- ?
	["Scarlet Monastery"] = "ScarletMonastery",
	["Scholomance"] = "Scholomance",
	["Ruins of Ahn'Qiraj"] = "RuinsofAhnQiraj",
	["Zul'Farrak"] = "ZulFarrak",
	["Zul'Gurub"] = "ZulGurub",
}

local path
function Cartographer_InstanceMaps:OnInitialize()
	path = debugstack(1, 1, 0)
	if path:find("grapher\\") then
		path = "Interface\\AddOns\\Cartographer\\Cartographer_InstanceMaps\\Artwork\\"
	elseif path:find("grapher_InstanceMaps\\") then
		path = "Interface\\AddOns\\Cartographer_InstanceMaps\\Artwork\\"
	else
		error("Cannot determine path of artwork")
	end
	self.name = L["Instance Maps"]
	self.title = L["Instance Maps"]
	Cartographer.options.args.InstanceMaps = {
		name = L["Instance Maps"],
		desc = L["Module which provides maps of instances."],
		type = 'group',
		args = {
			toggle = {
				name = AceLibrary("AceLocale-2.2"):new("Cartographer")["Enabled"],
				desc = AceLibrary("AceLocale-2.2"):new("Cartographer")["Suspend/resume this module."],
				type = "toggle",
				order = -1,
				get = function() return Cartographer:IsModuleActive(self) end,
				set = function() Cartographer:ToggleModuleActive(self) end
			},
		},
		handler = self,
	}
end

local CartographerInstanceFrame
function Cartographer_InstanceMaps:OnEnable()
	self:SecureHook("SetMapZoom")
	self:Hook("SetMapToCurrentZone", true)
	self:RegisterEvent("PLAYER_LEVEL_UP")
	self:PLAYER_LEVEL_UP()
end

function Cartographer_InstanceMaps:OnDisable()
	self:HideInstanceFrame()
end

function Cartographer_InstanceMaps:PLAYER_LEVEL_UP()
	Cartographer.gotoOptions.args.Instances = {
		name = L["Instances"],
		desc = L["Instances"],
		type = 'group',
		args = {},
		hidden = function() return not Cartographer:IsModuleActive(self) end
	}
	for i = 1, 4 do
		local validate = {}
		local func
		local name
		if i == 1 then
			func = Tourist.IsInKalimdor
			name = "Kalimdor"
		elseif i == 2 then
			func = Tourist.IsInEasternKingdoms
			name = "Eastern Kingdoms"
		elseif i == 3 then
			func = Tourist.IsInOutland
			name = "Outland"
		end
		if i ~= 4 then
			for k in pairs(instanceToTexture) do
				if func(Tourist, BZ[k]) then
					validate[k] = BZ[k]
				end
			end
			for k in pairs(MapData) do
				if func(Tourist, BZ[k]) then
					validate[k] = BZ[k]
				end
			end
		else
			name = "Unknown"
			for k, v in pairs(instanceToTexture) do
				if not Tourist:IsInKalimdor(BZ[k]) and not Tourist:IsInEasternKingdoms(BZ[k]) and not Tourist:IsInOutland(BZ[k]) then
					validate[k] = BZ[k]
				end
			end
			for k, v in pairs(MapData) do
				if not Tourist:IsInKalimdor(BZ[k]) and not Tourist:IsInEasternKingdoms(BZ[k]) and not Tourist:IsInOutland(BZ[k]) then
					validate[k] = BZ[k]
				end
			end
		end
	
		for k,v in pairs(validate) do
			local text = v
			local low, high = Tourist:GetLevel(v)
			local r, g, b = Tourist:GetLevelColor(v)
			local levelText
			if low == 0 then
				levelText = ""
			elseif low == high then
				levelText = (" |cff%02x%02x%02x[%d]|r"):format(r * 255, g * 255, b * 255, high)
			else
				levelText = (" |cff%02x%02x%02x[%d-%d]|r"):format(r * 255, g * 255, b * 255, low, high)
			end
			local r, g, b = Tourist:GetFactionColor(v)
			text = ("|cff%02x%02x%02x%s|r%s"):format(r*255, g*255, b*255, text, levelText)
			validate[k] = text
		end
	
		if next(validate) then
			local lname = i == 4 and UNKNOWN or BZ[name]
			Cartographer.gotoOptions.args.Instances.args[name] = {
				name = lname,
				desc = lname,
				type = 'text',
				get = function()
					return Cartographer:GetCurrentInstance()
				end,
				set = "ShowInstance",
				validate = validate,
				handler = self
			}
		end
	end
end

function Cartographer_InstanceMaps:SetMapToCurrentZone()
	local zoneText = GetRealZoneText()
	if zoneText == BZ["Blackrock Spire"] then
		zoneText = BZ["Upper Blackrock Spire"]
	end
	if IsInInstance() and BZ:HasReverseTranslation(zoneText) and (instanceToTexture[BZ:GetReverseTranslation(zoneText)] or MapData[BZ:GetReverseTranslation(zoneText)]) then
		self:ShowInstance(BZ:GetReverseTranslation(zoneText))
	else
		self:HideInstanceFrame()
		return self.hooks.SetMapToCurrentZone()
	end
end

function Cartographer_InstanceMaps:ShowInstanceFrame()
	if not CartographerInstanceFrame then
		CartographerInstanceFrame = CreateFrame("Button", "CartographerInstanceFrame", WorldMapFrame)
		CartographerInstanceFrame:SetPoint("CENTER", WorldMapButton, "CENTER")
		CartographerInstanceFrame:SetWidth(WorldMapButton:GetWidth())
		CartographerInstanceFrame:SetHeight(WorldMapButton:GetHeight())
		CartographerInstanceFrame:Hide()
		CartographerInstanceFrame:RegisterForClicks("LeftButtonUp", "RightButtonUp")
		CartographerInstanceFrame:SetScript("OnClick", function()
			if arg1 == "RightButton" then
				local zone = BZ[Cartographer:GetCurrentInstance()]
				if Tourist:IsInKalimdor(zone) then
					SetMapZoom(1)
				elseif Tourist:IsInEasternKingdoms(zone) then
					SetMapZoom(2)
				elseif Tourist:IsInOutland(zone) then
					SetMapZoom(3)
				else
					SetMapZoom(0)
				end
			end
		end)
		local bgf = CreateFrame("Frame", nil, WorldMapFrame)
		local bg = bgf:CreateTexture(nil, "BACKGROUND")
		CartographerInstanceFrame.backgroundframe = bgf
		bgf:Hide()
		CartographerInstanceFrame.background = bg
		bg:SetTexture(0,0,0)
		bg:SetPoint("CENTER", CartographerInstanceFrame, "CENTER")
		bg:SetWidth(CartographerInstanceFrame:GetWidth())
		bg:SetHeight(CartographerInstanceFrame:GetHeight())
		local texture = CartographerInstanceFrame:CreateTexture(nil, "ARTWORK")
		CartographerInstanceFrame.texture = texture
		texture:SetPoint("CENTER", CartographerInstanceFrame, "CENTER")
		Cartographer:RegisterInstanceWorldMapButton(CartographerInstanceFrame)
	end
	if CartographerInstanceFrame:IsShown() then
		return
	end
	CartographerInstanceFrame:Show()
	CartographerInstanceFrame.backgroundframe:Show()
	WorldMapDetailFrame:Hide()
	WorldMapButton:Hide()
	ShowWorldMapArrowFrame(nil)
end

function Cartographer_InstanceMaps:HideInstanceFrame()
	Cartographer:SetCurrentInstance(nil)
	if not CartographerInstanceFrame or not CartographerInstanceFrame:IsShown() then
		return
	end
	CartographerInstanceFrame:Hide()
	CartographerInstanceFrame.backgroundframe:Hide()
	WorldMapDetailFrame:Show()
	WorldMapButton:Show()
	ShowWorldMapArrowFrame(1)
end

local num_tiles = 0
function Cartographer_InstanceMaps:ShowInstance(realZone)
	if not instanceToTexture[realZone] and not MapData[realZone] then
		return
	end
	local zone = BZ[realZone]
--[[	if Tourist:IsInKalimdor(zone) then
		SetMapZoom(1, 1)
	elseif Tourist:IsInEasternKingdoms(zone) then
		SetMapZoom(2, 1)
	elseif Tourist:IsInOutland(zone) then
		SetMapZoom(3, 1)
	else
		SetMapZoom(0)
	end
	]]
	Cartographer_InstanceMaps:ShowInstanceFrame()
	Cartographer:SetCurrentInstance(realZone)
	if MapData[realZone] then
		CartographerInstanceFrame.texture:Hide()
		self:ShowSpecialInstance(realZone)
		return
	end
	for i,tex in ipairs(CartographerInstanceFrame) do
		tex:SetTexture(nil)
		tex:Hide()
	end
	CartographerInstanceFrame.texture:Show()
	CartographerInstanceFrame.texture:SetWidth(0)
	CartographerInstanceFrame.texture:SetHeight(0)
	CartographerInstanceFrame.texture:SetTexture(path .. instanceToTexture[realZone])
	local currWidth, currHeight = CartographerInstanceFrame.texture:GetWidth(), CartographerInstanceFrame.texture:GetHeight()
	if currWidth == 0 then
		currWidth, currHeight = 512, 512
	end
	local newHeight = CartographerInstanceFrame:GetHeight()/CartographerInstanceFrame:GetScale() * 0.95
	local newWidth = currWidth*newHeight/currHeight
	CartographerInstanceFrame.texture:SetWidth(newWidth)
	CartographerInstanceFrame.texture:SetHeight(newHeight)
end

local cos, sin, abs = cos, sin, math.abs
local function smallRotate(angle, x, y)
	local A = cos(angle)
	local B = sin(angle)
	return x * A - y * B, x * B + y * A
end

local function rotate(angle)
	local A = cos(angle)
	local B = sin(angle)
	local ULx, ULy = -0.5 * A - -0.5 * B, -0.5 * B + -0.5 * A
	local LLx, LLy = -0.5 * A - 0.5 * B, -0.5 * B + 0.5 * A
	local URx, URy = 0.5 * A - -0.5 * B, 0.5 * B + -0.5 * A
	local LRx, LRy = 0.5 * A - 0.5 * B, 0.5 * B + 0.5 * A
	return ULx+0.5, ULy+0.5, LLx+0.5, LLy+0.5, URx+0.5, URy+0.5, LRx+0.5, LRy+0.5
end

local initializeMapData
function Cartographer_InstanceMaps:ShowSpecialInstance(realZone)
	initializeMapData(realZone)
	local map = MapData[realZone]
	
	local angle = Rotations[realZone] or 0
	angle = angle - 90
	local ULx, ULy, LLx, LLy, URx, URy, LRx, LRy = rotate(angle)
	
	for i,v in ipairs(map) do
		local tex
		if i > num_tiles then
			num_tiles = num_tiles + 1
			tex = CartographerInstanceFrame:CreateTexture("CartographerInstanceFrameTexture" .. i, "ARTWORK")
			CartographerInstanceFrame[i] = tex
		else
			tex = CartographerInstanceFrame[i]
		end
		local file, x, y, w, h = unpack(v)
		tex:SetTexture("textures\\Minimap\\" .. file)
		local A, B = abs(cos(angle)), abs(sin(angle))
		w, h = w*A + h*B, w*B + h*A
		tex:SetWidth(w)
		tex:SetHeight(h)
		tex:SetPoint("CENTER", CartographerInstanceFrame, "CENTER", smallRotate(angle, x, y))
		tex:SetTexCoord(ULx, ULy, LLx, LLy, URx, URy, LRx, LRy)
		tex:Show()
	end
	for i = #map+1, num_tiles do
		local tex = CartographerInstanceFrame[i]
		tex:SetTexture(nil) -- get rid of memory
		tex:Hide()
	end
end

local initialized = {}
local initializeTex
function initializeMapData(zone)
	if initialized[zone] then
		return
	end
	initialized[zone] = true
	if num_tiles == 0 then
		num_tiles = 1
		CartographerInstanceFrame[1] = CartographerInstanceFrame:CreateTexture("CartographerInstanceFrameTexture1", "ARTWORK")
	end
	initializeTex = CartographerInstanceFrame[1]
	local tex = initializeTex
	local left, right, top, bottom = nil
	local floors = Floors[zone]
	local z_axis = floors and {}
	for i,v in ipairs(MapData[zone]) do
		if z_axis then
			z_axis[i] = v[4]
		end
		tex:SetWidth(0)
		tex:SetHeight(0)
		tex:SetTexture("textures\\Minimap\\" .. v[1])
		local width = tex:GetWidth()
		local height = tex:GetHeight()
		v[4] = width
		v[5] = height
		tex:SetTexture(nil)
		local left_p = v[2]
		local bottom_p = v[3]
		local right_p = left_p + width
		local top_p = bottom_p + height
		v[2] = left_p + width/2
		v[3] = bottom_p + height/2
		if not left or left_p < left then
			left = left_p
		end
		if not bottom or bottom_p < bottom then
			bottom = bottom_p
		end
		if not right or right_p > right then
			right = right_p
		end
		if not top or top_p > top then
			top = top_p
		end
	end
	local map_width = right - left
	local map_height = top - bottom
	
	local x_p = left + map_width/2
	local y_p = bottom + map_height/2
	local deg = Rotations[zone] or 0
	local A, B = abs(cos(deg)), abs(sin(deg))
	local scale_x = (A * map_width + B * map_height) / (980 * 2/3)
	local scale_y = (B * map_width + A * map_height) / 980
	local scale = math.max(scale_x, scale_y)
	
	for i,v in ipairs(MapData[zone]) do
		v[2] = v[2] - x_p
		v[3] = v[3] - y_p
		v[2] = v[2] / scale
		v[3] = v[3] / scale
		v[4] = v[4] / scale
		v[5] = v[5] / scale
	end
	
	if floors then
		if #floors+1 == 2 then
			for i,v in ipairs(MapData[zone]) do
				if z_axis[i] < floors[1] then
					v[3] = v[3] - 490
				else
					v[3] = v[3] + 490
				end
				v[2] = v[2] / 2
				v[3] = v[3] / 2
				v[4] = v[4] / 2
				v[5] = v[5] / 2
			end
		elseif #floors+1 == 3 then
			for i,v in ipairs(MapData[zone]) do
				if z_axis[i] < floors[1] then
					v[2] = v[2] - 490 * 2/3
					v[3] = v[3] - 490
				elseif z_axis[i] < floors[2] then
					v[2] = v[2] - 490 * 2/3
					v[3] = v[3] + 490
				else
					v[2] = v[2] + 490 * 2/3
				end
				v[2] = v[2] / 2
				v[3] = v[3] / 2
				v[4] = v[4] / 2
				v[5] = v[5] / 2
			end
		elseif #floors+1 == 4 then
			for i,v in ipairs(MapData[zone]) do
				if z_axis[i] < floors[1] then
					v[2] = v[2] - 490 * 2/3
					v[3] = v[3] - 490
				elseif z_axis[i] < floors[2] then
					v[2] = v[2] - 490 * 2/3
					v[3] = v[3] + 490
				elseif z_axis[i] < floors[3] then		
					v[2] = v[2] + 490 * 2/3
					v[3] = v[3] - 490
				else
					v[2] = v[2] + 490 * 2/3
					v[3] = v[3] + 490
				end
				v[2] = v[2] / 2
				v[3] = v[3] / 2
				v[4] = v[4] / 2
				v[5] = v[5] / 2
			end
		end
		Floors[zone] = nil
	end
end

function Cartographer_InstanceMaps:SetMapZoom()
	self:HideInstanceFrame()
end

Rotations = {
	-- currently only 90*k degree rotations are supported since in-between cases causes texture bleeding.
	["Dire Maul"] = 180,
	["Shadowfang Keep"] = 90,
	["The Deadmines"] = 270,
	["Razorfen Kraul"] = 270,
	["Old Hillsbrad Foothills"] = 90,
	["The Black Morass"] = 90,
	["Hellfire Ramparts"] = 90,
}

Floors = {
	["Karazhan"] = {5, 140, 260}
}

MapData = {
	["Ahn'Qiraj"] = {
		{"a84f02b3c2f180bfffcf3227491ea0fb", 1017.852966, 728.192505, -529.042053},
		{"0469862cb27b64fc9a66135cd782d5d0", 1529.852966, 984.192505, -529.042053},
		{"ab6ed25f6971c030ee9f744b5e58b445", 1529.852966, 1240.192505, -529.042053},
		{"f303e9811d24622abe5a5c2ac809fd8b", 1273.852966, 984.192505, -529.042053},
		{"274fc50488a383d393aa6740787b9b21", 1273.852966, 1240.192505, -529.042053},
		{"3b7c4f4e89c3a46f63a8586f33be37be", 1017.852966, 1240.192505, -529.042053},
		{"e0525f82d690ddb2db8ee6c96a4cecb3", 1273.852966, 728.192505, -529.042053},
		{"e1b1070508ac202d3d0dee60a3df6569", 1017.852966, 984.192505, -529.042053},
		{"4d58934fb3e890a82e71ff198ac09a43", 1330.556152, 20.945675, -520.212463},
		{"62102373f9f975d60b619f8d896710d8", 1330.556152, 276.945675, -520.212463},
		{"8e9ba7fb3fca0e1bc0989f90bbc397fd", 1586.556152, 276.945675, -520.212463},
		{"8b33fa4f6401b51eb851a1e280883980", 1330.556152, 532.945675, -520.212463},
		{"7a79acd878362ad9cb2679e63a923819", 1586.556152, 532.945675, -520.212463},
		{"02aa57141f0bc01a6aee7fc149345130", 1586.556152, 20.945675, -520.212463},
		{"b7ec22ffa75fa09c70c84fddc19cdcaf", 1330.556152, 788.945675, -520.212463},
		{"a0a99c96abf7671641b36c416409546f", -73.765114, -135.567215, -517.757385},
		{"3c90cbac445b363cb62b6eda93e0bff4", 1033.138367, 761.693329, -512.331665},
		{"24a4f77a90754cc0ee69bbef7cdf0390", 1033.138367, 505.693329, -512.331665},
		{"270f9ddbe09713ddb88216107e76feba", 777.138367, 505.693329, -512.331665},
		{"da59821b463cacfb036192c2393bc253", 777.138367, 761.693329, -512.331665},
		{"a05adb457728524b04835929840702e6", 546.232422, 704.496613, -494.951263},
		{"db47f2b0c0bad6178198cb0273ddcacf", 802.232422, 448.496613, -494.951263},
		{"d733a518e2f2bb6eba52c68ed35181eb", 546.232422, 448.496613, -494.951263},
		{"3751053994b9827f0f34384dc590f1e5", -183.644882, 1293.087646, -490.234955},
		{"d317bddb1e114272259a86fb700c8e3b", -183.644882, 1549.087646, -490.234955},
		{"c8a8976cba13f2a4424d8836c52501ad", -516.438416, 1642.326660, -490.234955},
		{"f7c35bb6a7230324848bb58913263a8a", -260.438416, 1642.326660, -490.234955},
		{"4ce50e82f2531972289b8a72ab3d76a9", -260.438416, 1898.326660, -490.234955},
		{"2a1304505e2b871bd75aae59d0673943", -516.438416, 1898.326660, -490.234955},
		{"ef38132bc0cbe1268f2ad795fbb0ca1e", -864.000671, 1529.567261, -490.168610},
		{"b6cf603a900ec739ce0b819eb6062f71", -864.000671, 1785.567261, -490.168610},
		{"b9ba21cd0571e625cf62e461509c8ee2", -608.000671, 1785.567261, -490.168610},
		{"72d0bf82caa3d19af3490ce3df5b7024", -864.000671, 1273.567261, -490.168610},
		{"95ea43b71c6b5193d0a04f67d203e39d", -608.000671, 1529.567261, -490.168610},
		{"d040cc2a45c17b9b383d86b4a04526f0", 289.478271, 526.837769, -487.940796},
		{"05b89113acecf7fcc1bee130805f6ace", 289.478271, 270.837769, -487.940796},
		{"eab81e879220872b005b2586cb3c2689", 545.478271, 526.837769, -487.940796},
		{"4888361ad428437e35d5684bf2fdcf5f", 545.478271, 270.837769, -487.940796},
		{"ddf87f9191eda9613d71e7d15a3715f2", 33.478271, 526.837769, -487.940796},
		{"0cb71d7ec4552392888e54c82945a36d", 33.478271, 270.837769, -487.940796},
		{"6d36126857f88bac9242ce60418623f0", 333.104614, 1095.342407, -480.236328},
		{"d554adf8601b51b2176be893bb39dba7", 589.104614, 583.342407, -480.236328},
		{"36eb01e6d116979bc3a6f73ca4401753", 589.104614, 1095.342407, -480.236328},
		{"f8979a731a88ffbe95f1111d2eb21bba", 589.104614, 839.342407, -480.236328},
		{"a50a5694cb3214ef3a678aa51a87785e", 333.104614, 839.342407, -480.236328},
		{"8643ccea6354d72213d82746e21c7d3e", 333.104614, 583.342407, -480.236328},
		{"c8407dcd9440159b2d4c9114edfe4e6e", -269.597229, 2004.805176, -468.656769},
		{"8cc8574fe310aaca1c87933fd05737e5", 271.828024, 1103.004517, -456.481110},
		{"b209791d442b60c301d1b5025cc8ab5a", 271.828024, 1359.004517, -456.481110},
		{"f0bf157c642a659720469ea976ebc25c", 15.828024, 1359.004517, -456.481110},
		{"15b3236eb9f2f9dfb806c252831ee1e7", 15.828024, 1103.004517, -456.481110},
		{"bc7f8aa84815794dd8f16c25bd2d889c", -249.256622, 1948.516724, -455.956543},
		{"3fbaa7dc5b62d43ed47936b24f72df92", -505.256622, 1948.516724, -455.956543},
		{"93e55220a7f881bc49699281ea9dc068", -505.256622, 2204.516724, -455.956543},
		{"8a262c74eed4be24eb0775abc6262c26", 690.730652, -403.679260, -443.476837},
		{"0cf9a53a86c82a55afad0d7591e04925", 1202.730652, -403.679260, -443.476837},
		{"2b109bea1fde44fa378bb9cef898ba4f", 1458.730652, -659.679260, -443.476837},
		{"92f80f2bdec1bff2f8a8e292420efdb1", 690.730652, -659.679260, -443.476837},
		{"14be5c667166787b72afb44583d3a751", 690.730652, -915.679260, -443.476837},
		{"ad56be44451b811e19e74bf112fb8851", 946.730652, -403.679260, -443.476837},
		{"3e723c929d30792505e542077379a0ba", 1202.730652, -659.679260, -443.476837},
		{"c7f553ab0dae4739b22244788b7f5a93", 1458.730652, -915.679260, -443.476837},
		{"55b2d10ce3982a6bd01904d53ba234f5", 1202.730652, -915.679260, -443.476837},
		{"25f61185c5e672eed74047a2b401794c", 946.730652, -659.679260, -443.476837},
		{"2c4a5078437432cbe86c04cc21357482", 946.730652, -915.679260, -443.476837},
		{"441baac5bba9b3f3c415293234eddf52", -555.081421, 1100.123901, -441.412628},
		{"eff45df2ab0abbb88b10be51be9d9f14", -555.081421, 844.123901, -441.412628},
		{"a78b0edb414a9401160d1dc5f2ddf393", -811.081421, 1100.123901, -441.412628},
		{"9e6bbb3632668592713412ec5b912985", -811.081421, 844.123901, -441.412628},
		{"089837ee965c052e5e908946d9d794f9", 959.104431, -357.536896, -410.527649},
		{"a4c998c81e44ae5cd66c4dee597c9f3c", 1098.565430, -17.924500, -410.527649},
		{"0da7197e2368b23bc95f905b3ebbe740", 842.565430, -273.924500, -410.527649},
		{"5a8bd750aac98919155d0ce8041840e0", 1098.565430, -273.924500, -410.527649},
		{"78b024f80ec838ccfb861da05dd80c0f", 842.565430, -17.924500, -410.527649},
		{"9149264dbff0682e54cf5d70de87a6a9", -422.297028, 2207.600342, -409.808289},
		{"74a6c24b2d1e1c73f7cf6107f495cc52", -422.297028, 2463.600342, -409.808289},
		{"b36ef1f0f313aad3e3c63737f6e1ce31", -166.297028, 2207.600342, -409.808289},
		{"5f4776ffa3fd9e1097f3a833ac9dc81e", -166.297028, 2463.600342, -409.808289},
		{"7c799f1873931a4455623c5140eee848", 1099.014404, -113.040703, -393.262360},
		{"889f5c54faca7fc1a72cae99b9d3f3f4", 1355.014404, -113.040703, -393.262360},
		{"46dc943ccd2d713620dc4313474e2e59", -222.062042, 569.693054, -386.330566},
		{"3381878c00c948fb74f67cf179534a55", -222.062042, 825.693054, -386.330566},
		{"c723e705852cda06e9ffec68d5b6e9c0", -478.062042, 825.693054, -386.330566},
		{"5a9121bd6f6e0d5dbe5de8133ae3b1d7", -478.062042, 569.693054, -386.330566},
		{"5c719b0e391b06b2058b44cfa123c78e", 652.060974, -105.742455, -367.908020},
		{"e25f1bff25b13b4f16bd26989413349b", 415.528015, -237.014465, -364.679688},
		{"ba8c744394c3bb8c0e9a9ac93282be29", 671.528015, -237.014465, -364.679688},
		{"4840d54d933c911a79b402df0c46eebe", 159.528015, -237.014465, -364.679688},
		{"13cdcadb89534a05d4b895652f969416", -377.848969, 121.631065, -321.828888},
		{"6c4bbf1137dff64d9ea33ea2573335a0", -377.848969, 377.631065, -321.828888},
		{"65eec9a4af89ee9bd83997acef6ae58b", 72.301422, -150.681488, -320.613434},
		{"3a98b7f42cc506169ed34320a2f1bed3", 72.301422, -406.681488, -320.613434},
		{"3f2e35a8123dca99a464f7d6a27dd511", -183.698578, -150.681488, -320.613434},
		{"b7b6ede87ccce5ded4b840bbd8b141e7", -183.698578, -406.681488, -320.613434},
		{"a08d59e72856b8c58e84cd740c414d9f", -133.565857, 115.836716, -310.170410},
		{"124dc57c465c2dad6df193b5ffe8e93b", -133.565857, -140.163284, -310.170410},
		{"3f29b9a65bd3a6102c3ac364b84538af", 122.434143, -140.163284, -310.170410},
		{"0f0e93c04c45ac35d5df979d7ea88659", 122.434143, 115.836716, -310.170410},
		{"c1d5144858e80677b26dd84ee303191b", -432.271484, -104.683365, -299.053284},
		{"53eaaf0b549b9fd0a4e08f548efedcae", -432.271484, 151.316635, -299.053284},
		{"1e69d624685b9aa3ba19d3fe57ec0e53", -176.271484, -104.683365, -299.053284},
		{"67e95476a7dedaa5742329edeafa2fb2", 7.478103, -132.046921, -178.597931},
		{"d51b2ebc3551e86884aa19f9ed414265", -33.706699, 125.604576, -169.317078},
		{"a3ba26ee1e7b577b5b6470cfa7d2afa7", -190.386871, -129.472549, -155.780334},
		{"43ea02f2fd5dba9f38f10c272ed04176", 62.567692, 66.264061, -131.768387},
		{"1d9d09ec55e6c4023e4522ba4ceaa627", -6.563436, 44.722046, -104.216606},
		{"2ea8cd9f8e0cb08d8a1997909abf6f8f", 249.436564, -211.277954, -104.216606},
		{"def8cbe14914a5ae0a8ade0c51b0dd27", -6.563436, -211.277954, -104.216606},
		{"92022affaa14a5c0add3b8936fa6ecc8", -100.926910, 121.840149, -102.804382},
		{"1c17888f5021433d9b378630f7722e20", -100.926910, -134.159851, -102.804382},
		{"5dcb494bc7a69ca3ba8020bb2f7c49ce", -348.482025, -100.667854, -92.549950},
		{"bef64fa37000750e3f90d69aed036845", 7.612481, -205.549866, -86.741753},
		{"39437f9eac296007f48bfee7c41e4de4", 139.417175, -173.186508, -86.645737},
		{"682624018e451fc13f8f376f1d55349e", 261.112762, -70.986183, -86.000786},
		{"45414af2e96c98764b7864c6293f15ae", 261.112762, 14.907022, -86.000786},
		{"66a9b3e284b083f28d913beb8a44321f", -197.838593, -149.032013, -71.568092},
		{"1af228b77646b972e05fa511ef346c3e", -197.838593, 106.967987, -71.568092},
		{"c805aad96c07c1ab3e102c91365a87b1", -247.586639, -93.357079, -33.385384},
	},
	["Auchenai Crypts"] = {
		{"b172905581d06d727e19f7b10272a1bd", -407.895294, 198.213074, -370.536163},
		{"4f2fa269b09e28e166852f7d37e3e7de", 104.104706, 198.213074, -370.536163},
		{"399d846a9c4c0b337123f9971c4784fc", -151.895294, 198.213074, -370.536163},
		{"c359840298fa5690cf66cb0aa8af0860", -564.650208, -86.973625, -6.942796},
		{"62c5f77be6c4ce444349fe47d07b55e3", -152.827637, -102.272926, -5.093929},
		{"d43218f2308433beb7442223b4362151", -408.827637, -102.272926, -5.093929},
		{"289697614995688195473fea4b5213cc", -53.845661, -23.350622, -2.085798},
		{"098054af7a2fcc2d03e07205dffa1bce", 202.154339, -23.350622, -2.085798},
		{"8a88bffc3669085af9f147885039e6c6", 45.888657, 673.346008, 38.760227},
		{"516c8629ddbb9fafc06422aa0eba961b", -210.111343, 673.346008, 38.760227},
		{"0c4fcc5347b6926dc92b4576b09edfbb", 361.442039, 567.456421, 45.813297},
		{"7a64376a6185b96f3467d486a0b7742d", 105.442039, 567.456421, 45.813297},
		{"4b67a2742e378d7a075cc61c741e46e5", 361.442039, 311.456421, 45.813297},
		{"42a403813ce943e2e801fceb2f0cbff6", 105.442039, 311.456421, 45.813297},
		{"ab0da751579394fdfd1cee1bb149782a", -589.901245, 255.164200, 53.026886},
		{"7ac2495fd9a1e85dff8719e5bd0a4980", 185.492722, 303.032196, 53.119419},
		{"e3691ab73e0bb0465c0f724b2ff60022", 187.882751, 651.143311, 53.119473},
		{"d667a8c03ad9862621a56552c55462d6", -501.423828, 87.671188, 53.126865},
	},
	["Blackfathom Deeps"] = {
		{"70bd476daf9bf89fdd263581c3a37f83", 603.590698, -458.121887, -166.029358},
		{"c7db2111705c118ae2e977162f7508db", 859.590698, -714.121887, -166.029358},
		{"32b59b6688febae29779e08a3b510722", 603.590698, -202.121887, -166.029358},
		{"3142420b82e684b1dc1f969e7b601111", 859.590698, -458.121887, -166.029358},
		{"145012be7c6fd68e0b4b7d3a2e58e7e1", 859.590698, -202.121887, -166.029358},
		{"1c08cda9753cf031eb101ad15130270b", 603.590698, -714.121887, -166.029358},
		{"310ebc31ba5be21557857fabe4d7f60d", 571.676086, -735.518066, -164.195068},
		{"f82fe7ccbe7264c3bc5ed3fa1b4f8074", 1062.659973, -706.924988, -161.050598},
		{"361711a5f4854697ed6e482a5eb0fdbb", 806.659973, -194.924988, -161.050598},
		{"defda8a635a26fc00c04716427d8db30", 806.659973, -450.924988, -161.050598},
		{"1355774216da3a658c0eb23a4190977a", 806.659973, -706.924988, -161.050598},
		{"f3c74c5af20f3050b52ca797a5ed1a1d", 1062.659973, -450.924988, -161.050598},
		{"2863d12a872925460f5d6927b7c7eb3e", 615.297943, 80.736267, -153.811981},
		{"61b0d5f77fded5711b423e2d5a34f4f4", 615.297943, -175.263733, -153.811981},
		{"ebc5a727a5cd482d1a6aacc5ea774889", 359.297943, -175.263733, -153.811981},
		{"49f74496e6215d938d25569a88a52548", 1039.428223, -224.002090, -151.570770},
		{"f0ee2bd8ff192f80c45c10f9dc2456ac", 783.428223, -224.002090, -151.570770},
		{"a6daef63649ae345d25a0c4c98ce6001", 783.428223, 31.997910, -151.570770},
		{"46657de8ffe5523fd9f1ffa0fb1e963f", 1039.428223, 31.997910, -151.570770},
		{"8f40426718d4593ea0181bd9fe08d23b", 365.638802, -109.817551, -130.141830},
		{"56c831d088281e7ea5938056f77d181a", 869.810608, 38.214508, -127.356438},
		{"2d6bc321a7f4a8eb8a820ec23dfe7a9f", 560.706421, -299.979218, -124.319977},
		{"ddac70385cac8ed859d4ad192dbc6c16", 1213.740356, -295.249756, -120.360161},
		{"94b5e8319484a8e906275bb75a7b1326", 1386.338867, 241.631042, -119.235001},
		{"09337b5dad28ad1e095d6bf149cc4eac", 1174.124146, -516.374512, -116.538933},
		{"110bef3aa668db8db75863611ea02424", 572.883179, -848.048523, -115.732018},
		{"140d1b17944d58e41fccff660415b34b", 1144.706909, -129.106674, -113.146698},
		{"78f78df8378824f0e64b9f252e5dfdf0", 322.915558, -158.676758, -111.624496},
		{"9649f54b6b9d9e09f3ae1bff89ddea06", 269.008270, -256.863617, -111.083725},
		{"7582bcf6fb287a80b81a8ee722e480d5", 1055.830933, -51.953846, -102.239067},
		{"1fb665b140ff8db78392ae6aa44a75a6", 1471.679077, 33.109715, -101.220581},
		{"6fad6b8b063e8640ae100abdd30d6aec", 1727.679077, 33.109715, -101.220581},
		{"e5b06191e385e3496bb35d432819d4cc", 273.490845, -417.350464, -98.463737},
		{"5956b196160a34cda9e2f6bb7a6c63df", 153.635635, -344.078674, -95.240974},
		{"1700cd072a0bc5cf6814885b7b781660", 1558.108154, 388.811646, -93.897781},
		{"85ceebf41c6cda4786ecb94f6e6fd7f2", 1558.108154, 644.811646, -93.897781},
		{"385687b575b0dcc3f344060d17df5e74", 1558.108154, 900.811646, -93.897781},
		{"8caddcbfe53268a8fbdea6e285163877", 1347.622803, 211.050880, -91.956100},
		{"7d5f3569014bc7f575cfd966a67280a8", 1347.622803, -44.949120, -91.956100},
		{"ed739c9694bab6a9192d092bae520756", 1529.095825, 155.690063, -86.518738},
		{"c6568b5d481db57f09e29e1044929fb4", 1054.411743, 43.699295, -81.077042},
		{"b0a0a547beb7e7652b3a7e16159542e6", 1292.364746, -105.981758, -74.303101},
		{"bd0797903ccb54ecf62bdea415e0b88e", 1183.728516, 2.454933, -59.633141},
	},
	["Blackwing Lair"] = {
		{"e6da9447c554b83829be872b2c7cf6e4", -387.342316, 719.268738, 220.888992},
		{"dd568020402c7fec19f4105d98a362bc", -154.640305, 938.558960, 221.722961},
		{"b986e49f7459a4659081a67f29f9fbff", -108.445801, 878.870117, 221.778580},
		{"e97c1c831e3b4b043c440cad9024f01b", -675.209229, 1195.778198, 232.407471},
		{"6cd554a5ae587d0696bcdce14ceeebf9", -419.209229, 1195.778198, 232.407471},
		{"40f6e1f8acf5b7755aa9af7a246109d5", -217.066742, 918.053650, 232.441025},
		{"f13b6c3f23034cef237ca676e87418f4", -439.521088, 935.369507, 233.562332},
		{"2248e899dfa070ffffa87101ed7b1034", -251.295135, 938.644775, 233.629257},
		{"ccc260bb017071e571bbf2c7db00b269", -668.795593, 835.832458, 254.670105},
		{"1e84aab969c569f09e5fe484ad1d08da", -688.646851, 939.984741, 257.307953},
		{"ab220cc712fe25738745fc2ce9987560", -861.794617, 906.467957, 257.389465},
		{"897a0cd0ca89f0cee5302a000510848d", -874.589783, 694.812500, 279.342346},
		{"c36e657e0ff3800e8167acc49ce4b9a0", -738.450562, 648.433533, 297.087952},
		{"8e222290f0ed1faf1cea59b331d84a86", -665.161560, 869.729919, 319.357941},
		{"8e41c7434da173fd1f637e4b9312cdba", -666.787720, 691.566650, 320.290314},
		{"4fd06c29cd6d664be5fc77a262031771", -410.787720, 947.566650, 320.290314},
		{"c2079e03589c5a624c6d09a96da62798", -410.787720, 691.566650, 320.290314},
		{"8867a93ebb77539f30c4379695c6abf2", -666.787720, 947.566650, 320.290314},
		{"421bc9ffb5123c5082be5e7cf4bae325", -879.560608, 878.677673, 327.854431},
		{"d031be303b3c9cb543dc5093953072be", -904.665039, 802.551941, 338.810974},
		{"77fc205a177963df6f302bb310849285", -1040.549927, 767.587463, 370.083862},
		{"4588c52ba3049751fb24335c25b46dbb", -1040.549927, 1023.587463, 370.083862},
		{"bfa977c1c7fed7c45d053b04fdec9bda", -1086.917969, 1037.666748, 370.245270},
		{"918e9c494b20b9039c661ae9bcf65028", -830.917969, 1037.666748, 370.245270},
		{"8d63b4d8ed2f79d00a6ada93b3a75b35", -584.552856, 1131.139038, 377.847748},
		{"2988e4674665bb091fc30ec470eb7341", -399.062897, 1131.139038, 377.847778},
		{"bac96d2d12a973cae890223c0c5b9601", -822.659363, 962.095154, 393.326447},
		{"057479dbd614afc9473357c46f7518ed", -742.988281, 1196.297607, 393.395477},
		{"dcf94cbf86b75d17ea016cfe17a687e1", -668.808960, 1218.392578, 393.395508},
	},
	["Blackrock Depths"] = {
		{"09469b3d4c5a8f9f02efff91c5de533e", -2468.810303, 1227.399109, -417.784973},
		{"86164732cfc9c7990402011b3f2f888c", -2468.810303, 971.399109, -417.784973},
		{"c1c9f5d5dcdcdad25817aacbc9479e32", -2212.810303, 1227.399109, -417.784973},
		{"26aeb74c5555d2549355e70a9f1fb49c", -2212.810303, 971.399109, -417.784973},
		{"e7430eeb8d4afebc8a215dcf3f728342", -1956.810303, 971.399109, -417.784973},
		{"97e65614ce0e39ed9fbb68751cc181b0", -1665.481201, -29.818264, -399.798004},
		{"623416b0baf2299e15c8adb26a796088", -1665.481201, 226.181736, -399.798004},
		{"1746ff3f79068655d6fd5ca37343770e", -1409.481201, 738.181736, -399.798004},
		{"aaa6b2064eb4b4b23049b33e4edb30ad", -1921.481201, 994.181736, -399.798004},
		{"fdf9b9136acf62720bd2da26e4e70635", -1921.481201, 738.181736, -399.798004},
		{"98bcf710aafb3691bcd7ecf68107274c", -1921.481201, 226.181736, -399.798004},
		{"bfe465f091bbe99ebadd113eb33847e8", -1665.481201, 482.181736, -399.798004},
		{"b27a374ec6dfd381fb28f6c5590ea78b", -1409.481201, 482.181736, -399.798004},
		{"c21728512b6bd57a87fc1fdfaaa227c3", -1921.481201, -29.818264, -399.798004},
		{"ff1ece15f069d3d9b5c5e1be283cdc4d", -1665.481201, 738.181736, -399.798004},
		{"83098780c356fe70cf560b9d8b375a78", -1409.481201, -29.818264, -399.798004},
		{"9480947239d970d0c459409d7ff087d7", -2177.481201, 226.181736, -399.798004},
		{"ad520a39ec72560a3a516ccfe0cffdd8", -1409.481201, 226.181736, -399.798004},
		{"030d746c3ae62c772033f3d220aa9214", -1665.481201, 994.181736, -399.798004},
		{"caed76d83665b9219e531f1a02f3d0aa", -2177.481201, -29.818264, -399.798004},
		{"25b78fce75a1794294bac8e604a314cb", -2666.110352, 809.257141, -250.773712},
		{"641529bbcb032a4565257c4c6e95689c", -2666.110352, 1065.257141, -250.773712},
		{"d6cc9f2a53adb805ea82693fb1c6bc2a", -2666.110352, 553.257141, -250.773712},
		{"6fa42b0c7e57d2344fbb196721bdb41d", -2410.110352, 809.257141, -250.773712},
		{"1c208e3285f6887a603277cdff9f5c06", -2410.110352, 553.257141, -250.773712},
		{"e33c4fd04313b687993e7edd08aeed74", -2390.613281, 593.068878, -249.577774},
		{"d8d13445eeca1b229c8287111c224532", -1878.613281, 337.068878, -249.577774},
		{"8a3b4ff2c491c37195bc517db3647fdb", -2134.613281, 593.068878, -249.577774},
		{"fb62d6d1524e2380f231ca741fa4443f", -2134.613281, 337.068878, -249.577774},
		{"3d73a565c76777f8a4285bd127a7621b", -2390.613281, 337.068878, -249.577774},
		{"780016c3248555b3062452a67409bfd9", -1257.890015, 312.994629, -240.874603},
		{"1cbf927818114e3ae91ed260b0b2e803", -1999.549438, 452.561279, -232.903732},
		{"f71510a7c31734ae759986c203d727da", -1743.549438, 452.561279, -232.903732},
		{"263113fa659a3c788703673eaf94f84d", -1999.549438, 708.561279, -232.903732},
		{"24cd3101606af5abd5fc028db2c8d628", -1743.549438, 708.561279, -232.903732},
		{"3b71aac1925580871995b43b46290817", -2240.435059, 896.248962, -228.062500},
		{"9676c1eecc932dd9e5c5901edca3c53c", -686.028625, -245.845810, -204.802338},
		{"88c0d749cb7c5c911572999a48e0dcba", -942.028625, 10.154190, -204.802338},
		{"b11e677617ce83affbf62a8aee6c9257", -942.028625, -245.845810, -204.802338},
		{"9fd482909c49f941b9c59d911e76c7fc", -2717.353027, 866.367554, -189.404785},
		{"64dfcf77e8c2ebed85c0e95edb1d47ce", -2717.353027, 610.367554, -189.404785},
		{"ad7f926992da09fa2557f9f1e47c0c0e", -2973.353027, 866.367554, -189.404785},
		{"3814e5287ce0faf578dce307210eb4b3", -2973.353027, 610.367554, -189.404785},
		{"3cc499e99f5b6b9cfb23e93acf4350ca", -2859.297607, 1416.010376, -185.508881},
		{"0169fcdf281c592e73f837a32ba97c80", -2859.297607, 1672.010376, -185.508881},
		{"9fcbe842ea609cc539119eb7d3bc2ff1", -2829.871826, 1114.800415, -184.350189},
		{"fa79f4b9ff896af7264611c55a7bf70b", -2829.871826, 1370.800415, -184.350189},
		{"b49fec537a017579d2a482cf2355e1d7", -2629.463135, 612.082214, -184.164337},
		{"3b9278fd1d58b658a2e071b9ce0e6b5d", -2654.039062, 557.893127, -172.547470},
		{"2dba442581e7213b43a46ec1d89662bd", -2398.039062, 301.893127, -172.547470},
		{"1d55922e0cd8dc66a4f2b227ba604f96", -2654.039062, 301.893127, -172.547470},
		{"d1d5d4df2d3e9f010044ce1e7287dfae", -1334.353760, 433.194122, -171.558807},
		{"70a79a96d7e338e2c45592be05dd1e93", -1078.353760, 433.194122, -171.558807},
		{"d21a389c0a942ecb2992a02e2cc809ff", -2209.963135, 221.228607, -171.428864},
		{"701e7c96fa71583024ea00f39e5bca78", -2465.963135, 221.228607, -171.428864},
		{"e57a818069bd0529ade8cf7992d817fd", -2465.963135, 477.228607, -171.428864},
		{"065cf8a5833b4b5533f00b269c46de61", -2039.609985, 630.056335, -168.533051},
		{"014e81536b620d2363ea71cf6c85fe6f", -2039.609985, 886.056335, -168.533051},
		{"f413590aa96de98b923bb9100a47234f", -1783.609985, 630.056335, -168.533051},
		{"c91edccbf7a535e566b76b8b1fab4dca", -649.052856, 280.015350, -167.618332},
		{"c51fc00a25dd19a4633aadecb68ed508", -905.052856, 280.015350, -167.618332},
		{"77d170b4efeec9e0ad6d96b9ae26e240", -1350.446655, 219.208313, -161.109573},
		{"45f58e48034102543640e71b548bc755", -603.542542, 78.113625, -158.457062},
		{"b8578d04d32c37bfe1d03d750dae0ff3", -603.542542, 334.113625, -158.457062},
		{"0218f5f564d96748e1655dc615fe6736", -859.542542, 78.113625, -158.457062},
		{"167a0802f397febd8d52ff0e74777f0f", -2570.443359, 582.396973, -156.494125},
		{"314a636abb674224ef5bf88c1ba0df98", -1662.172485, 410.265442, -149.540802},
		{"27efce68942f5e9b4fa06521907965b2", -1918.172485, 410.265442, -149.540802},
		{"400d990135c7c867fbb580f48beacf4b", -1918.172485, 666.265442, -149.540802},
		{"468d2d1985b719c892de35259e0a3c99", -1171.647827, -78.488434, -149.375244},
		{"36d818faa2678c2c761b816c8d8d1129", -1171.647827, 177.511566, -149.375244},
		{"342a08d984bc58ce3c3a06ae30a33538", -915.647827, -78.488434, -149.375244},
		{"e5f7e035cba05ae0ad3a4e6520b687d1", -915.647827, 177.511566, -149.375244},
		{"01d81986b64d15c0295fa8c390e94a65", -1267.784912, -18.572266, -149.306641},
		{"b1c881f783fc273b5a79c67e9ef62aef", -1267.784912, -274.572266, -149.306641},
		{"e9ecccd873fcbc355f20176aa2c4f3df", -1523.784912, -274.572266, -149.306641},
		{"810eaab9c0c38d59af5ea4ed14c57b39", -1523.784912, -18.572266, -149.306641},
		{"b941fb2f27e4a66ef289a3bf1cc28091", -1523.784912, -530.572266, -149.306641},
		{"e7481a76a55e2a28813e9065eb84e3cf", -1706.153809, 305.076202, -147.808395},
		{"b74fbc80b287c17548da2fe90cb41959", -638.077209, 182.559952, -142.480621},
		{"e02bb7dc2bdd2f172a220758fa381a11", -894.077209, 182.559952, -142.480621},
		{"e825cc9d5c6e830c33999e51cbfcfe12", -1652.160767, -129.949615, -139.900238},
		{"1a878d1777dda631e6e00951dea6745c", -1109.109009, 328.755493, -128.030411},
		{"df7f1690a34fce9c24988e613b9b51b5", -1940.134521, 399.830048, -123.630913},
		{"a33724c6863781e4586410b32e09a7f3", -1277.937134, 66.179703, -120.175079},
		{"49545d416652efa42010970c1bb04655", -1482.338989, -127.355392, -120.175079},
		{"a65d93baa375ed0c1a360ba7065a7902", -1282.989868, 462.537720, -118.645416},
		{"73205a07eb1e318766be3df8b4e4b58f", -1381.503418, 468.991196, -117.849289},
		{"95b9ac1c1e7dd53aff42e2bcf1b132b7", -1381.503418, 212.991196, -117.849289},
		{"cdba8ed43794e58b26d6852d445ad133", -1125.503418, 212.991196, -117.849289},
		{"fee09f472e789aab36e2e955f49221e9", -1125.503418, 468.991196, -117.849289},
		{"3ee4bf65a942cfca692e424582d0f005", -1712.469238, 241.358398, -108.301437},
		{"2dfa6717d12e703816156878d54dfce0", -1739.614746, -90.598099, -107.535698},
		{"834987b35ece95a14091496e29b00b01", -1646.617920, 80.343033, -107.535698},
		{"05819f3965d98f66319207dd793395be", -1180.757568, 208.928528, -107.103493},
		{"0a6251564bc8159314a0c398611226aa", -1724.284424, 602.087158, -101.383217},
		{"8e1588bdce77163c602e9d738ad8e462", -1667.077515, 656.232361, -101.211708},
		{"40e05a709efb29c469bd8f8dc7d97a3d", -1804.046631, 657.083557, -99.972366},
		{"cb5e6dd3ebeee4645e2d524881acd466", -1868.337402, 224.499802, -99.605713},
		{"42d4f1b8a647f9899ba42a84f96f4915", -1860.447510, 256.747162, -99.577568},
		{"a657a915b0cafbc557d1e0fbb3e8aad4", -1697.737793, 446.265259, -98.921989},
		{"f3bf080278445f85199aa859e6920db7", -1658.965332, 480.780792, -98.821289},
		{"230be86dccca3394abc7cb09b9fe9ad8", -1386.661621, 233.858948, -92.523079},
		{"fa078f77ac8215ae34058bb9d3df4ebf", -1541.629272, 2.230281, -92.523064},
		{"9efd8b1674987bc538b5de55f061c5de", -1035.675903, 463.241730, -88.137779},
		{"7991720ce95522bca3810e1aac25290b", -1291.675903, 463.241730, -88.137779},
		{"60e82af2038b01cbccd3e4d7e378d0fd", -1748.107910, 444.828217, -87.595093},
		{"bb5066db9775dfeb0ee2c6ab5b169b5f", -1640.298096, 412.678741, -86.688431},
	},
	["Dire Maul"] = {
		{"22d25ca8f14d9f73a8920291b04e0e25", 261.166931, -1230.355957, -239.979172},
		{"2bae92fe8632e16bd3333e1c2a069a67", 517.166931, -718.355957, -239.979172},
		{"ef539e08ea0a942f6dee94c05131aaee", 773.166931, -974.355957, -239.979172},
		{"a7ab1f78c3603d1e00e7b7f58835b51c", 517.166931, -974.355957, -239.979172},
		{"e172665131fee168c62766330cac77f0", 261.166931, -974.355957, -239.979172},
		{"9df4b13eea7a2ae10dece580c2baeff9", 261.166931, -718.355957, -239.979172},
		{"ac5092d7f22dc27f8e9a4618e6a9c156", 517.166931, -1230.355957, -239.979172},
		{"14d4b4e17e80f1418537628932b44303", 490.140045, -776.920654, -234.443314},
		{"00cde19f745aa51d3ce453936d5aaa5d", 531.696167, -708.442505, -206.501434},
		{"659bf6ff5feeeada15986d801dd7dfd7", 479.681427, -619.318970, -170.733398},
		{"37051a8032756dd822f0bc797cfc3a73", -248.078323, -949.485352, -122.286423},
		{"e7b1ea2ec00cdc79e6619128267ced6b", 7.921677, -949.485352, -122.286423},
		{"768a50199a9842710dc23312bc246912", -65.013153, -747.059448, -118.814468},
		{"e39e52c26f62a126bb6d4f30c59eaa03", -65.013153, -491.059448, -118.814468},
		{"f4ca878f76874e579ae0ec3a25a05a27", 190.986847, -747.059448, -118.814468},
		{"a43ee50e02083ad865ead845a67b2b84", 190.986847, -491.059448, -118.814468},
		{"5cd96d2b24fe407d81853a27afcdcd76", -321.013153, -747.059448, -118.814468},
		{"580d7104a5d92b10621016848a2d30d3", -321.013153, -491.059448, -118.814468},
		{"ff30fd46d8d2dee23dff0b96fa04a28c", -321.048431, -1035.393555, -117.140274},
		{"5b77a64aad0c11548136a0f33e7c4a60", -303.018829, -823.742371, -115.206589},
		{"bc0c780f270df9bdb46d048414b70fdc", 52.907536, -994.519226, -114.273277},
		{"d7106ee4895949cbe357e752ca0f4129", -265.114502, -814.203186, -114.109962},
		{"75fcf371f78b8fa6d34946359a247dd0", -295.892548, -760.075562, -114.088257},
		{"a85786433bc40abfa196f8bd60b77785", 468.174866, -614.080383, -113.250641},
		{"ecf758bb33c233604b7da441b17f90ea", 366.479034, -568.412781, -113.250641},
		{"793581bdaea5751229c584dbdbf8f874", 261.884064, -568.404053, -113.195305},
		{"7265c4094160597684608caf78ef1463", 513.744629, -657.140442, -113.169846},
		{"67d0b7ad1c2dcc0ef10dda6171b197f4", 388.198120, -540.173096, -100.979057},
		{"43ca5f097b64e12446a59acfa85abb37", 210.418610, 1122.652771, -97.000191},
		{"640ea447d88d49d97a4dbaed16554e0c", 210.418610, 866.652771, -97.000191},
		{"68820381313f686b76443be1b23bd7a0", 326.273590, 826.059814, -95.525055},
		{"d3c8f5b224d178bb386a989a498ed51b", 505.202179, 732.532166, -95.525024},
		{"11780a3d7282e1b2de95bf1a2858e67f", 346.647369, 847.563721, -93.971321},
		{"d5ed1fb515acffd05dcfa56a1275f63c", 564.841034, -448.019897, -93.264946},
		{"89228d746e2017c51e719b9e06ae6f34", 308.841034, -704.019897, -93.264946},
		{"ac65861a2c99ea32619a13596304f00e", 564.841034, -704.019897, -93.264946},
		{"2a4f9355b68e09bff9253d238b3697cd", 564.841034, -960.019897, -93.264946},
		{"687ebcdeb9305d88704d747ba270782b", 820.841034, -960.019897, -93.264946},
		{"eddf76651536484328188e17f3ae4c5f", 308.841034, -1472.019897, -93.264946},
		{"6956513817c69d58751a1ff6c5c5d69d", -459.158966, -448.019897, -93.264946},
		{"54c9718cfce631dfd1c5fe30646fabdf", -459.158966, -960.019897, -93.264946},
		{"430a74c624ab5b5355bbdeb2c91d7c55", -203.158966, -960.019897, -93.264946},
		{"bf11ffe12724c6b80ae3a30ca03ff6e1", 602.736938, 580.501831, -85.744431},
		{"d14acaf64b2c43eb77bbbf8a70984dd3", -119.943634, -779.965454, -82.433418},
		{"12c6f8d0d1bdaf44f0874e854a6a6e27", -375.943634, -779.965454, -82.433418},
		{"53dc062770506cdcec52a7f38ae7a0b3", -375.943634, -523.965454, -82.433418},
		{"63cb702e6cf0120a5d2e549ea83dde0b", 136.056366, -523.965454, -82.433418},
		{"f5123cb7f7c0733825f0ce6907a92080", 136.056366, -779.965454, -82.433418},
		{"2752bced300e14ddfec9cc31998fed04", -119.943634, -523.965454, -82.433418},
		{"a836a1941db3fadd0b3d97bf299c6d5d", 601.809570, 434.060211, -75.916039},
		{"cd2af5ed1e3d2ea929eafff92fb2c993", -26.846699, 198.681976, -73.193733},
		{"9458fe956006fdf54f048d864d17ec2e", -26.846996, 133.091492, -73.192696},
		{"a7c03ed1895e8017428b39c533ddce45", 60.741028, 166.118439, -73.192688},
		{"61ce844bf601edd35f1509d34c6db958", 639.066589, 304.933411, -72.972893},
		{"579e327e5a91a9f7a50c29272dca5d66", -11.786288, -994.337341, -72.877739},
		{"1d2a72e428142a475606617f4c5319bf", -4.955119, 138.720032, -72.651161},
		{"4ed23023fd103b3d26c9e1eed191cd4e", -60.223507, 245.454315, -72.642517},
		{"ed6858fc58b54323014365f581a8862d", -61.805672, 267.158386, -72.642517},
		{"49d8f9f9b9ca1cc5e84e7cef31957198", 21.071270, 110.502907, -72.637146},
		{"f28d9ea0061d8fe3fb5081a77b073cdb", 20.901194, 54.068909, -72.637146},
		{"84d5e9c18c79e4b829286fdf9ce1a29a", 795.472351, 238.352692, -71.662018},
		{"b5c7b1a8e694b6ae20374d19bd18bc98", 539.472351, 238.352692, -71.662018},
		{"0f55dee37d6cf687498029301ef91694", 795.472351, -17.647308, -71.662018},
		{"3b693d34ea9a30872a39a1095f6045d4", 795.472351, -273.647308, -71.662018},
		{"5a1e808152601aee1d1e29bca57637bb", 539.472351, -17.647308, -71.662018},
		{"2fc73ab627b074e7ccb45e66f3d0b92f", 692.318787, 172.497665, -71.662018},
		{"32ccf52c7cedf91fc7cfee641e61a170", 539.472351, -273.647308, -71.662018},
		{"3e7737499d981e1f561eb2c49e73e8ac", -101.950020, 301.315582, -69.078789},
		{"4b159e1c7a65ff70860dfcbee3091d69", 95.557587, 1710.817261, -66.179146},
		{"6a85132f66a5646afbabc0eb5162813d", -416.442413, 1710.817261, -66.179146},
		{"5b586b57a759a5f0ed063ebf77212a35", -160.442413, 1198.817261, -66.179146},
		{"82e418d6e81ad64bca22b9e0a2ad8799", -416.442413, 1454.817261, -66.179146},
		{"b58f9dec55d32d326ce0828995e062f2", 95.557587, 1454.817261, -66.179146},
		{"dd2fd5de21588f8062dae21104f91126", -416.442413, 1198.817261, -66.179146},
		{"512826c0efe2ae6674c119a17b9380a3", -160.442413, 1710.817261, -66.179146},
		{"3aa699bd6b00a1c26c3c2dfff3fd88d3", 95.557587, 1198.817261, -66.179146},
		{"b1d174eb3ffdcc8cdfd856dc8c6c948e", -160.442413, 1454.817261, -66.179146},
		{"f5212ecd729be2e5c14462c7a45c6cc8", -53.088413, -1734.344971, -66.151123},
		{"6ffff19bb1a66391254d0d546b7b4006", -46.373837, -1742.689697, -66.151009},
		{"1f4bb8faba3d84d94a91c9d1986ed159", 14.577161, -1680.298584, -66.141586},
		{"6656ae79705e57c58988e14da5d1b196", -69.369026, -38.825489, -63.647858},
		{"3d92014ecbeaf785100cfaddec3b8eeb", 42.576946, -1684.615845, -61.954388},
		{"c67448ad9e0c5eb07f530fbb5f89e8c5", 312.194550, -500.405212, -55.575737},
		{"5ca5dfa71d28ce902265151604e191e6", -166.500031, 327.982086, -54.078831},
		{"dbe0d0e7ea813b62b5858f9c0e286941", 94.058266, -1632.119751, -53.621113},
		{"d80bbd0b51f1bb3ce07fb31a85ea2e99", 122.716362, 1236.315063, -52.592056},
		{"52fe8388f0e473bad02bfe3a55499bb3", 149.423599, -427.531921, -51.874912},
		{"017494d784efb1a6271647e8e44e6901", 1183.919312, 1037.673584, -50.874729},
		{"d6c1d1755832308cbdbabc231ee6d4fe", 927.919312, 1037.673584, -50.874729},
		{"cd72ef26e3f4cbf13f2372458a9dec86", -7.275587, -1592.717407, -50.637962},
		{"47c170235fc3b301f7ff602121604b64", -7.275587, -1336.717407, -50.637962},
		{"fdd2719ba534f7a4521d90b901bd4430", 740.782288, 965.957153, -47.856544},
		{"795cd362cf7fc31055bec4678bdd660b", 909.056580, 1078.046753, -47.856544},
		{"7f7925dbd7c88d471fe65d655b0dd251", 94.293739, -1171.918701, -47.203930},
		{"94a497964a26ce7e353e0b2588481836", 19.661240, 995.385376, -46.713989},
		{"3620b777d53a9eee4d21277da37b0181", 19.661240, 739.385376, -46.713989},
		{"53f94a311aa387feaaa1e5b7c509cf84", -236.338760, 995.385376, -46.713989},
		{"c29792dd487fdbc2e0b45603da08ed54", 275.661240, 739.385376, -46.713989},
		{"a9a7c745076bd0193e4c1ed0a85f157e", 275.661240, 995.385376, -46.713989},
		{"52e83facf549a5a4583414ed1061c3f0", -236.338760, 739.385376, -46.713989},
		{"8390f3567f50d121402b8ebc37bde8a1", 43.743031, 1049.213379, -46.667076},
		{"1b29b18b0ce62b17fc77353be1fd0000", -99.822365, 1088.910156, -46.666111},
		{"20b80bd9deec7ebd775c7b4f6d08e67b", 87.265984, 996.076111, -46.666107},
		{"880f815ec32d8dc9d46632f3567d7818", -99.822556, 1174.239014, -46.666019},
		{"f6cb770df89dee58aa71bb870a077e67", -186.370102, 276.534882, -39.078865},
		{"7b58b813bb98f8f9e854cd30d662e148", 89.976402, -1132.519043, -38.884289},
		{"70203f839d86b43f171a5ec816af229e", 157.426895, -1096.060913, -30.551046},
		{"b332271436e2fa3ff93ac4a56bf0124d", 185.650848, -1100.378052, -22.217628},
		{"e6f9857d5b49821a482d25f169e982e9", 213.597015, -1061.038452, -22.217628},
		{"0956b0645ddcbdc1dbf17976b04ae12a", 268.525421, 349.167725, -18.469519},
		{"96857eb6ecbc7c87b71f2e157844d266", -243.474579, 349.167725, -18.469519},
		{"470c20a83955f370cc8c58936ee616b0", 268.525421, 605.167725, -18.469519},
		{"74cb5197ac0f146bd281cb10f27012fb", 12.525421, 349.167725, -18.469519},
		{"49e38e8a522a6518ea82e791f9f6cb00", 12.525421, 605.167725, -18.469519},
		{"cd2fc5abec650a126c231ea1d9e364f1", -243.474579, 605.167725, -18.469519},
		{"8866126b49557de7504e6534ca209e5e", 731.602234, 752.320312, -14.520109},
		{"bd0e8b59100515413819370273beecf9", 203.701752, -954.843750, -9.661120},
		{"2b020dd28b6a53b239c0ea28cf3d5b80", 235.922329, 828.154358, -8.862866},
		{"b8beb85b614ff4a30fd895778eea01e0", 235.922329, 1084.154358, -8.862866},
		{"2b71d021c1077586daa816fc30f7aa6d", -20.077671, 828.154358, -8.862866},
		{"f2b31aeca225c77c940e8c0085ccb328", -20.077671, 1084.154358, -8.862866},
		{"6e94f8bb638d77f4f9d28e8720e1b3eb", -237.247482, 1159.189880, -8.862864},
		{"ccfe69eb18a151a4047d62a03a0ef6db", -237.247482, 903.189880, -8.862864},
		{"2fc958dcd0209c7d5af30795ce7469e3", -240.295715, -956.394409, -8.598323},
		{"aa42457433d5f9bdf0aa35cde14ad7a9", 15.704285, -956.394409, -8.598323},
		{"6e09797d1c35f5193d581c25443ab1d1", -88.653725, 298.014313, -7.009725},
		{"65ba48159e234359d9b0b8580833019f", -166.845581, 302.690918, -7.006760},
		{"8465cfe5981178f6747ed3c6dd6ec6ac", 56.681194, 301.896545, -7.006760},
		{"374e4d098265da88afb3fbdb78cb9046", 26.304102, 311.090302, -6.998082},
		{"78d6e86be0c5013dce455fd45a3e44ce", -119.030884, 311.887970, -6.984951},
		{"efa382ebcde2bbb30b8793d29a2bc162", -152.029083, -330.987915, -6.716691},
		{"cbaa312cc395f0b9d3d643720ff6810e", -435.554657, 16.542398, -5.537276},
		{"7d0afe0b8d15121882c3042ae1c15990", -416.175140, -689.847046, -5.508132},
		{"92882b1ccb17a592c8e5b70e6df1d30f", -442.281250, -641.397583, -5.508131},
		{"38d32dd7597a919a332d5b695f383a10", 176.965942, -908.640625, -5.503059},
		{"f49c21c4889ccdb3b55cf13c94fcfa02", 83.593445, -351.298737, -5.484356},
		{"a8c09dffe68157084bd54de99a50cd0c", 26.074097, -318.223419, -5.484332},
		{"075df96172d00a4e2943b68c23f72713", 488.993713, 15.786147, -5.453180},
		{"2ad58fc4d1221f607e09e37cb825d043", 502.853577, -26.629761, -5.453174},
		{"96776c1c8a6e683669408b4ff593534b", 502.090027, 130.729813, -5.453165},
		{"b04aefeecc206e8829b2b503acc52ac4", -422.192413, 131.017822, -5.453142},
		{"672b62bfdfa4814b3dc6eea541dbe86c", -423.038818, -27.667997, -5.453108},
		{"e8c6f053679afd5d3d3d15d6671b5d7d", 618.942322, 274.603973, -5.225938},
		{"e8c6f053679afd5d3d3d15d6671b5d7d", 857.046570, 274.602783, -5.225927},
		{"e8c6f053679afd5d3d3d15d6671b5d7d", 738.977112, 274.604279, -5.225925},
		{"5bd5eccba10a874ba4cc78ad8d3844f3", 493.348602, -71.925217, -5.174759},
		{"f97f11601c48b7e40efef7adc691570a", 493.348541, 166.543335, -5.174747},
		{"88cdc7b615821d825c9232eba0e63e69", 531.121094, 304.518463, -3.409013},
		{"55f76b9aff184fd0cfd74b0362051fab", 787.121094, 304.518463, -3.409013},
		{"b15f1dbc5664f94871cce0ef03bf596d", 787.121094, 560.518463, -3.409013},
		{"5ec18c31de4a7cf2e86c1efb877256cc", 531.121094, 560.518463, -3.409013},
		{"bbe7bbe71871cfc37f24102889ed5875", 1500.262451, 1016.751282, 54.315205},
		{"e3b5ca648da46a3a8ffedc488f204eef", 1244.262451, 1016.751282, 54.315205},
		{"11b2a65624d70d0fbd46372c25aeabba", 1244.262451, 760.751282, 54.315205},
		{"e37319d8da5b1296685c82d07687220a", 1756.262451, 760.751282, 54.315205},
		{"36222e993438109a4ae6f0ebe4ebf0d2", 1500.262451, 760.751282, 54.315205},
		{"c4505c2ecb8a7bc4dab21f7a0834c51b", 1756.262451, 1016.751282, 54.315205},
		{"35c5720d158afbf3ddd535261a32e9ee", 191.101486, 741.835022, 57.150043},
		{"1c9e59df4965c9f13563c2d0dd2099cb", -205.226639, 741.823120, 57.151440},
		{"311c8877fbc04e2425a76418be53ac55", 970.741882, 952.181763, 58.869492},
		{"faa1b35c2ca00d71665b313dc1b02e21", 1048.149780, 924.848755, 58.869511},
		{"e46819495d2976f4df6a0b799836cf17", -775.464600, 633.387238, 81.415237},
		{"ad6ef9fca02584337a412b4e6173e8cd", -775.464600, 889.387238, 81.415237},
		{"7c8c812436dccd6f95f7c8ccd075e0d6", -775.464600, 1145.387238, 81.415237},
		{"6cd314ac97704d0bf9b8b529ce123152", -775.464600, 377.387238, 81.415237},
		{"a0a692ecd7a148ceda02e36e2e0bdd6b", -519.464600, 633.387238, 81.415237},
		{"167888ec1630170a7ca2c56db7b8c32e", -519.464600, 889.387238, 81.415237},
		{"2e3c8dd2b51649ad2ced2986106ab45c", 248.535400, 377.387238, 81.415237},
		{"9789414c3c5e7599a8bd06a3ed20cdc6", 504.535400, 889.387238, 81.415237},
		{"cf5cd4532184c9d0e92d57297e6e78c9", 248.535400, 1145.387238, 81.415237},
		{"a3ab61969b284cd5afa0b96f7fba6631", 504.535400, 633.387238, 81.415237},
		{"546fbcd52a1ca79dd42b507ef4e3345f", 248.535400, 889.387238, 81.415237},
		{"9a6648312fcaf91b82d7b0800070b837", 248.535400, 633.387238, 81.415237},
		{"ee9394d10f9692962c7513f5766ca717", 1498.696808, 418.024872, 91.221680},
		{"8d27d74709d2a166aa1fe083f371341c", 1498.696808, 674.024872, 91.221680},
		{"eab82136051de92aa871020e2f15bf32", 986.696808, 162.024872, 91.221680},
		{"cd1a1db34e62288403e594d2cba5f6e1", 1498.696808, 1186.024872, 91.221680},
		{"379f79ba6699c8f1142cdb1b5b6b1f4c", 730.696808, -349.975128, 91.221680},
		{"c721b4cfe16f652ccf7f2754ffa66466", 730.696808, 674.024872, 91.221680},
		{"7a61dc6b626d94e0d888410a0a042126", 474.696808, 162.024872, 91.221680},
		{"35199d327b769de35c825ebb1dfd105f", 1754.696808, 930.024872, 91.221680},
	},
	["Gnomeregan"] = {
		{"9278015130cd008bb6c8bef3409b7b8c", 1232.025879, -1451.167236, -663.661377},
		{"e4136501ce145e70127f0ba80b5e7011", 1435.673950, -1363.357910, -661.621094},
		{"4ed59806333c08ca775acf29d8706a12", 1363.709839, -1459.900269, -661.621094},
		{"d7d2546076a2bbd945596e927cbf10d3", 1140.914124, -1256.321777, -654.741394},
		{"c40aeb17298544ea3eb3ec872c12358f", 1140.914124, -1512.321777, -654.741394},
		{"60fede6dae1d07f24eb75675a4e80b63", 884.914124, -1256.321777, -654.741394},
		{"0df0e0e1e00d12a1344658a52945a1e2", 884.914124, -1512.321777, -654.741394},
		{"940b3ffb7f164331894d1ea164dea225", 1449.918579, -1307.073486, -643.621155},
		{"4508b4a0bdcaca2af8765754dd8aa98e", 1445.894409, -1322.967163, -643.621155},
		{"1d076a1645e10a52266cf5dc89c8153f", 1541.209717, -837.892761, -642.671082},
		{"b44097170990e5d1b8036b4779a77a4e", 1720.162842, -846.577332, -632.959595},
		{"f9b70b4e3a98153b59358bc8f03dc843", 1637.536621, -908.716309, -632.959473},
		{"83f3e263d132a7e4a7424ac3a275bdba", 1460.142578, -1266.675537, -625.621094},
		{"e6f59077ae1d6f780d3b51d060b123f5", 1464.166870, -1250.785889, -625.621094},
		{"c0b00302e64add1b59aaa0304e80157b", 1616.554443, -1042.576904, -616.263550},
		{"83032cd676c85f158a9c779b5076071a", 1535.646606, -1125.459717, -607.930054},
		{"b7c1b59c5e4c67bf22815b751ceebaf2", 1442.597534, -1210.391479, -607.621216},
		{"ec1da740dc9703555b3a60e776f482e7", 1402.196533, -1138.122070, -607.621216},
		{"2a28119a56de110a4bef859a9ec3e67b", 1386.304810, -1127.899292, -589.621033},
		{"8a66179f9a8d7f25d7ee9e0fe3b76adc", 1345.918091, -1123.883911, -589.621033},
		{"0fad785d2b1937af846a2ae2dbfdd469", 1330.327026, -1113.641968, -571.621094},
		{"3a53a5ad3e07a65f5785b7f12f4fbea9", 940.704041, -1168.076294, -571.620972},
		{"c5882da9b6df6a04ae4da9324fcc5d0e", 1196.704041, -1168.076294, -571.620972},
		{"465b8b600df791fba069524ee1719d22", 940.704041, -912.076294, -571.620972},
		{"102cc947b5b7594c1930d3f028b6a446", 1196.704041, -912.076294, -571.620972},
		{"4230cb00618728204652772ea72d08ef", 1601.869995, -387.257111, -549.774048},
		{"7d7492495cd96ff613292e79dd21265b", 1441.920654, -514.494934, -549.382690},
		{"d77a87706bdbf2899d41b36fdc31136d", 1455.772827, -952.650085, -549.346863},
		{"0318b06c53de29e6889f6043cb6da3fb", 1199.772827, -952.650085, -549.346863},
		{"a5570e87123f844f72ad484a85e6ebf8", 1446.060791, -886.584167, -546.619629},
		{"91473f8c46985826d0f9d7c77c1aa96d", 1687.581909, -873.935608, -546.510925},
		{"31772ab167c75653490265f6bea32d14", 1506.083252, -787.394409, -546.307129},
		{"e4f334f63e4a7337cab6a8a074222af0", 1523.552490, -655.208557, -546.300171},
		{"1423f00c1253c8a134147fd2af588adc", 1492.426636, -563.353638, -546.215942},
		{"7316e82cdb8dfd0290b065e50bf75eae", 1258.555420, -777.095947, -546.178467},
		{"fe846d9e54d869dce3f16683db25e44d", 1501.317017, -878.241333, -545.957825},
		{"a7a5358bb1f06c1e0e3170cd06fa9988", 1501.317017, -622.241333, -545.957825},
		{"82bdda9f164f0228f130014ce2d3d1f3", 1757.317017, -878.241333, -545.957825},
		{"e71f09572976c8170921c51be984fb37", 1499.285278, -855.595825, -545.847168},
		{"e70f1e9206f2285958cfe428d674b1e4", 1793.320190, -691.574463, -545.847107},
		{"e9f231110b54ba3bf09db71ae26510e7", 1739.991577, -875.451355, -545.248169},
		{"343e33d5d33b21441d7d56b734584fae", 1724.376831, -639.168213, -545.248108},
		{"fae0efbed0a2ff7918736a661eb071e6", 1591.554810, -585.193726, -545.248047},
		{"5252f6bcc84eb8b5deb23ac42b7676ef", 1565.526123, -230.089417, -529.563904},
		{"da827ed643e5b17998e1edc26081a015", 1507.971924, -207.242386, -522.842224},
		{"16d2cd0de687ee9100d527dce8f27527", 1496.782593, -149.138107, -521.187683},
		{"8357ee7db91449b55261b33dec41741e", 1237.476440, -744.841675, -511.230560},
		{"c495fc74d9954a213043e8342885cc50", 1455.903687, -41.676605, -504.523590},
		{"6b4315d58298c5a601578e7f15a7e543", 1316.486084, -26.456142, -496.147552},
		{"31b98d9c09a3908f8941be3af3a87ed0", 1213.325317, -826.834595, -494.636169},
		{"ab15036b7fe9cddc7965910ee93bcfda", 879.385315, -975.685059, -466.135529},
		{"00ef814dea5184217d6cff2f22cc1c5e", 879.385315, -1231.685059, -466.135529},
		{"42d37b9e1277da76475a9856a7979d28", 1135.385315, -1231.685059, -466.135529},
		{"77bb79daf629ceee35bf6b9a89d85f4b", 1135.385315, -975.685059, -466.135529},
		{"e1bcaf01b755b5274a9904dd466cf2e6", 1031.397705, -789.270691, -463.464081},
		{"b76836dc18b331bcdf3f9f1cdeaa66f4", 1056.586670, -705.079895, -462.550171},
		{"1f7cad503490e39017eebcf2d91852f3", 1268.759155, -875.863770, -461.313965},
		{"983416ffc40fdfc643dbd781f36c5296", 707.226013, -393.018311, -434.857574},
		{"1387d048ad5f9fef7992acecb13ec57f", 963.226013, -137.018311, -434.857574},
		{"23d1ab99d3c12311f815169c0e709a69", 963.226013, -393.018311, -434.857574},
		{"246bb69bc1a9bb774f231695f63b6374", 707.226013, -137.018311, -434.857574},
		{"36ea2e67b02210ccad87f972cc127bb4", 1046.430298, -616.290527, -434.056305},
		{"e0cd29c9a2175d51b69446e90c9e3a78", 936.956177, -591.153076, -423.417023},
		{"764f9465392c9cd63121c5a163430a45", 857.738220, -591.148926, -423.169586},
		{"11358614fb0ae813ca61764d35ecb5be", 1025.032349, -597.034973, -423.169495},
		{"c283387629004c8b11cf0c8c472933a1", 826.810547, -555.285339, -423.169464},
		{"b96aed56fa8e05a59b38e673fc6ce9e3", 826.810547, -473.629120, -423.169464},
		{"c1e3ccbba54422f3250e11f0813d20a4", 1048.243896, -327.960327, -409.821228},
		{"36b284b26d11ec0c75ff610fd755523d", 1048.243896, -71.960327, -409.821228},
		{"c9a14b1f907730938556663d24e92553", 1084.536011, -333.716095, -407.564758},
		{"e438a8876cae58c238b4ef7aa0a22d84", 1120.244751, -122.913689, -401.482330},
		{"50eeb8c1f5de98170a34ed06e0498847", 1062.071899, -122.913673, -401.033203},
		{"6c5105d2a1392092df68dad248f633ff", 1189.838135, -335.793213, -399.381104},
		{"313b9d204f6eed07ee87d6709f30ea0f", 1189.838135, -250.674942, -399.367065},
		{"a8882d0bcecff6447092efe800036e29", 1189.838135, -168.736221, -399.367035},
		{"dd8e4241b991594e188d96ef9aa373a5", 960.021729, -481.528137, -389.784210},
		{"702e0befe92af6d97ed43dc75be45508", 1134.342773, -466.197296, -369.439362},
		{"d470c6cdb446943675614ee8018eefc4", 1224.952637, -312.396057, -367.899200},
		{"b8a6370a676e84067a54e95334b53dc1", 1224.952759, -199.907959, -366.609039},
		{"428cb1e2f0cb61e8085c6bab4a7b62aa", 1076.874390, -79.770630, -359.541260},
		{"fcbffeb04ee1b7a128969fc5e66d1875", 1151.517456, -79.770622, -359.428070},
		{"f9ddd1a42ef877a833c52c3922e7d8fc", 713.341248, -125.050934, -351.230896},
		{"3b76ec6d52095d93b769a3112861847d", 969.341248, -381.050934, -351.230896},
		{"421ad6929ccc03e94440778dacf6f2e2", 713.341248, -381.050934, -351.230896},
		{"76f6968a5093d8857001ecb07fb548a3", 969.341248, -125.050934, -351.230896},
		{"1c9abb81f1fe77e1208f9d86e75cc7f5", 646.176697, -124.250244, -325.048431},
		{"f2e8c36c102aef51ece0757996cea874", 1068.764648, -487.364624, -318.912476},
		{"f084f7916e2501b6720ffd5452f72fc8", 937.444153, 95.380089, -318.128448},
		{"aa7885b390f80af5f1716eadbd6b8cb7", 401.776672, -30.789429, -317.559143},
		{"6508ec1b74e9f18a1db5cd1e43896274", 401.776672, -286.789429, -317.559143},
		{"64918e02e1685d91ac49ce6d5ac69e80", 1029.736084, -71.625153, -315.094452},
		{"f38b3dc8ab84394de12cb4ba457604e7", 967.790588, -133.747406, -314.666229},
		{"ec1d00b5e7b6ced6984b203cffd4e805", 980.366028, -399.291565, -310.528259},
	},
	["Gruul's Lair"] = {
		{"70aa837972ddc3f603876c603aff879e", -77.104134, -123.808647, -36.234055},
		{"abc2c4063bdb10f4561dd9ae29e1ad33", -77.104134, 132.191353, -36.234055},
		{"f63f49fdecf2f89741549acbf2ad7a9e", -127.046112, -522.198914, -30.760159},
		{"5ce77be3a00926c0aed31999aa607d71", -127.046112, -266.198914, -30.760159},
		{"e8ace49f762964e3965cb3e703a81114", -383.046112, -522.198914, -30.760159},
		{"a0cf629e6194a4453838086b6138d4f7", -383.046112, -266.198914, -30.760159},
		{"744af25fd353dee0ee525c83a9b60198", -196.266953, -239.122696, -19.389427},
		{"a70011befba2d009405a6eaee6225f0b", 59.733047, -239.122696, -19.389427},
		{"042cb1e1610c35016d53781813d95be4", -196.266953, 16.877304, -19.389427},
		{"0c2065a32604066d9a50e31d527cc1ff", -313.036682, -779.408936, -6.597600},
		{"67c601a9595cd0dcddada6c575b7fccf", -313.036682, -523.408936, -6.597600},
	},
	["Hellfire Ramparts"] = {
		{"34f43f50938b4781ddc90b8e76fd2326", 7168.000000, -8704.000000},
		{"9169ae4df4f43737723242a3981874fe", 7424.000000, -8704.000000},
	},
	["The Blood Furnace"] = {
		{"5de218a3d0f2866a75c78f50c1a71dda", -513.149414, 97.045982, -282.213898},
		{"5781b553e9b260069040627e2e6fbdc4", -626.168884, 167.122627, -278.437897},
		{"466ad6729e861d87397ec2ff09d7a17b", -882.168884, 167.122627, -278.437897},
		{"d52640f5ad0b071f6e108ed203add7af", -626.168884, -88.877373, -278.437897},
		{"796546a69f19eab4728f7d8920399f67", -882.168884, -88.877373, -278.437897},
		{"8fb786e4c08b7a1ace2ccfbd46830715", -882.168884, 423.122627, -278.437897},
		{"2fa45de4485b0ac938cddb58c84f7981", -1106.271606, 114.557320, -143.044037},
		{"738c187ff3304579fb62da2c7c72a7e8", -478.704681, 224.850296, -118.051216},
		{"a40e2022767ca68363cbf35738cfef91", -222.704681, 224.850296, -118.051216},
		{"ae0f936633d5c05db265b0ead8255943", -382.874847, -48.861145, -89.762627},
		{"b4ee31d3fd5a41687041937a0617f86b", -382.874847, 207.138855, -89.762627},
		{"2ae200ade417820cb4022373ca11bb87", -126.874847, -48.861145, -89.762627},
		{"6d2cf0817c91a46196809ccadfdbdfc9", -126.874847, 207.138855, -89.762627},
		{"ee4966266c5a8908b16a518d758d5193", -905.057190, -81.545135, -66.262138},
		{"cbcd72b149360812d270ce5c95051569", -393.057190, -81.545135, -66.262138},
		{"4786343a3ec3c5ef6d40df182c1972ed", -393.057190, 174.454865, -66.262138},
		{"61e1a497f3d7aaa2d1436eeb336675c1", -905.057190, 174.454865, -66.262138},
		{"18529806e1800081a1b892cea579f10a", -649.057190, -81.545135, -66.262138},
		{"50f75b79d1588a08e557b2c7cba41544", -649.057190, 174.454865, -66.262138},
		{"b6c78c2fc7b0dc9b9663f601e0d49c36", -1023.845581, -301.778625, 7.115775},
		{"4ac0d258b4165116af2ae9b15a561955", -766.401245, -324.939178, 7.115887},
		{"a6f111e8c580bfa79657a9696ab85dbf", -1040.629517, 190.321739, 18.208412},
		{"abc4540bfdf89fcef06ec7e08ac50f49", -1040.629517, -65.678261, 18.208412},
		{"972cd92849d0095ccfe622abebb5b081", -741.287231, -426.720459, 18.962790},
		{"31befacec677db25e5c1eaca0b5d7e0d", -997.287231, -426.720459, 18.962790},
	},
	["Karazhan"] = {
		{"cc540319429740ee23cd6ad958ef56b5", -425.074890, -289.824066, -6.707768},
		{"9423800f4c29147ccaeb652a0f36b094", -169.074890, -33.824066, -6.707768},
		{"24a766ec18ca40113c0b80fb0261c133", -169.074890, -289.824066, -6.707768},
		{"36000e1e2547610167bd53d9db752ab1", 53.185616, -56.809116, -1.935851},
		{"1b8a3c64afe4f31f866820865131c758", -134.406174, -440.428009, 1.480373},
		{"83c31f5b24dd3273530c2a8ddf856939", -39.677197, -44.532249, 1.843560},
		{"a460605f654e1749d7a69a017d5cc896", -20.482077, 76.944778, 2.351917},
		{"e90b51e3f2910e81528c9e1344f2343b", -96.041389, -102.530411, 10.026437},
		{"af86f0b6b7d065de109c6318fd95dfcc", -56.852966, -277.129822, 36.325077},
		{"0b70308862a7923e9dc4ee54accc9a15", -312.852966, -277.129822, 36.325077},
		{"ed1bd5aa1ef546e01341eed12069b221", -312.852966, -21.129822, 36.325077},
		{"e272e99ae30d9cc793b0454559349ed2", -28.423174, 8.026168, 52.150311},
		{"30a1814da95527715c4b2586eee9b803", -123.907310, -115.122139, 55.242973},
		{"e6fe884ad5d3511b81f6071c68756576", 62.126877, -334.899506, 57.185654},
		{"707a62447bc8235bd2d5cc2534c02cbc", -193.873123, -334.899506, 57.185654},
		{"50815b136409b71c15b73995c50c6a70", -115.562248, -588.708191, 59.435627},
		{"677467d12b31b9b8931fda551b324691", 140.437752, -588.708191, 59.435627},
		{"4d0a27610ebb88bb0bb06ef68d36b2aa", -115.562248, -332.708191, 59.435627},
		{"6b3202b45af47b1e88e0674ff3f31ab8", 117.947060, -554.390869, 59.435635},
		{"21184f6e23419064df98070360bd9168", -209.988373, -405.561646, 59.692524},
		{"4256eb3e440588e08977c569c29d50b5", 11.424644, -676.174805, 81.562592},
		{"188c6c2964f57b07b57abc48eb92f4bc", 103.770836, -625.720886, 83.582787},
		{"7038ea7b50618683cd789d45bb1a8bc8", 109.768257, -480.305176, 83.602486},
		{"3224df15fb2e9135afd6569573209821", -495.636658, -197.477402, 83.640892},
		{"bab39e48ccd5f068dd5c7a1018fd55fb", -411.541687, -306.773712, 84.499229},
		{"270cc0781ed356fd5f1a900f62ef220c", -2.983750, -5.192108, 85.523514},
		{"5ce7fa9d47502159142506fafecbdba2", 80.962662, -39.635071, 85.532524},
		{"af5231f0e1e8c8b0d23f4efd09bcc7af", 49.688583, -45.715061, 85.587517},
		{"2db557609939e4f4bce524aa6b59ce6c", -119.366104, -358.763489, 86.938698},
		{"2e9e90f7882646e21ae11c2b7467a2f2", -370.303680, -406.084076, 86.968750},
		{"c54c45138e27b10e4ddb0428874a7a0a", -365.104553, -331.946869, 86.978020},
		{"2926ab54c9afc9b4974a97118b6fe941", -446.510956, -105.186737, 86.987572},
		{"6a689f8d92db4a94e85c9978bdbde0e3", -217.041794, -286.365906, 86.993080},
		{"2be222977f027171e989a6983e07995c", -53.768497, -72.138237, 89.247925},
		{"27e9ddd048dcd298ea25546b92cf97ad", -101.177910, -33.495884, 89.263618},
		{"9ce2a5ba43bc74bc9a1166ebe01b67eb", -122.049728, -35.539280, 89.475067},
		{"53c7568f2f7294c8e54c885eabdccff8", -105.305046, -123.171257, 116.188126},
		{"4030a099459bcc8f1b63d808e339639c", -79.617165, -219.781967, 130.153351},
		{"b7e6c4f21bbbd434bacdfedc54ef50fd", -26.661850, -301.192291, 151.768127},
		{"eccb31774ba92bc72f7e35ae55b53e9f", -70.101311, -72.707588, 151.780548},
		{"4cff3b2cfd013b502f502bdbdb65992b", 553.619247, 154.211639, 173.802307},
		{"94b59837218fecd8e4e3062ea3fc6f0d", 553.619247, -101.788361, 173.802307},
		{"55cbcc1f285866aa7aaa836851eb6d3d", 41.619247, 410.211639, 173.802307},
		{"63f867a4ef0c4a0673b730a291af414d", 553.619247, 410.211639, 173.802307},
		{"c71d56698f1317dc0e36747d52659f88", 297.619247, -357.788361, 173.802307},
		{"db06401c96b9f1b1dae15a74e876b34a", 297.619247, 410.211639, 173.802307},
		{"54125ba177e24cd73f79ae3a3a4858ca", 553.619247, -357.788361, 173.802307},
		{"12b21caa68e460e3b967aabe10557923", 297.619247, 154.211639, 173.802307},
		{"feb47e1dbf2859e508c55e021a024546", 809.619247, -357.788361, 173.802307},
		{"992506cad9e3312a3850c87244d36f9b", 809.619247, 154.211639, 173.802307},
		{"c6ef9a5e86e2777ba237c059b3b72141", 41.619247, -357.788361, 173.802307},
		{"1ed0bfdfb8388ba6ccdf27b697ff0078", 809.619247, -101.788361, 173.802307},
		{"7da775093a016c5694eedd388271487e", 41.619247, -101.788361, 173.802307},
		{"6e7b811b5f1702bfb34d52bbbed1a6f7", 809.619247, 410.211639, 173.802307},
		{"d3902a685dc52b3079d32714f68b818c", 41.619247, 154.211639, 173.802307},
		{"66322a97a2a97784767e8892ab03b7aa", 297.619247, -101.788361, 173.802307},
		{"ebb46e0e49e4756a17ab688a18a2b934", 162.946640, -23.053511, 214.783890},
		{"196a2dbca650e4b881f4bd049b909639", -34.359341, -128.668503, 224.320175},
		{"d1cd2292024b3819126e3ba2786a203b", -23.281164, -269.367737, 225.349182},
		{"7ed444449adc466e5e33361e4b3fa3e1", 131.677490, -242.385941, 231.133484},
		{"5aed907f30dc0ec34a21700657fdd501", 582.041687, -137.147217, 261.123138},
		{"a1556876c1163a6e9d3f039befc44f65", 452.295959, -180.796997, 261.188019},
		{"714a87a618349c3917ffbaef4a24ae34", 398.405884, -175.586929, 304.949249},
		{"6abe18288d11f28a9ff0fa720082cb5f", 579.443604, -122.237267, 324.408081},
		{"4126196e74f41056a9fed7f6ae4d565a", 56.076084, -170.951904, 343.983704},
		{"63cbdb696adcae16250c2139795f6678", 378.294983, 46.302944, 350.484741},
		{"76a1e16fb4c665eece07857a78cd6c2a", -40.114498, -48.349644, 363.429077},
		{"5e266538dd8eeedafe01bca41daac42d", 144.797867, 17.342758, 366.550262},
		{"a4b6e356dda4f8f5a8099a4a655bdbb6", -8.509508, -211.377365, 367.163483},
		{"12db568461deb26be0ab03f7d7cbe725", -36.956257, -137.516327, 367.163483},
		{"c40597d4af3d8266c8791767750fdef6", 575.331604, -145.914398, 384.523926},
		{"69c22404c40381fb0e8ee2937ba80517", 76.288544, -233.247131, 392.416260},
		{"9483f99e45ed53d0addf430dd91135da", 71.078827, -158.477219, 392.416290},
		{"3c8a9572725f8de41951b660af281870", -58.338314, -181.010056, 396.935913},
		{"a98be5a37d4e28302d9d0b9f8092ff53", -51.085361, -64.763512, 399.031616},
		{"72df333b69dd3c288d4e73454efc6cc9", -15.788733, -63.654636, 432.045135},
		{"af2cce081088b9b52bf00245bb31fe89", -29.728580, -75.383011, 448.074280},
		{"d56d4c45a3d2a4e1f385a54c4f55fffd", -58.562393, -93.576019, 452.466064},
		{"8af3b29e669151aff628da1d709ae4ad", -50.888721, -95.917313, 452.466064},
		{"baf34b513909489fee09f64a1c869c30", -15.847957, -79.464531, 452.466064},
		{"d7311f5355db6efd0ad1ccbea0ffc275", -23.760088, -93.893257, 452.466095},
		{"73a856f159087b80c844232a2acf636a", -69.246521, -88.593758, 452.466095},
		{"7833fdf2eba10cc9c7f1a95a91b3f09f", -38.068699, -98.684135, 452.466095},
		{"2e8240525ad53087a049cc4cdf2cf273", -18.365925, -86.614822, 452.466095},
		{"fa685ded01c36b44754f81d96ad3551d", 743.482971, -518.045532, 455.379913},
		{"fc9c7010880dcdd52fd147901df412f5", 487.482971, -262.045532, 455.379913},
		{"cd2059759116e6598ecbc03b8eff30ba", 487.482971, -518.045532, 455.379913},
		{"0b4ed5219eeb21d30d563c5e6b6545da", 743.482971, -262.045532, 455.379913},
		{"a3fbb961703984764e536df66bd7d64f", 617.287476, -192.860199, 459.126160},
	},
	["Magtheridon's Lair"] = {
		{"18908b33e0f5b1ba1143218c8e13dff7", 140.071968, -183.752014, -1.137301},
		{"74b15bb5968d84a789002304c040d302", -115.928032, 72.247986, -1.137301},
		{"4613db1fd966b8f5107ee1d84a64ca70", -115.928032, -183.752014, -1.137301},
		{"51270f6ed5d5c222bd4545f3c0bc7a22", 34.797302, -158.006973, -0.881529},
		{"b5f26d55eb5f883480f199420aa9d27e", 132.619812, -56.291382, -0.881524},
		{"48eb5d2f88bc7df1d926cddc0fb66838", 34.797295, 39.365406, -0.881407},
		{"3faf69755654d367b4f7ca11e8ecc52b", -266.869171, -44.497059, 90.055321},
		{"f3cbeaca912b292b232afcc99ae8ff36", -473.627441, -234.264328, 134.897507},
		{"03f252b182b401fcac57b59896f1210c", -473.627441, 21.735672, 134.897507},
		{"537b077f743c18274ae56a03f74b5e10", -134.595993, 77.239395, 143.565048},
		{"e811d7dbc235bccf1cc8e48036bce485", -134.595993, -178.760605, 143.565048},
		{"e03b57d87c253ef4f39aa62ceb79892c", 121.404007, -178.760605, 143.565048},
	},
	["Mana-Tombs"] = {
		{"c88c19d925a8bd9fdeb4172e1170beea", 357.096466, 543.583038, -9.825274},
		{"0d20c1516b12b5e6cb1b42d1d5376b20", 613.096466, 287.583038, -9.825274},
		{"0dd2ffd18484f0c21b82f781e84ee00e", 613.096466, 543.583038, -9.825274},
		{"72019f9781f541bbfaedc3d4d9596a3a", 357.096466, 287.583038, -9.825274},
		{"1f0c489c2898fe6e4bcdfaccafc4fa49", 171.057640, 340.870361, -9.364659},
		{"b30925f2338f84a96d38e0598664e94d", -84.942360, 340.870361, -9.364659},
		{"5e973a25b8a5b316765739c9fdc3f740", 15.512451, 52.317009, -5.354987},
		{"76d18c9d39e5b36245516301e3ab4f03", -160.141663, -103.652519, -3.753315},
		{"c8bb0a5368d2416e11b046cac6a428f1", 95.858337, -103.652519, -3.753315},
		{"7db56aa9808cbca217489c024c711371", 634.831970, 257.285370, -2.459637},
		{"664d1ee8c1833bfc3265ecd864b661be", 634.832336, 76.027962, -2.459637},
		{"cc581f6eeaab32efad6e47240e38bd6f", 112.471115, 292.965088, -1.997681},
		{"6058b0e028213448fee66d2087a88227", 666.711731, 398.670258, -1.975323},
		{"b49ca6955fce854af51164923387ba13", 671.814697, -41.015881, -1.974322},
		{"91348011c21b48cb2d5fa24d9ab9c3ba", 723.309692, 217.412918, -1.973213},
		{"ebb81c1286c8c51367efb9066b3cb448", 312.542633, 423.920227, -1.965983},
		{"6d23dba19b58ca66a3b9b3cdf8f0553b", 572.832794, -120.011650, 28.734859},
		{"5a2ef5f163017e8d7f6f317ac38b01c7", 316.832794, -120.011650, 28.734859},
		{"8a115dfbd3d609bff4040265c84cc968", 175.637634, -41.030453, 33.518475},
		{"1ecdebe1b8e32513f7871d4b47e05009", 520.514404, -105.881012, 142.968979},
	},
	["Maraudon"] = {
		{"d7ea04d9789e27bb04b9b57daebdde51", -301.452240, -319.512146, -417.911499},
		{"2b6414afec08dfd4b3430329e9ded51b", -301.452240, -63.512146, -417.911499},
		{"a592d85f6735e841786688257641533b", -45.452240, 192.487854, -417.911499},
		{"8a56651495dced5cab78efc5ec313a55", -45.452240, 448.487854, -417.911499},
		{"d4a599d6bcf835d1ba276f4ad9b85210", -45.452240, -319.512146, -417.911499},
		{"101461e2c2a16b1292ad5fa1af29f4de", -301.452240, 192.487854, -417.911499},
		{"8930bb50eb8fbd3aa3612634eb4b0417", -301.452240, 448.487854, -417.911499},
		{"794de91b1e4b34edd9e40c1c21007493", -45.452240, 704.487854, -417.911499},
		{"2de6ff3253f27a30eec986af5fd6af9b", -45.452240, -63.512146, -417.911499},
		{"97fa6b32b1d256f27048208a22352f5f", -33.875824, 887.181335, -416.320038},
		{"d8fdd682b10dd2e7a10cc62b8e2357fe", 222.124176, 631.181335, -416.320038},
		{"7844960cb45837c58572c5bd606192ca", -33.875824, 631.181335, -416.320038},
		{"72edae48a6f9a85681f63ffcea513336", -450.528748, 598.552673, -351.034393},
		{"c25b87d41c16c9a1590a25bd1ac552db", -706.528748, 598.552673, -351.034393},
		{"48fcb7df4b2ca29e88e754701fd4f3cf", -394.621613, 579.874268, -349.259338},
		{"5672a4614ac014720fe78ab46cf1adf3", -359.592224, 337.996979, -344.496368},
		{"35a5cae75748d98be0f533386155810f", -394.621613, 433.258606, -343.786652},
		{"5f32715ac5dbec0e1b509ec6e132c2e7", 133.215515, 466.202911, -340.900848},
		{"461edecb8b2157e16403b91f7f15f685", -275.202179, 302.437286, -339.754517},
		{"afb4bacab733b79d5a2201a739d7d5da", -800.788696, -249.777832, -300.191010},
		{"5b5d7f19fea2835011dff21f595df1ef", -1056.788696, 6.222168, -300.191010},
		{"9a60e38fffcfa0f780fc9a1aa5af0641", -1056.788696, -249.777832, -300.191010},
		{"96409fa63ba20d78b5bbf1f56fb6df39", -544.788696, -249.777832, -300.191010},
		{"3827c9098155463fafbd89214cc946b8", -544.788696, 6.222168, -300.191010},
		{"2fffd12a1f45335fc8a161c36bc49245", -800.788696, 6.222168, -300.191010},
		{"684719c460b38307e202f459867b9598", -830.426392, -586.719543, -263.580200},
		{"184f026f7a6cba93d4728cf70cbfd41a", -830.426392, -330.719543, -263.580200},
		{"b231585f8a512e515772d6c75b17e06a", -712.984680, -351.802765, -263.580200},
		{"641e5eafc6f4dfcb3cb268c1f56718e7", -1086.426392, -330.719543, -263.580200},
		{"c01de8d4843b961461da743cd78eb961", -1086.426392, -586.719543, -263.580200},
		{"87b89eb5ea485818764983e07638d461", -661.636597, -249.712753, -263.580200},
		{"67429aa70b62525e340cc201d85d5872", -489.064087, 436.759872, -263.522705},
		{"351b344a17aeed60ae16022fd6abd6da", -745.064087, 436.759872, -263.522705},
		{"b63cfe3a8a13cca3497a77bcce5da5f4", -745.064087, 180.759872, -263.522705},
		{"4c96f473073773f019585ef36d8bd349", -489.064087, 180.759872, -263.522705},
		{"0def2e1621e2983e77a9328a5dccef65", -480.379333, 129.635864, -259.298584},
		{"4e78c00d489db6f616f9a49417c8f3ed", -544.688904, 159.497253, -259.298553},
		{"625f4675948b1d0d5cd9a82f4e1b4274", -718.129883, 493.728088, -240.179779},
		{"d31b09a9027913e9e4f4cca898fd3a92", -350.343842, 407.341339, -217.761017},
		{"e77325b858a850bc22b07cab1d81f8bb", -1065.148926, -294.733368, -192.681259},
		{"b244a49d06742c5d8ea1cfbd7536b812", -1321.148926, -38.733368, -192.681259},
		{"6dcb801c0641c6cccaebd83fe5cc5311", -1321.148926, -294.733368, -192.681259},
		{"ec7ca73a2d8d85273a5fa2bd8378c1de", -1065.148926, -38.733368, -192.681259},
		{"f3bc89a8a6d7c7d5339492bb411bd72e", -1066.076172, -313.301544, -188.503601},
		{"9ab41915740e97f7e874ca2248e9201b", -1066.076172, -411.533112, -188.154160},
		{"af257fac261f0891efb91865738bd2b2", -1716.587646, -9.161346, -178.363663},
		{"d60716f4cdf08d28678c04bd67025a3b", -1716.587646, -265.161346, -178.363663},
		{"4ff8f0e5d0df48b98fbba4dc628f1048", -1460.587646, -265.161346, -178.363663},
		{"ed100ea1d8040876239918d27b3343bf", -1877.262329, 2.073998, -177.811142},
		{"e81dcb1322bb1b923de135f9bece6c24", -1877.262329, 258.073998, -177.811142},
		{"078cb5173ac90623a839074d50974166", -1877.262329, 514.073998, -177.811142},
		{"291e6f59cc4b4d46b3792c7c743c6d55", -1621.262329, 2.073998, -177.811142},
		{"b88acba8ad237e232b37addd9ea3bc98", -1621.262329, 514.073998, -177.811142},
		{"6d93e71f23e101c832bfef7384fe1c05", -1621.262329, 258.073998, -177.811142},
		{"26de0c4d62c2244c8c89d167b7d0b7a8", -2337.741455, 338.599182, -160.888870},
		{"177700ffed2e41990bada54413daba7e", -2081.741455, 338.599182, -160.888870},
		{"0ea0b10e88f19c822e10335d6f9dfe5e", -2337.741455, 594.599182, -160.888870},
		{"8b05deb6f2412a5230ad1d9bd56ab591", -2156.516357, 562.720825, -146.520798},
		{"075b1596ae0fa501c4ff9af4b8c73bfd", -2040.099121, 599.984070, -144.533035},
		{"9ed689a8cb6368f1231ee47ae3952898", -1961.911011, 165.831070, -136.334457},
		{"3240f2508da18018420d1e6eb9502033", -1251.654419, 267.947784, -130.132965},
		{"82c306868404a5bc5576f2c0015710f2", -1507.654419, 267.947784, -130.132965},
		{"39cc350df46ff608a96189b5a5feb17d", -1507.654419, 523.947784, -130.132965},
		{"6a4a01bb27b07c3459412fd869eaa4d3", -1251.654419, 523.947784, -130.132965},
		{"5515d6aac833d6782bb46e1be11fb935", -1800.442017, 882.587646, -128.905060},
		{"c8f1c7eb9aace5387e7efd3dc009ff7a", -1800.442017, 626.587646, -128.905060},
		{"45fdcf602df8ee4306a9a63dd1d6b42c", -1544.442017, 626.587646, -128.905060},
		{"3b788020209d643f2cc1bfcc8bc3ee2a", -1755.622437, -19.032095, -126.775383},
		{"4bd6ccbaa5776d77affdaa6fd50fd816", -2011.622437, -19.032095, -126.775383},
		{"5c367e679c13a32c528e532c5601ba7b", -1403.702637, 147.908096, -115.448463},
		{"a9bacc81bbbd6df5d192b3d9fd323eea", -1737.142822, 838.243530, -113.050255},
		{"d94557a2bfd95eea0102ac7f5bb22b8e", -1759.353149, 1510.752075, -112.776131},
		{"e70eac51b99aaabdb866427709a7cc8c", -1759.353149, 1254.752075, -112.776131},
		{"932a0280858db3dcd54a905ab8eda337", -1503.353149, 1510.752075, -112.776131},
		{"883c6a53286c8c543fe0b80c84c23181", -1503.353149, 1254.752075, -112.776131},
		{"3381b99aa3548684a7fe298a794d41b3", -1653.846313, 824.255310, -111.247520},
		{"a643461a048ad2ebecebbc7d8b1ceb5d", -1653.846313, 1080.255310, -111.247520},
		{"f78ecc565dbe4df4a1699df33915bb5f", -1397.846313, 824.255310, -111.247520},
		{"6f7eae1de797b5d665cee7026fe9add6", -1774.086548, 407.502991, -109.112732},
		{"e5bb908030a7ab307bb1099e5026ac56", -2030.086548, 407.502991, -109.112732},
		{"2500d2217f350c21d3b993ec6dda7ef4", -2030.086548, 663.502991, -109.112732},
		{"7f1c0f68bc5ddfd9f3602b3f895e7ac5", -1813.273193, 788.295410, -106.779778},
		{"1729488e84de43c2f6a069d33f9a8dd8", -1220.807251, 587.457275, -105.993050},
		{"88755726e7b921673a4d0fa77ab52654", -1476.807251, 587.457275, -105.993050},
		{"67b2c3db2960b9de6223e44755af974d", -2016.756714, 852.746155, -102.634148},
		{"1dd4dabfba34c556a2ba982aa4ff29d7", -2192.273682, 832.495117, -87.861305},
		{"c7cfc1f19f8ee0e60762ab576a3f08bf", -2054.044922, 669.976562, -86.981964},
		{"218daba1035c23fdf76da6e0675880c1", -2123.980713, 621.112366, -82.376213},
		{"b458fdf03461487d9ddde5256bbbd908", -2189.111572, 715.188416, -75.170776},
		{"2ab249b4f6357048bcacf23379c219fe", -1646.207520, 1167.098022, -66.562881},
		{"77489de0a16abb9e1360f9997c8e0bcf", -1646.207520, 1096.958740, -66.492622},
	},
	["Molten Core"] = {
		{"7e27b740de13c7c65d325633bbf76697", -1637.307251, 1600.457886, -467.044464},
		{"d71e9484f2b8e185e07f87d258ca8ff7", -1893.307251, 1856.457886, -467.044464},
		{"7c6e0c7b9ba93c353a0587776271c25b", -1893.307251, 1344.457886, -467.044464},
		{"a871a50208d3edbbc3312d1907137fe4", -1637.307251, 1344.457886, -467.044464},
		{"e718ecb0aae477cd7772291028ae279f", -1893.307251, 1600.457886, -467.044464},
		{"896c22dfe59c837f59a8a773de998924", -1637.307251, 1856.457886, -467.044464},
		{"b0e03ac1d0cd2a66b280b021838a1505", -1962.171875, 1228.719116, -461.781281},
		{"c9dbc73b5ca548f0041d24d416dfc03d", -1962.171875, 972.719116, -461.781281},
		{"dbef6d4886edd125a23642b5379328bf", -1706.171875, 1228.719116, -461.781281},
		{"f25bbacfd2b19f2897b860acaf17c4cf", -1962.171875, 1484.719116, -461.781281},
		{"8125c328035d6f39b3cd6c176f1270b0", -1706.171875, 972.719116, -461.781281},
		{"4b3568f2fc03d87f73ac61c8b32853db", -2218.171875, 1484.719116, -461.781281},
		{"8ab3fabf7256b4f7801db319046e25c2", -2474.171875, 1484.719116, -461.781281},
		{"3cc37fed3793052cc6e9164191c43ed7", -2218.171875, 972.719116, -461.781281},
		{"d667d43b0958f6f39c40edee82cb6198", -2218.171875, 1228.719116, -461.781281},
		{"06cc07f31679f5ef9f06c4b9923c3bf0", -2474.171875, 1228.719116, -461.781281},
		{"c0c7694eac7c8f07df8d0d04ced96da7", -2474.171875, 972.719116, -461.781281},
		{"8b02b2e54bdb49f912818cbbf74180bd", -1841.406738, 2304.329956, -450.690857},
		{"a6684031c4289594be80f8c3a4bb758b", -1585.406738, 1792.329956, -450.690857},
		{"3c742b7d2848a1f9f1fcfa2a36bd0ae9", -1841.406738, 1792.329956, -450.690857},
		{"d808130bfab47b1be915f933bf3c9e5f", -1585.406738, 2048.329956, -450.690857},
		{"cf2074aca45ec763d03b6da18f9dbcb3", -1329.406738, 1792.329956, -450.690857},
		{"1ba32da0bd98242b95882b630e65614e", -1585.406738, 2304.329956, -450.690857},
		{"f5e3a8e3e16f30289e6ac15ad06a7a83", -1073.406738, 2048.329956, -450.690857},
		{"ea923dee22d3cffbae61c2c3af34680f", -1841.406738, 2048.329956, -450.690857},
		{"35b6f9691bc0de0bd762f3949151a682", -1329.406738, 2304.329956, -450.690857},
		{"9310e720dae4ec7963465e55aa31969e", -1329.406738, 2048.329956, -450.690857},
		{"d83479a881e54856223f7e4aac457487", -1480.621216, 1717.969604, -438.351227},
		{"71c588a1ee4adfc467a5290f961e2737", -1480.621216, 1205.969604, -438.351227},
		{"4d9b0867c9a6df0de2dd87995ef72621", -1224.621216, 1205.969604, -438.351227},
		{"fec77fbed23793782e01a80195ceea28", -1224.621216, 1717.969604, -438.351227},
		{"13d7208d0f2b3bda2093d0b82695e214", -1224.621216, 1461.969604, -438.351227},
		{"7d3c3d2593cd1523968da8d732efe05f", -1480.621216, 1461.969604, -438.351227},
		{"77b178e054bb3de7807b9d084750efc0", -1360.291016, 912.413635, -436.323090},
		{"75b698850c556b0c683e55aab348cec3", -1616.291016, 1168.413635, -436.323090},
		{"c1dc8a2e0ccbda240abdcc6e5da25360", -1616.291016, 912.413635, -436.323090},
		{"ec3467e97b0d81ac9b58221686474fa6", -1449.262085, 1195.566650, -420.222534},
		{"138547fa1286ec4f8dd6dc32a807b345", -2329.312744, 2060.760864, -384.947144},
		{"b1e75e8743c9c0b7c09f0d42e7e8d8cd", -2329.312744, 1804.760864, -384.947144},
		{"efb965b210a81356152d00141adb24b3", -1817.312744, 1804.760864, -384.947144},
		{"5ba0ee2923e365167c4e8847c3e94384", -2073.312744, 1804.760864, -384.947144},
		{"8032f17c144725f5c7d19cac01d8eb60", -2159.855713, 1742.217529, -358.340942},
		{"06e969cfac25a1466baea9b44046ac16", -1903.855713, 1742.217529, -358.340942},
		{"d38056ed437fa1a9966a30e8580a6d6d", -2138.459717, 1671.706787, -334.351868},
		{"b411370404c376e76345bd8ecd6363ab", -2666.110352, 1054.664612, -250.773712},
		{"701fda327fcf58f388ce9d400045f288", -2666.110352, 798.664612, -250.773712},
		{"d3a7a788f62d5ac84c9c4a3c373f216b", -2410.110352, 542.664612, -250.773712},
		{"360c7f76868860341e035d51263fa1fa", -2410.110352, 798.664612, -250.773712},
		{"f60a29b3a2f5ff39ddc11758c6799cf4", -2666.110352, 542.664612, -250.773712},
		{"ecb6c9a7efbfbe5697208aed8dafa846", -2240.435059, 904.925964, -217.584946},
		{"115086e9ae115926fb9d9c066dc0972c", -2570.443604, 580.058411, -156.494125},
	},
	["Naxxramas"] = {
		{"cbcd3f08bee9070ee93fdc04f5c951d9", -858.312622, 794.681641, -253.441193},
		{"89ff0c4ac2d8f2f7d7234628f96e65c0", -1114.312622, 794.681641, -253.441193},
		{"93e73396888fcfe75338da4e34fe10cb", 1010.541321, -754.557678, -127.580200},
		{"e1eadca1245be2477274932de713da3b", 754.541321, -498.557678, -127.580200},
		{"fb997352b4e73da2b2ac987126307ebf", 754.541321, -754.557678, -127.580200},
		{"aeb894578d1c5b04e8d687a6feddf2cc", 640.609802, -868.400452, -127.580193},
		{"29bd67fa5cb02ca010ea0f8544b18303", 489.595490, -1023.835510, -127.580193},
		{"605edd4e060aed97c533c5850d3244df", 489.595490, -767.835510, -127.580193},
		{"e98c3dc3173441be37ea32f56ff11661", 745.595490, -1023.835510, -127.580193},
		{"8fc0567090b53d1254ea57c8edda5caa", 808.980957, -488.322571, -127.580162},
		{"f2ecd7f54f21a7367fb97ed13d1ee9be", 314.415802, -986.798950, -127.580162},
		{"81aaed0a7636eb46b3e3336a518181ce", 680.712921, 163.682693, -125.489883},
		{"ebb7dfd90830d6eca4e5fea512a7344b", 168.712921, 163.682693, -125.489883},
		{"e0039d3092237195d804e5816f21bf48", 168.712921, 419.682693, -125.489883},
		{"28e2a270364b9e6c976c49ab1e03863d", 424.712921, 163.682693, -125.489883},
		{"b6cfb88ebf3e365103729e04b1ae445d", 758.525085, -877.205566, -120.619194},
		{"cd4f579a0b3dc4551f9eede97b43f11d", 1014.525085, -877.205566, -120.619194},
		{"6913149c7501afa377684819a9b2afb2", 1014.525085, -1133.205566, -120.619194},
		{"4aa939a7cdecaa1f98513d6df5e8551c", 758.525085, -1133.205566, -120.619194},
		{"4ab6a4d87f57119c788f3ee0f3a03185", 1.441640, -922.982605, -110.851051},
		{"0cdc974db1f138de5bfe8c47ef01a40f", -71.556267, -922.982605, -110.851051},
		{"35cd1010c5e94a0949895337e344ff6f", 872.791260, -0.110470, -110.851036},
		{"5ab9fcf81f3e0d3ec49b771549096f94", 872.791260, -73.108414, -110.851036},
		{"66e8ea0510193ff1c177567693bc5f78", -921.430237, -0.055539, -110.851028},
		{"8cd090522fff5ab408cb4a0981890571", 1.496403, 871.239197, -110.851021},
		{"4acbf33f96d65f182b8cbbcd1b3d97fb", -71.444092, 871.239197, -110.851021},
		{"1bc416b869db229881e62112e28fded1", -921.430237, -72.996094, -110.851006},
		{"66f36071a4c95b484d67ec42eb88da3e", -531.793701, 566.743286, -83.880539},
		{"67c6cb8e6939aa29cf2f1acd8a5593c9", -787.793701, 566.743286, -83.880539},
		{"8cffdaf4093b55767b9f58a22b62d28e", -531.793701, 310.743286, -83.880539},
		{"184ada8b4a154467cd77048b3c41a071", -275.793701, 566.743286, -83.880539},
		{"d75c1c8559c603b99d53c5007f40fb1f", -787.793701, 310.743286, -83.880539},
		{"e63fecc86cc4ad9875855ba0f9548c0d", 876.984009, -108.513626, -82.786690},
		{"75d2f4612121cbd3d84bc4dd34170693", -106.961479, -919.060974, -82.786682},
		{"1304d73bef2ee05bc64abe9ef8a75d58", 48.364559, 875.431946, -82.786674},
		{"1659aa0ff378cfdb7b6b6d4902e2c4ad", -917.244141, 46.812584, -82.786667},
		{"70b4fc4b54980324ce9039c2a05db8e6", 48.252361, -918.789795, -82.785759},
		{"2ab56d40279e5ec95161171d0197e5cb", 876.984070, 46.700253, -82.785744},
		{"26330aed2788fa5a12b109939ff001ab", -106.849327, 875.431946, -82.785728},
		{"4846968f6762ca1aab25a3de7482dd70", -917.293091, -108.401314, -82.785713},
		{"50e57f5e830af824c98db77af68a2b25", 519.912598, 19.073938, -79.638420},
		{"a27f110f0ef8d2754313161d32e1a99d", 331.510590, 75.912079, -77.745491},
		{"db71a17a1f2381c008cda42b2ec5148c", -311.678589, -1024.059814, -73.674370},
		{"6f2d0c4b843d39cb70820937f849cba6", -1022.336365, -313.113525, -73.674263},
		{"d4c84bc48ac6bb1933f9166e56a06361", 69.734177, -1023.794617, -73.674225},
		{"d6545a641ee5f7d87444125284fc3e88", 773.384766, -313.142883, -73.674217},
		{"9370ff3df4cf954a14ad4efc63d0c798", 1024.641418, 68.182091, -73.674210},
		{"3acb752f54c1bed8ffcc89ac12961b05", 768.641418, 68.182091, -73.674210},
		{"2f6d85f935129a54864b1051c286c26c", 69.846367, 1023.089111, -73.674202},
		{"022dd252d8d7861d0a0092078a538ac0", 69.846367, 767.089111, -73.674202},
		{"e80a1b7bc9fa42c0900c8f796472f49c", -311.478577, 767.089111, -73.674194},
		{"17e890edb04f9a041455798085047008", -311.478577, 1023.089111, -73.674194},
		{"ad0c31173106596fb8d7397d7fd5749a", -1022.287415, 68.294411, -73.674187},
		{"9b848e1246756723eaf7306ee59b7c4e", -486.774719, -987.116516, -73.444847},
		{"e1da26ff971704cd3b76721f024e89c0", 808.977844, 312.863708, -73.444778},
		{"e4f0cb99f5eb815b2e4d57b13e0bd67c", 314.528717, 807.429138, -73.444778},
		{"86da3eeeb5ef081e58f0dfeb159f7d72", -486.658295, 807.425842, -73.444763},
		{"777063349a7dbbd55a5dd3c47cbe7f75", -985.250305, 312.976746, -73.444763},
		{"40b5292e68d8311fa69950acedd799dc", -985.247070, -488.209686, -73.444756},
		{"598644d0592efb4445961fc25de174b0", -440.759460, -107.925354, -67.510605},
		{"f42dd7e6351800ef1db5c070b5f563db", -696.759460, -107.925354, -67.510605},
		{"b51ecbbd26a78e9ff5baa6e195b6c566", -696.759460, -363.925354, -67.510605},
		{"18633c9e1c5575aefee9a604eec4cf87", -440.759460, -363.925354, -67.510605},
		{"021aba0e807b2aa8bb87298020236845", 399.121155, -466.145081, -66.956192},
		{"880dfe6163d0dede3d42d4d99ce6bc36", 399.121155, -722.145081, -66.956192},
		{"cf96d2cb4678bc425e14e925846faf24", 655.121155, -722.145081, -66.956192},
		{"75b4cbfcb8d469e7eeeea0a75acb001a", 655.121155, -466.145081, -66.956192},
		{"de14da1387c99ff5a83855d10bd96d6a", 481.645355, -295.788666, -66.684853},
		{"f55abe82e771a2af4995f02a6f98af75", 481.645355, -39.788666, -66.684853},
		{"84d308ba3f47a5f1b78a609c324d69a3", 737.645355, -295.788666, -66.684853},
		{"06062a967de347f41fbf07ca162dc4e9", 737.645355, -39.788666, -66.684853},
		{"828b21b48127794ee0cad777ce72c3af", 401.287781, -282.178986, -66.631264},
		{"78398df51008ab1fa28edd1ceb928f6b", 92.317558, -504.318298, -66.631256},
		{"ff39afdc45b8d0decd9e65880ac43ee7", 348.317558, -760.318298, -66.631256},
		{"e160b83b25759b68cdfd68971401db84", 92.317558, -760.318298, -66.631256},
		{"f8bcbee1bcc407b8b4337b4279d61f5f", 348.317558, -504.318298, -66.631256},
		{"b00cd3b795ccf3f8c61e092bd70ec93b", 409.524567, 612.090210, -64.548225},
		{"8c5163993b4db2e9eb6f8e33aee0af8f", 153.524567, 612.090210, -64.548225},
		{"c7ad09c44e53ea38eae65fb1d6346985", -232.792236, 654.755615, -60.935310},
		{"d15a509764eafc567f3b7c38ea5254c2", 52.385590, 1026.972656, -60.437473},
		{"a1df990fe42965985d079f84d8de62b1", 308.385590, 1026.972656, -60.437473},
		{"ce689aca91cb0f535903be5def649e87", 359.640533, 405.505157, -55.762413},
		{"636ccaf0f1f24bd466192d56eb7e6cb0", -403.924500, -141.371368, -47.973129},
		{"4a51c4ad062cb2d6a16caa26f00ff6a8", -147.924500, -397.371368, -47.973129},
		{"d7ed1a1b018b0988e18d25bcc9838bd7", -403.924500, -397.371368, -47.973129},
		{"70382a5364e6f79170e6cbbe42c39f88", -453.193634, 242.883301, -42.618134},
		{"1b13251c3cdb8a318885ccebb955e2dd", 94.343063, -161.003708, -42.289711},
		{"f078a96db062d551d4b423a8e7ebadb5", -161.656937, -161.003708, -42.289711},
		{"23d956ebeeaeca5db34fbc7932df04f5", -161.656937, 94.996292, -42.289711},
		{"9cf4e6a0a7ce3a3540786e8a1547c21a", -695.255310, -694.196411, -39.629185},
		{"1deb185281f9235dae0afc202c7541bb", -327.315399, 84.817993, -35.823593},
		{"0478cb4a92d195a88acd59d0159ac6bf", -419.944336, -47.655979, -33.602081},
		{"5b100d59d96c7ca17b76315bc0e85fc1", -675.944336, -47.655979, -33.602081},
		{"f3d54064fdeb0984ec53b6e914ca072e", -675.944336, 208.344021, -33.602081},
		{"b16614925e1b987c36087118bb2056d0", -195.428528, -193.522308, -33.338844},
		{"9e370b0b1f3f90b0da0c62364ea5c615", -396.642395, 39.705143, -29.316881},
		{"d4dce979c6716f462c41f72c93ae6d93", -1116.749634, -1117.476074, -28.686768},
		{"d9254e05a8aee0b57ef66494d18f3571", -1116.749634, -861.476074, -28.686768},
		{"16175e93d7a2ec7c905264d6b04c25e5", -860.749634, -1117.476074, -28.686768},
		{"493f2713fad21b2b962e7bc41dc4a727", -860.749634, -861.476074, -28.686768},
		{"a21e6a73ea91dffb57866bef5bd79e1b", -154.611023, 59.850761, -27.840096},
		{"7980c293ceaa95094e2d4ccf82ce134b", -346.394745, -538.148682, -20.702507},
		{"1ec95d425a1484a50ae2b76426484f3c", -868.147278, 639.161316, -19.310783},
		{"c3fecaa4ce5f044fae2ea79a11e4467e", -748.426453, -1015.087219, -19.309505},
		{"f72a54dfe486fa1a8ac73ad59eaac8ce", -748.426453, -759.087219, -19.309505},
		{"f798b3b1fe9fb04061849df6fafc8296", -492.426453, -1015.087219, -19.309505},
		{"dc37352dea5fb7ac234d4e7a4bb6da08", -766.275513, -872.450928, -19.309465},
		{"710caf23b20a511f5c4191770590f183", -766.275513, -616.450928, -19.309465},
		{"52ddbe75a2c6666a8266fc5977316ea5", -1022.275513, -616.450928, -19.309465},
		{"da6621d16b454937e767e3d07ac93b8d", -1022.275513, -872.450928, -19.309465},
		{"4e3d3f0248f603812ed39284e45102bb", 754.556152, 488.043854, -19.309431},
		{"76f1b670cc832e3686f8db81d550292a", 745.708130, 752.989685, -19.309431},
		{"83a6db2331b58bd1a6135743869859c5", 489.708130, 1008.989685, -19.309431},
		{"02829834c6bd874952407ef9cc8e73c1", 489.708130, 752.989685, -19.309431},
		{"e10bca21cc86d3265a8997bace39c896", 754.556152, 744.043854, -19.309431},
		{"2c7010e8841298ba80a61c718fc9b9eb", 1010.556152, 488.043854, -19.309431},
		{"25fb88ebdb4c6f672186f31b692f514b", 640.713318, 639.058105, -19.309422},
		{"6145a30f1269475613a5cb5abd47b141", -1022.282532, 488.156158, -19.309418},
		{"41b4cb70227d2f0a67d207970dca10d1", -766.282532, 488.156158, -19.309418},
		{"a921eda818a9b30a84bbad89f9690bc2", -1022.282532, 744.156158, -19.309418},
		{"2317b747473841722cce21757ee901f8", -752.902161, 1009.004150, -19.309412},
		{"406aa6995eca9412de6ac1ea6ace9a93", -752.902161, 753.004150, -19.309412},
		{"48f49447c89dde91e5bbe31a15fc8ffd", -496.902161, 753.004150, -19.309412},
		{"1040f0f53d94d16bf7720cd578db6471", -155.642700, -765.667603, -16.409714},
		{"861c8d0f59267833de48ec863ddc9acf", -667.642700, -765.667603, -16.409714},
		{"7e30aeb3a5a0ae47a1535f5e5558b301", -411.642700, -509.667603, -16.409714},
		{"02b5173b9cb5e025bfd6714b3c3a9b6f", -155.642700, -509.667603, -16.409714},
		{"c33d9c1d8366c1062927bf601a7d27b1", -667.642700, -509.667603, -16.409714},
		{"254b9f60d30bd0814b14806bfa4d27d8", -411.642700, -765.667603, -16.409714},
		{"5c1f878f3db0dc5313170c983d389a6b", 72.915527, 54.900795, -15.944805},
		{"c9a9a5c37e30711783d0039d90af1ea8", 328.915527, 54.900795, -15.944805},
		{"a7a43268441ccab076d07cf1678f190a", 60.411369, -129.684113, -5.880033},
		{"8ee99730c5cd2741ffa3127ed28adc64", 60.411369, -385.684113, -5.880033},
		{"ead810f932baf4f320c91d5cb5896d5b", 316.411369, -385.684113, -5.880033},
	},
	["Onyxia's Lair"] = {
		{"78397ed5982e6c7c14e68fdcca735860", 137.716049, 540.699951, -192.950333},
		{"e1799bb921554c95f56c65e672d267b9", -118.283951, 284.699951, -192.950333},
		{"cf09373273d90bf8be9b94fbb3ecc2b8", -118.283951, 540.699951, -192.950333},
		{"b31bd8a0e3438610b400088bf9e22011", 137.716049, 284.699951, -192.950333},
		{"0ec4e3776a69543205175cd0b280bf52", 253.205460, 238.053818, -141.662766},
		{"5d9a286b286efbf1237c8c7f5b307104", 253.205460, 494.053818, -141.662766},
		{"2d2fef937acd1da861871a26f4b95d5f", 160.574646, 178.510223, -126.546280},
		{"1c260ea8b1732da60781d4c88afd8b1c", 48.608906, 154.818954, -81.054352},
		{"3a050f110f2d5642a88085e80d169d5a", 3.496235, 170.429382, -66.665489},
		{"e585104741a872a0528376ba688c7a73", -126.491890, 98.720047, -57.953400},
		{"2d3dd748b78dbff48c7648aa9c91982f", -90.243881, 25.429382, -9.534581},
	},
	["Ragefire Chasm"] = {
		{"405a610dc692a9072fe23a1c1e03ede5", 518.514069, -98.339828, -132.382874},
		{"d7856cf8a6b8bf3c092908647725c853", 262.514069, 157.660172, -132.382874},
		{"6ecaf15e41a190e577e25736f66c36e9", 262.514069, -98.339828, -132.382874},
		{"e533c2164f3a4647d2a4686195a6ae52", 518.514069, 157.660172, -132.382874},
		{"3523132a1041d185d639491fe5ddd5ca", 133.193054, 9.382098, -87.941589},
		{"bd6125ea09443982575bbd6a6b8fd39f", 578.827240, -276.126404, -79.638771},
		{"7e0ca17a3229d30d88e63a5e9c85462e", 578.827240, -532.126404, -79.638771},
		{"52cf8181be3dc8c07113f51456459d45", 322.827240, -532.126404, -79.638771},
		{"c6af1528cce440fbb81259cb80904961", 322.827240, -276.126404, -79.638771},
		{"237342a76300787dd953aad0e856e240", -33.427898, -15.771896, -49.912312},
		{"3c43c9430cd4720ca97230922aa9ed45", 126.778221, -213.711731, -48.731426},
		{"f50de18124de7c6aee554bc12f9cb16f", 626.517517, -294.758118, -45.384815},
		{"c58e820d9547879a8357da904284f356", 626.517517, -550.758118, -45.384815},
		{"587db365eaf3e1d9d7967c5e689dee3f", -177.524628, -125.734512, -25.716606},
		{"887cb5b59f8e6ff68b293a789ecfd510", -205.911331, -167.370667, -21.596722},
		{"670257610f8dc0445dc1ef2f6da2b0c4", -198.651489, -233.210297, -15.739727},
		{"60e88665de38422620d2574fbe3757f3", -194.923798, -319.508362, 6.404248},
		{"fcaf3a4518800d214917e7507df7ffb8", -52.245319, -372.508850, 43.499203},
		{"7ab8cfb28914799b552932d2a7b0a74f", -126.075981, -376.497345, 53.183681},
	},
	["Razorfen Downs"] = {
		{"3cc0bce6682d1ed6fb747fe829c1ecff", -293.057648, 137.738251, -81.434418},
		{"627d1b646b72cb3ddb1e5f0520c37c7a", -37.057648, 137.738251, -81.434418},
		{"00d68f71bb8ca428da34d170b4d0bed4", -293.057648, 393.738251, -81.434418},
		{"0f9f24929a6f2f7a5085702013dbd817", -37.057648, 393.738251, -81.434418},
		{"55b8d997f024b48bff7544f5b7fdfab9", -37.057648, 649.738251, -81.434418},
		{"bc95b1dd9c1d00907a40941f9f32d98f", -306.508026, 250.736084, -77.691124},
		{"897ac41644d7eb6e4382f4dd431d9a1b", -306.508026, 506.736084, -77.691124},
		{"b7d5c17cd9037913f864005dd6b3c3a0", -50.508026, 506.736084, -77.691124},
		{"427b4f034220a8f340903466606722f5", -99.587128, 440.566010, -75.090721},
		{"2a3d7003b9a4099516cd11ff2aacf9a4", -99.587128, 184.566010, -75.090721},
		{"20d1024b85232ce76dd3830caf79a73c", 156.412872, 440.566010, -75.090721},
		{"98a8931b354cf395fcada7023af829d5", 156.412872, 184.566010, -75.090721},
		{"ad05baff3171a326c4ef07c219c8f405", -214.798920, 855.192627, -66.888931},
		{"f5803a96c22b7f00660c25b7772f52ba", -214.798920, 599.192627, -66.888931},
		{"1f680b23a689e16b29923b723f613149", -367.428741, 1024.598022, -51.933834},
		{"1aa67f4d9d72a04f8f02bdb61d187540", -367.428741, 768.598022, -51.933834},
		{"9bc59035c9dcd9ff109b3f76e45c6f21", -111.428741, 768.598022, -51.933834},
		{"ff43f1a5adab24e7bbbdde623dd480d1", -354.749573, 796.740723, -38.737591},
		{"9adc2a2d33b087b18912aba3019fea0e", -354.749573, 540.740723, -38.737591},
		{"c4b8932a97e6074a82afc11bfde9bcb2", -436.687592, 170.045029, -37.669960},
		{"2db384c6f58491ad9c66d42137e0755a", -433.710236, 238.130615, -31.468039},
		{"0348c56692aafd4bd075ebec7ce0d6ee", -282.027374, 909.962402, -30.424431},
		{"e06672c5a361b249390ff972b80bb57e", -282.027374, 1165.962402, -30.424431},
		{"b5474c9d9b711386fd15c80dcd921c48", -26.027374, 909.962402, -30.424431},
		{"7c9213bf33fe3f16d3d5f9cf93ad6383", -433.380310, 405.724426, -30.243666},
		{"005eecb5eef57549068829143e8aad28", -454.791046, 826.193054, -30.230232},
	},
	["Razorfen Kraul"] = {
		{"14baed26b20e121ef32db085e7c79937", 446.705688, -39.138187, -82.418556},
		{"1c12ae78969dbaa6aa55abf3e2280def", 702.705688, -39.138187, -82.418556},
		{"50db950f198e39c8749191e9824949ff", 702.705688, 216.861813, -82.418556},
		{"b1625d0d2e28d495c40f6ce511dc4753", 446.705688, 216.861813, -82.418556},
		{"f01d2b56d8b06891c6b67949bf72be52", 357.644989, 114.709946, -77.313957},
		{"5b23d111585e098710f83761b78178ac", 357.644989, -141.290054, -77.313957},
		{"e3474d45570b628149a9af3a644013f7", 439.837769, 124.067505, -72.196114},
		{"0e84589543ba58c616925a5b751d62b4", 306.520081, -210.849701, -71.209160},
		{"19741de50c745c2aa4f6b2a635b37de5", 600.758179, -79.158546, -69.860954},
		{"c70b32721c4219747aae7c61ae050c28", 714.136169, 112.129295, -63.878685},
		{"f326e8220a2e93376fa57b2bf672dcf0", 246.278290, -62.483265, -63.262360},
		{"409ed41a2b67b31b87dd4f3ad617f252", 335.233261, -223.492447, -62.445347},
		{"f4377a4b9bd7bdaa78061bef0c2aeee4", 79.233261, -223.492447, -62.445347},
		{"26d83d77b8f3feb47c6b4aca9062b935", 600.804138, 202.453979, -61.047195},
		{"300b467132496f0e800b85c0d8e1fe47", 709.560791, 220.553497, -59.996891},
		{"72dc29fa8b735ff1569cb711ba868249", 604.911011, 432.898438, -56.329662},
		{"39724c5244ed0112c3ac66ea5366bcf7", 567.930115, -124.202316, -54.340439},
		{"bf8896408a8bd54632bedfc4cfd2b02c", -90.800758, -318.078613, -50.087254},
		{"8207ebed316a9913b2959c6a201196ec", -90.800758, -574.078613, -50.087254},
		{"3abe03ad2ab4744043865e44ca41d438", -70.836426, -239.538010, -47.935616},
		{"537e4f6b9a2dd5ddb2d8e6eaf579e0cb", 34.578396, -570.911499, -43.250294},
		{"082a565a762054988c04b41c2302082d", 131.012497, -526.613770, -42.285065},
		{"891a82258bec719df22c5178b377c413", 653.720215, 148.471756, -35.017658},
		{"a0266795e6e768bfd823632ccfcdff4c", 305.609802, -404.831299, -25.705433},
		{"b8bce3826bc7c6584e55c4ba80ec72a1", 242.967499, -274.013397, -23.556213},
		{"8ecd9c1267b79ab6e9b95f92a96e0f7d", 91.174019, -328.088379, -22.184507},
		{"1c76f6050eca9f5d63c9e602d86e872e", 175.933990, -316.872864, -18.515430},
		{"b41ad8ae4d91d092eaa09b92fb2cbca5", -51.962009, -124.959717, -18.003889},
		{"d08d20b01f120c112becb84a34d6315d", 137.346390, -52.443611, -17.628021},
		{"5cfbd76dfd99f1aeb211026946cc8faf", -89.838547, -62.719532, -12.476663},
	},
	["Serpentshrine Cavern"] = {
		{"a8b72ef783735ec67ce094711f83c4b2", -1127.384766, 824.230896},
		{"f95e9a719cddd800c5c591ebc1ed0f6d", -1127.384766, 1080.230896},
		{"adfce3f1ee352d744b4f4df8d2868acb", -871.384766, 824.230896},
		{"35ce674d058e35a3059f4a44ebd9a0ac", -871.384766, 1080.230896},
		{"f0be2ddd36a13dccb590dbf83b647c2b", -1147.779663, 1204.553101},
		{"ca717f0e4f805045174be576b2ec85b0", -1147.779663, 1460.553101},
		{"65ffe8adc5eef90dedfa406fe8f070d5", -740.356750, 471.072998},
		{"13ce17ceda485e75f59fdde29e1969d0", -1026.307983, 775.793396},
		{"8b76be4107d7bcb1222be78121889265", -608.597839, 1285.453857},
		{"7ff681e563f21ec25b762681875efb9c", -898.168884, 841.080627},
		{"a3a9ca9737202f8ce58b936933d32ea9", -394.245392, 1581.373413},
		{"3b169b95f91d6050e326058f38bb683d", -394.245392, 1837.373413},
		{"3af2f33643120538f879f44a9a104748", -394.245392, 2093.373413},
		{"68b2e0f3a51680a457d6b2ce8bd446e4", -138.245392, 1581.373413},
		{"afca60e013b90ade7923b4686e738e7e", -138.245392, 1837.373413},
		{"79f6d4ea8bd4a646dda96dd0f85e1f53", -138.245392, 2093.373413},
		{"86364feedf3f8ea172dd55af07c04969", 117.754608, 1581.373413},
		{"3567eccdf8bca62a38ea8a275b62afb1", 117.754608, 1837.373413},
		{"5e637779786ff6d814c4ad7887b1c878", 117.754608, 2093.373413},
		{"c9feafb7beda223eb46db9b6bb5c3604", -203.144196, -230.653290},
		{"4de92e719912ddfe6fe6e6b65cc15105", -203.144196, 25.346710},
		{"cc4b59fe7aca109f97739fae4c1671bc", 52.855804, -230.653290},
		{"1ffd865f1431f9366b98faa2af269208", 52.855804, 25.346710},
		{"d795a8f15278a0fbca600d6e69377234", 308.855804, -230.653290},
		{"a0abd69b145b7e399aacae0524fcab19", 308.855804, 25.346710},
		{"85c44d71bd48841e8b1d6406b66d748d", -837.105225, 579.645874},
		{"f601320b62f886673dadf7254cd80792", -837.105225, 835.645874},
		{"67f47084b084a9087ab3d770b7f677bf", -837.105225, 1091.645874},
		{"a211c72f9704c09fa4e36674484d14d0", -581.105225, 579.645874},
		{"597015ddedf0b4210189e62535dc241f", -581.105225, 835.645874},
		{"3b4af94fd741827f7e0e3caed3e27977", -581.105225, 1091.645874},
		{"c83d9d660c0d6c48a10fd00a2aadc007", -926.372620, 1320.882568},
		{"05b51dd5c7d4a7c30cc0962841939d8b", -670.372620, 1320.882568},
		{"d68253c36736b332ab7e97c408d1bd14", -594.130493, 271.692387},
		{"b1215b048a7b7378cfddcb5127c26f1f", -594.130493, 527.692387},
		{"f87ddcd49a2ec78efcd000d1943dd935", -594.130493, 783.692387},
		{"9fa41d99da8b3847582a899dd92d7685", -594.130493, 1039.692387},
		{"f712d47a361ecfb4c0099d1e36269e62", -594.130493, 1295.692387},
		{"509bfc71b853a084f3a098f267020e89", -338.130493, 15.692387},
		{"d52854dd2920ba2017e9931c662778e3", -338.130493, 271.692387},
		{"6c5a5e08fbbd70e7eadb14ae59bd6e2f", -338.130493, 527.692387},
		{"c6fb6705bc0567e253f5c4bee7f0c275", -338.130493, 783.692387},
		{"c3e7e8e8aee4f0794d59375b7c21fc25", -338.130493, 1039.692387},
		{"7c49185950efe74dac29bbe974cb1d18", -338.130493, 1295.692387},
		{"aa0c89718a56f40190bcaeb68c6d0eec", -338.130493, 1551.692387},
		{"34a895708726dab85e373626025c0931", -82.130493, 15.692387},
		{"82828d71a6dc5993894a85c4823beacb", -82.130493, 271.692387},
		{"2578b6b2d173215103435df79d3e5ac1", -82.130493, 527.692387},
		{"b555e9ef7c91480b549428f39cbef33a", -82.130493, 783.692387},
		{"1292875bed0fa93a8ede465ec34cafca", -82.130493, 1039.692387},
		{"4b06a4e685cf296c34682824b0d32e50", -82.130493, 1295.692387},
		{"24c12b390b04fe9bc7467f58d087c4f5", -82.130493, 1551.692387},
		{"be9c57e01d01c06caaf83644d3bd1654", 173.869507, 15.692387},
		{"f78e986edb09cc771d3be259c6396189", 173.869507, 271.692387},
		{"b21bf35b9e82010619bc53a426b63f59", 173.869507, 527.692387},
		{"d502a758563ee98439d29409d1977dd4", 173.869507, 783.692387},
		{"34d1588837e696e7e27674a834a990da", 173.869507, 1039.692387},
		{"ac5ecc7bc1caaffa3fa9a510bd933f13", 173.869507, 1295.692387},
		{"e55acaf2ea6b2e23aa6d9c227efaffb9", 173.869507, 1551.692387},
		{"e9d366712c0436efb2d00dcd9fcdd049", 429.869507, 15.692387},
		{"b177a8ce803a33dac6b9b0069dc26d67", 429.869507, 271.692387},
		{"5db8f29c8ab39476c013603285111cb4", 429.869507, 527.692387},
		{"e1551462c22b15ae8f52b50ff0c8312c", 429.869507, 783.692387},
		{"fe1eb95e4a37bdc2c6a773d7097ab743", 429.869507, 1039.692387},
		{"6e40efe6235258668dadebd94071a2be", 429.869507, 1295.692387},
		{"ba4c9d249e0566a817cc6d060f166351", 685.869507, 527.692387},
		{"4d15237252b364a438fd8cfa51d830e0", 685.869507, 783.692387},
		{"c4a69bbb8c247ec9a46e18e01588c9e8", 685.869507, 1039.692387},
		{"674de7d789a1af8bd3ec0b8de2241dc0", -164.098694, -46.047417},
	},
	["Sethekk Halls"] = {
		{"db7b9947dd35f6833e4a09ff17e74106", -71.307922, -391.925385, -6.651114},
		{"fc841cbcecc131b6099bc88a816cfaae", -327.307922, -391.925385, -6.651114},
		{"c8b7feefa1cb1880fbfa1b087d64ab77", -71.307922, -135.925385, -6.651114},
		{"a976fceb9f4eb2ead4e1e43db3b1030e", -327.307922, -135.925385, -6.651114},
		{"1483005d7d2a7a341da34aef7d8a31ed", 405.531281, -435.149658, -2.500183},
		{"8a769d1f9594fb5d240683e94ff175ad", 70.780846, -272.022461, -2.292464},
		{"9935018d4a70b66284be8e0f3631ce55", 16.943417, -22.998817, -1.829718},
		{"dd02ab4d4e2cc461401c5561ab790165", 217.359512, -458.405975, -0.520570},
		{"71c9ee3589221e91cb1cebbcdc6c5be5", -109.932236, -124.123947, -0.047576},
		{"63e4866b6ab2339283689df2e505d4c8", 118.636742, -369.928375, -0.043607},
		{"9e77bbb603ebaf9d5638d80c1cfba9dc", 12.379078, -224.235321, -0.041185},
		{"998c850e509fed97e54d4d8e001262e4", -112.605186, -328.720337, -0.040673},
		{"9293e005f3f9be8fd81c3c258726a4d7", 358.744598, -369.943939, -0.034047},
		{"744350ab21918e758b2807a0b3ae13ef", -112.605186, -398.073090, 0.079078},
		{"1cb6b37ef6338dce710738d346cb017f", -64.274559, -501.833313, 46.092285},
		{"28a258051fb800a6b278fd3fdedaf4f5", 191.725441, -757.833313, 46.092285},
		{"367ad5ae7483cce5f35f124afe39933f", -64.274559, -757.833313, 46.092285},
		{"6aac3e9683e03236beeddb65b314f740", 191.725441, -501.833313, 46.092285},
		{"595cfa27b52a626ca96636262107082e", 313.621429, -730.432861, 46.670437},
		{"9a2de7891eef4b5b6fa30a297966a681", -185.143417, -669.036865, 49.968811},
		{"70b8a0e78beaf778a4c604bdd68d7e0d", -112.606010, -462.307068, 53.344589},
		{"b7d147557c83cb749b72282e22bd564f", 461.645844, -522.787231, 53.390366},
		{"718161b25285e62c08c5a5e886877aa2", 272.347412, -596.628418, 53.405361},
		{"933ca35abf5fc8c3986dde5abbbb8b58", 21.116869, -596.612549, 53.405373},
	},
	["Shadowfang Keep"] = {
		{"feeae215bba2e3fc19de381535fe1635", -374.814636, -231.891739, -4.831418},
		{"7c181a617156089dd0512b428ad9498a", -360.899841, -101.367569, -4.732882},
		{"a5fc3372fcb147feb793c7cf037cf153", -318.965668, -20.448267, -2.449937},
		{"91d01347719deedfad53c659fb804df1", -150.136627, -71.522575, -1.048578},
		{"ff2c23298e684f07cda7880fe53e0e6f", -52.533722, 26.990248, -0.979326},
		{"85c9fb62a3c653bc8d27e72edbc8075d", -40.620079, 17.630421, -0.953723},
		{"5ed05b27c638f2890ffb313090e8d674", -351.486755, -82.249626, 0.334267},
		{"0a53f1342a30c0c7d6239d329e1361b4", -304.274231, -121.633316, 4.751660},
		{"80df60c469959729ac27fe6d531e49c5", -124.494606, 7.961989, 7.325326},
		{"fbb51092345d716d8ff0b5dd87650784", -84.656944, -69.853584, 7.514500},
		{"5e714ae17f194b5d911bed9402bb39ad", -369.619232, -256.104034, 7.986136},
		{"0917e6258967dd1ea5234e73f50d7e4d", -113.503441, -65.117722, 19.280680},
		{"efdbc5d4cd053a2fc4f23de84402d365", -52.533714, 26.272644, 20.388227},
		{"2dbb61a864e6ae450de207e16b7d6965", -128.051697, -64.027542, 24.648153},
		{"0f6a45cd73840f7a3611d0dc6c42749a", -358.778473, -277.974579, 26.485281},
		{"2e8f86b5b3936545259aa4ac46b47658", -336.911957, -277.974426, 26.490871},
		{"5fd17353200943c1d74f53a8c3af80e1", -384.534241, -277.974426, 26.490887},
		{"11d6d5d160011dc8dc8ad609cf23932c", -113.503418, -22.716869, 26.504942},
		{"3ab610b39ad279876864e5f2086918bb", -113.503418, -32.005486, 26.516455},
		{"5b6ac74d4a2cf5f6c70ce8145419b3d1", -358.779358, -63.332832, 26.550955},
		{"9c0ef2851d104639b109acdebe5570c9", -384.535034, -63.329342, 26.555950},
		{"014b359f335ed1c84bb60d166374e9b5", -267.577698, -110.469742, 32.338074},
		{"6f06727225051668f69be01853930320", -255.542999, -119.831978, 32.347858},
		{"f83484c385db23894934311ce0a7dde4", -253.346573, -99.672356, 32.350243},
		{"3968e39092ec496f27c6686366dc83fe", -253.277130, 62.341030, 33.349159},
		{"b18de18ac013afb588f78be213a058fa", -198.812027, 51.214607, 33.351650},
		{"1a648f7fc529162dfd5fd6f5d1e309cc", -215.734909, 45.122829, 34.048378},
		{"c30ca12967d35ea4a678efa0cf87577c", -436.218079, -168.675232, 34.621498},
		{"dcf7a693a03d074c7dd32d10ea2db206", -74.761894, -106.471107, 36.911800},
		{"115a735deb7f86e811561a634b2ef587", -419.540802, -234.237961, 36.974129},
		{"631550a100f529a781bceb4011ac41f6", -315.046539, -234.239594, 37.001377},
		{"e44d40ee48000f5356810e0e8b3f3dfa", -315.046600, -212.372925, 37.001377},
		{"54d65a72bf0cf31f988f94d98bbbc2b4", -315.045227, -277.976349, 37.001377},
		{"f3bb78e5fa8f3bc7b249913117d6f2ab", -406.399689, -256.104553, 37.001377},
		{"ac569ad66ff489d20b2b5e341e747b0c", -315.046539, -256.106201, 37.001377},
		{"8ffef88c55961bd2e39f5d49da26c5d1", -406.399994, -277.974731, 37.001377},
		{"36ac7ba5f3ba64bee57a411215862dd1", -315.048706, -190.506317, 37.001408},
		{"04ac7a8cbbd12f7e80181282a4fd6f4d", -406.401337, -85.193741, 37.066448},
		{"211643b6c2679dbb0c7d043d00f7b5c5", -406.401306, -63.327122, 37.066448},
		{"d4cc104e16ef91cb0b18c663f60de85e", -406.401337, -107.060371, 37.066452},
		{"31716c6e1a4df355f05c3a4bf9d1c217", -69.225662, -96.947929, 37.789967},
		{"b12cd59348b2073437b17c7c446fcb12", -215.734909, 28.199944, 38.048374},
		{"af0969f6a482482ee655f4601e3560f3", -254.445557, -136.490433, 39.154972},
		{"cdeba07140878010dbd07e69b21318a9", -198.228806, 28.199944, 40.048367},
		{"e3cac2d08b086a89442da8d33aef1a6f", -30.191067, -77.468658, 45.326054},
		{"1918f3276d74fc7d14977a0c2f33bcf0", -100.527267, -79.121841, 45.326103},
		{"b78977f05835cc9e1e96354efa4692dc", -23.892281, -39.940262, 45.329712},
		{"5fd7d8e08f4ba7c43d862c6e1a80cd92", -315.583832, -157.847260, 46.931911},
		{"bef8aa1552435c1fbdc875f2c7725cff", -295.598450, -182.972748, 47.000988},
		{"f8f43c88f9e4170c2bfc8eca07ec2ec1", -309.101471, -168.638092, 47.045788},
		{"ad0c1317376fe2940c60aec50c3e57ac", -335.569611, -132.722275, 47.049431},
		{"5d6980bda32fcffc4f2b4fcd68f486b0", -259.609375, -140.630539, 47.061909},
		{"b2459e9cd212587f6e2b2fe3d723b5ab", -225.579208, 40.643345, 63.779331},
		{"c3cb943ac144aecb5338af3a6a83115b", -227.072052, 17.684469, 68.779335},
		{"7f572cfb005f1c36b9b93a27a6824c61", -213.621552, 16.191603, 73.779335},
		{"c344cc495e9e48a9e207d15923a5be29", -227.072083, 35.213524, 81.279335},
		{"03722bc40829c71d0a08b2432a4c7de5", -227.072083, 16.191595, 90.446007},
		{"fc456cb1f867cc98b62f531edc613370", -216.764816, 29.642120, 98.779335},
		{"0769d6b072a7080af00d8ef81cab505b", -248.974670, 61.970627, 101.174438},
		{"c60660e70d7148854dc6300e34477b7a", -246.329193, 144.607376, 103.155785},
		{"131792e1e1b401839863d574eebf8738", -272.733673, 125.508667, 107.057152},
		{"392e087edb82bf8df20c8b12d9f8c527", -279.319061, 86.997292, 110.958481},
		{"1b7e4d2e2794dd1322d5ff82b5785cb0", -276.361877, 56.787273, 115.835167},
		{"ee7246f7354af3f970c4aebd4daf2d6b", -254.413055, 45.248062, 119.736504},
		{"06645f1c8a6bdb2bd7c3cd913f5c306b", -246.329193, 144.607376, 122.662338},
		{"8b32184a0e7c1ef97c6fe6b469307883", -272.733673, 125.508652, 127.459389},
		{"1046ed7c38f6dfe57cf3666bec4a779d", -279.319031, 86.997299, 133.027405},
		{"c0d1dcc2c82be9014509b6d9bdc9b1a7", -245.294159, 169.509232, 135.109329},
		{"0fc830a5c11699f052e06d838ef2d4ec", -276.361877, 56.787273, 140.075027},
		{"a97bf3846b8d1f6ca6e943c93d2bd1f2", -254.413040, 45.248081, 145.805389},
		{"912f27cc89b2249db807d0482f0c4608", -244.373993, 61.970634, 149.079987},
	},
	["Shadow Labyrinth"] = {
		{"71c1352e679e8a1b3485fbb9629719c5", 4.926779, 163.467026, -16.989702},
		{"660db21f8536fddabff892618c9fb5b7", 4.926779, -92.532974, -16.989702},
		{"59e794aa4a7933c3f6dda00bbb67c0e3", -161.927322, -101.251701, -4.100524},
		{"ef083d460f5fbcac9bc160e98cbac9ce", 101.828300, 207.164368, -2.312078},
		{"8d24f08a8578e21803152aeb636c3df9", 113.422218, -148.363861, 0.364982},
		{"72f45f287e481d927fdca773886e7c96", 198.431259, 249.630295, 6.839122},
		{"6f4b9772da5ecbaa80e3c29a7f376fc2", 239.407639, 207.164444, 6.839122},
		{"62c8ed6a573f3cad0c67759d3c13b8ea", 239.408524, -148.364044, 6.839703},
		{"0e57e0904b3597b1feb3ddf70bf4f333", 198.523392, -156.590790, 6.839703},
		{"d3c0eaa137281d5ac98781579c4d0312", 423.209595, 114.766357, 15.999954},
		{"9f0964c8de94523ec8af167b91eb51ad", 679.209595, -141.233643, 15.999954},
		{"ac3cb731b904e359d4d7317fc85fb5ef", 679.209595, 114.766357, 15.999954},
		{"2fe877fa19c3dca3a25373c39fc6135f", 423.209595, -141.233643, 15.999954},
		{"8a6776750b54d1cb81cbfb75e91e88a1", 231.675186, 199.527744, 16.065296},
		{"8feb5cc69e4c20287e67ffbcd4b31187", 231.675186, -56.472256, 16.065296},
		{"e7f5e89dc7fe772ed13529802a03695a", 396.357788, 55.075329, 16.088047},
		{"5b1418e75efc1898b2b39c6fdcc7d752", 654.745178, 132.447662, 18.009569},
		{"663bf45aa429a4e0a775705767dbd5f3", 654.745178, 388.447662, 18.009569},
		{"b77448f2dc39b2dad127ba3e2aba3e86", 910.745178, 388.447662, 18.009569},
		{"396eeff3c2af1c51e2c44bc199209c83", 910.745178, 132.447662, 18.009569},
		{"0eebc9b1c640d394b3b25f538c977d80", 434.574097, 434.754761, 22.651035},
		{"a74631c9f1d93925fc05e928b6e1263c", 690.574097, 434.754761, 22.651035},
		{"cd394aeb7146060ce6cbc49a0f5e3c9b", 761.100830, 55.071236, 25.315125},
		{"4fa780c4cd775c262ef037cb313753e4", 761.100952, 403.182190, 25.315172},
		{"3c5901d74159f48b924c0c3cd999fb10", 202.684265, 884.839966, 31.507942},
		{"72b5f08afa3c32a9a2ea84406ccd0a3c", 202.684265, 628.839966, 31.507942},
		{"6bbc062a67ea1dc2ef52601ef19a4238", 290.098175, 504.358643, 34.110077},
	},
	["Stratholme"] = {
		{"6627ca5b7e46155acc03cd77e2d04ed6", -1098.184937, 374.848267, -180.823471},
		{"586882efcf4a8a2071c6d445d8ed1d05", -1354.184937, 441.330994, -180.823471},
		{"96e481c561fce432c83b10901265707c", -1354.184937, 630.848267, -180.823471},
		{"06c4e82f60bfb5ad96f2383cbdc7f1a7", -1354.184937, 441.330994, -180.823471},
		{"6ea35f4472ee79b802d3151a02b343ac", -1354.184937, 374.848267, -180.823471},
		{"1922813213806c32ad923e1433f9ba10", -854.495850, 333.880554, -163.713089},
		{"17d45c2232bffbd800593afe52c61099", -1110.495850, 77.880554, -163.713089},
		{"bbd9350012bc213f95f57558dae7f1c4", -1110.495850, 333.880554, -163.713089},
		{"b5ca259bc111246ec3ca3dd78431acc0", -1005.361145, 99.677475, -163.713089},
		{"a67116960070d219a4cbb08100573ae5", -919.880005, 99.677475, -163.713089},
		{"f1967bdfe14486d3289ceb4b74fd038c", -854.495850, 77.880554, -163.713089},
		{"2879219a9392b88fa9feee103ead20b8", -935.050537, 601.174927, -155.950317},
		{"41023dba46aa98a7b312cb10d4b5bd01", -935.050537, 601.174927, -155.950317},
		{"447b1fc3b6612711de47fe9db7b819d2", -1107.976807, 434.358582, -155.950317},
		{"5fe2d8ea942de72ccb31887a8d52b0c8", -851.976807, 434.358582, -155.950317},
		{"ff7c2dc13521c53d5f95f7a638ac9718", -851.976807, 690.358582, -155.950317},
		{"6c91921f0030df0d4b099d9fc976b77d", -1107.976807, 690.358582, -155.950317},
		{"116c455053a4c878db30c585424b6366", -1150.975220, -211.419647, -155.628998},
		{"919a55ba9fda3bc59e1033c28b60974a", -894.975220, -467.419647, -155.628998},
		{"69527debe7487c00c54f840fb8b35ba0", -638.975220, -467.419647, -155.628998},
		{"4c5ac300e4389aacfce92d5c113b6f81", -1150.975220, -467.419647, -155.628998},
		{"a8e8d03e76beeb2dfb2cc61205c89748", -894.975220, -211.419647, -155.628998},
		{"23350975d3bba574e81475058d95dac9", -1374.098877, -67.298882, -121.132019},
		{"5a058c766ca203446beb102bde0b610d", -1374.098877, -67.298882, -121.132019},
		{"4e9bda7e88c2c729734f090922aa31e3", -1374.098877, -67.298882, -121.132019},
		{"772354b64b957581522e566ee9199582", -1374.098877, -67.298882, -121.132019},
		{"b916dfe93096e48b913207015ec79cce", -1118.098877, -110.557854, -121.132019},
		{"6ade11787cf7c2a231874fcfdbcec134", -1374.098877, -110.557854, -121.132019},
		{"1ca42c6abe4c83ca8773b39c55c74864", -894.975220, -77.880615, -111.288651},
		{"4a9d6ab794d2a21fc092c5ee3d24107b", -1150.975220, -70.514137, -111.288651},
		{"7389fa6d6b26761f27bf6f48478be0c3", -1150.975220, -63.046612, -111.288651},
		{"c2bb58c4863c300b2d64b8e28b0d1a2b", -1150.975220, -77.880615, -111.288651},
		{"032cf5d11d4c24b24e0957221ea57087", -1150.975220, -126.306076, -111.288651},
		{"da0603d29dced9648534912edbfc6465", -894.975220, -126.306076, -111.288651},
		{"85dc8afc90dc2379c9b96342eef88761", -1150.975220, -55.835701, -111.288651},
		{"6a0f1ec190e21665a36b12672f475e95", -1145.057739, -210.559158, -106.195450},
		{"4e05b27bb6a8067513b6b6831673597b", -1401.057739, -210.559158, -106.195450},
		{"ac7f7016e904388180a3a5c8d006b90f", -1401.057739, 45.440842, -106.195450},
		{"dbdce10f160202b2982e47dece347354", -1145.057739, 45.440842, -106.195450},
		{"64f452dac6ff77030212903cb2161fc4", -145.450317, -78.400223, -102.763618},
		{"4ec5f7747ae254348ba001d1359a21dc", 110.549683, -78.400223, -102.763618},
		{"56efc969ee776cb09175208cb5f2d0db", -1328.812256, 205.906830, -88.599442},
		{"5ad91659b782d183d734499e7eb17745", -1276.258545, 216.356873, -88.599442},
		{"de92b0e874d46a043f67bab910237fc7", -1276.258545, 199.204178, -88.599442},
		{"317619ea3c02b6677ddd29d9fbcc1f42", -1020.258545, 216.356873, -88.599442},
		{"39236f79c3f138d159f97c0580269f5c", -591.101807, -630.388611, -88.136383},
		{"1b706b4f013ad1a6f81be407b4d51f4c", -329.513672, -259.387512, -88.136383},
		{"5f49d00b5b120aad08410656ed231d5d", -588.614197, -289.792786, -88.136383},
		{"37e38bb61cce8098603c3e1bac5d76b4", -588.614197, -545.792786, -88.136383},
		{"c6ff9356b3e94c89b17036764e8d9dd4", -585.513672, -259.387512, -88.136383},
		{"91d0c4fab8c644db7e622765ff39ffc2", -591.101807, -374.388611, -88.136383},
		{"1d3988a1bc5f5d50b73ad6b5e157899b", -335.101807, -630.388611, -88.136383},
		{"4cdef6083aa32485eb11908033092032", -395.872437, -330.845581, -88.136383},
		{"75167cd7886432d85435e986dac60d85", -651.872437, -330.845581, -88.136383},
		{"b2c92b55404dbdcb5b63b867932d9b14", -335.101807, -374.388611, -88.136383},
		{"68fc7fc4815e836da864a67b75ceabf6", -310.262634, -5.269867, -87.432693},
		{"ea3e85507ab1ad8f1f115040ed5fb1b6", -310.262634, -164.369675, -87.432693},
		{"51e281f86e5773caf844bac8544601c1", -566.262634, -164.369675, -87.432693},
		{"4db112d390b06e1920710272bb8c5d08", -506.301117, -270.509827, -87.432693},
		{"847d148717dd95adfaa0d0d1c63dc6c5", -566.262634, -164.369675, -87.432693},
		{"0f04636038f8ac7f19e3f9f20b971c04", -566.262634, -261.269867, -87.432693},
		{"9b30b53e8c3b3f9b59855423ec538bf6", -310.262634, -261.269867, -87.432693},
		{"957fa65e8d595a7436779e4226f4c53e", -45.246552, -261.269867, -85.854095},
		{"6d8506185ddef97e089b134a67270dba", -301.246552, -261.269867, -85.854095},
		{"9e01bf8073dbcdd06185ae5e5b776d75", -45.246552, -5.269867, -85.854095},
		{"84aa6f6669088e6a934a3ee14d23a736", -301.246552, -5.269867, -85.854095},
		{"20bef307f01d0cace6a9d3eaf75a8479", -473.154388, -536.371033, -85.283752},
		{"c9c2adc75d4ad2ef2e1839229c096cc0", -518.423523, -497.104095, -85.283752},
		{"e6ee3a98aa0a4fe209d6178f6d061fda", -632.599915, -131.798431, -81.127968},
		{"a731461c65eaf0d7d95a89607afd2750", -366.765320, 75.076599, -81.127968},
		{"9e636054f8cab44c1085651a549e9276", -376.599915, -131.798431, -81.127968},
		{"6248dc343d0d37f7c30c6976dc8f67ca", -632.751343, 52.490891, -81.127968},
		{"bae4d285cffcc103dca3d0bc1902c690", -655.937988, 53.416866, -81.127968},
		{"a97e29004121843e7815da50df9cfd36", -622.765320, 331.076599, -81.127968},
		{"a5a454e41c9b4d46d440238af86db909", -622.765320, 75.076599, -81.127968},
		{"a82c87d0372fd0cc18d05c1d3a30f02e", -366.765320, 331.076599, -81.127968},
		{"7c9063f6e02aa017856dc390a988c3f6", -632.751343, 65.080330, -81.127968},
		{"4d370bb78d215c7e10d3a8c19ac5acd9", -632.599915, 124.201569, -81.127968},
		{"eaf590054552a9a691b35545bee0507e", -1110.495850, 157.298660, -76.672073},
		{"63dfef64e6edaff90bbd3d7826792e50", -1110.495850, 270.479034, -76.672073},
		{"719e00cf068d039e0988aa16d54e9b6c", -1176.967896, 282.583435, -76.672073},
		{"5fabb032e64b90d920846ac05c315671", -920.967896, 282.583435, -76.672073},
		{"cc3e449a402964f740a7707a1b72c5fe", -145.450317, -78.400223, -74.719231},
		{"c5599f06e1cff779ea66873bd40bdba3", -595.976807, 277.815063, -67.748878},
		{"827eb327cf9379d9a58af59a1bb7271b", -1107.976807, 441.781738, -67.748878},
		{"15ab9b01dae382d835d404661bbe4cfb", -851.976807, 533.815063, -67.748878},
		{"8235e212a2b76b774c54c1c56022ff39", -1107.976807, 277.815063, -67.748878},
		{"fe8143b5083ed9f502d7be1d78ba3e58", -851.976807, 277.815063, -67.748878},
		{"5bd757c7979774a32003a94404634b09", -1107.976807, 388.055573, -67.748878},
		{"60e712ff9a9d15000b60d6df7789ec6c", -469.333130, 89.009995, -65.797676},
		{"99c8f44a945eb6ead71fb58208fd014b", -213.333130, 89.009995, -65.797676},
		{"abe555087463282ccfc82b56cdc34258", -213.333130, 91.368904, -65.797676},
		{"b62b296ce5d68e2e51f2d4e7fb14e162", -469.333130, 91.368904, -65.797676},
		{"d97cc930db73ac8a790f6957e57e6343", -511.850037, 355.615967, -55.348648},
		{"213e61f4a80f6a1db5a34704e2e1da13", -372.356567, 587.234192, -55.348648},
		{"65969b6e0763eaab6bae0fef61383022", -511.850037, 205.007751, -55.348648},
		{"dff6527238d6f1475f54f408bbbf574f", -628.356567, 331.234192, -55.348648},
		{"32562016a290854faa84d1ae4d8f319d", -628.356567, 587.234192, -55.348648},
		{"ef974ab7ea268c4901f3203a718dd653", -372.356567, 331.234192, -55.348648},
		{"97f40f8c746a0fed0c468157b3f9aaa1", -355.773987, 89.009995, -54.513153},
		{"48c5609c0ac50cff2ec8c4c86785247e", -99.773987, 89.009995, -54.513153},
		{"a82437a8f013e11c3f51cd6105646b67", -355.773987, 89.009995, -54.513153},
		{"dd3fc21c585d74d31596e04e62bcf68c", -1026.026855, 12.805107, -49.430115},
		{"85c1b1dc7b1859fcc7081c6836517ba5", -975.953003, 15.429086, -49.425297},
		{"81e44fbe02a4d269c89f4ca94d807bed", -466.209656, 450.847443, -48.155613},
		{"4e07679a8a8b52a3013ab006b6f3045d", -466.209656, 450.847443, -48.155613},
		{"6941d8deb733280e94f8512d0c012e52", -466.209656, 450.847443, -48.155613},
		{"97d23edd7f1d2de48609ec666a2093b4", -897.095154, 156.042068, -48.072701},
		{"10380682bc4919c2121972e88fb72203", -572.845886, 396.658844, -46.085724},
		{"b0bd3e0e03dc73934aaedddc15954a25", -329.833435, -396.064362, -43.788895},
		{"c246aad554fb82b198f124d213a5aaa1", -699.361450, -9.967423, -43.624454},
		{"4d433304af28a1d9cf15109d59d4dfe3", -289.827362, -902.836487, -41.009148},
		{"e89a3846cf18d9d4ea04a07d8f6cc7e6", -846.970093, 365.622406, -40.389156},
		{"fb24b26a57bcde2cd8aa125b190eed2b", -237.216263, -702.754517, -39.157196},
		{"040bdd264fb059837a314753620a5b09", -773.198181, 405.093567, -35.335903},
		{"ca8fe35429a05351f9c35dc058a4f2a9", -773.198181, 259.872803, -35.335903},
		{"822ee13ae86b0ee40f9165b16be96da5", -773.198181, 391.782196, -35.335903},
		{"dcb9512c4af4b5accd62aab6ad43b197", -1101.816284, 505.188995, -26.941563},
		{"203de6531810354b3e4599fca02aea4f", -414.528198, -630.059937, -20.668661},
		{"00a8a44fad570cdf12237d178396bbe5", -408.131317, -567.441284, -20.668661},
		{"11a98a15d567df7fc2e2cf667030564d", -435.442017, -584.364685, -20.668661},
		{"ad3721aa12517b632239d8f972755deb", -272.204376, -667.739319, -18.907331},
		{"f004d394bde02a8fc586165edddd3c11", -215.228394, -635.641663, -18.907331},
		{"2f119c8c0a28a45e1c7703734aa51def", -240.222717, -647.423889, -18.907331},
		{"4e475fa642aff5a5e1b4e73626982672", -134.321869, -638.371094, -18.907330},
		{"d7ad3ddfdfad0ff5794bdafa5e6ee430", -159.274353, -655.847168, -18.907330},
		{"c837c1bf1f94746b4177e468e70827ef", -192.006851, -676.653809, -18.907330},
		{"8513d5f9e5df0d1dd31afadfa169e282", -109.361526, -620.893677, -18.907330},
		{"b2cf3c057e7a64ddc0c64620a86d26af", -93.123466, -667.659241, -18.853985},
		{"0850f6d2d88f78a315cf2702ce2885ff", -319.487579, -646.160522, -17.501129},
		{"16be330f05bca51c749ab34c7bd14981", -353.863953, -529.581177, -17.495661},
		{"33f8ee87b60e310286daa2ac1d6c57a6", -123.960396, -586.561646, -17.490831},
		{"9c2e6d348dc8f487b228682be42f7a71", 4.829518, -693.856384, -15.829473},
		{"4a68d37e4fcc28877657e8b4eb754d1a", -68.631157, -592.508484, -15.734319},
		{"8e94cefed4dd6cb48da7877fdedfdcc4", -32.459118, -567.180542, -15.734316},
		{"835f71d5de7ba21c703ba12d340ee989", -312.713654, 533.991699, -12.243218},
		{"2a152cffb005c4a5a79479e95a0e23a4", -893.837219, 719.348022, -8.624312},
		{"bb9656f4e9a3813488fa821ec5c01aeb", -1233.406738, 556.909119, 19.061584},
	},
	["The Arcatraz"] = {
		{"cf19a1ddeb68c6097ad670989d8d004d", -647.912842, -134.383743, -1868.487183},
		{"0daa7cca1fc692b998d0a550f056f831", -653.656677, -140.916458, -423.698547},
		{"9b08403e19aaf9d39688407163c40daf", -653.656738, -140.916458, -172.877121},
		{"1cc76f8d93d93a9ccf48a8e8fe6fae6c", -451.565674, -203.332306, -118.589752},
		{"125f8d56f6be26f79a7b1089c7cb4d19", -682.607361, 135.488205, -39.051506},
		{"c9bb5df18df126f03d1a0e2e71281535", -426.607361, 135.488205, -39.051506},
		{"f3a72e79071ffa4accbe19515a22d580", -682.607361, 391.488205, -39.051506},
		{"e5f6d7ce956f9efec9b6caaccd51fa29", -426.607361, 391.488205, -39.051506},
		{"231ca2d69e0409eb18a71d490db61324", -489.944000, -80.779015, -35.732616},
		{"7690739cc9ede2c15ac94cd574c412cc", -426.683472, 147.184753, -25.995443},
		{"fd7eb8170c4dea15db3c6e7a00621f6b", -317.568726, -20.240322, -25.995369},
		{"39c3b5658e60d2bf6c80e7085dfd534d", -481.260254, -190.394745, -24.879320},
		{"f74cb3a0469ba70c4607b8c29b900c47", -481.260254, 65.605255, -24.879320},
		{"ff86f6c96bef4578bc6464296223f82c", -737.260254, 65.605255, -24.879320},
		{"b913397ebf33de4c29a7fcc4003a387d", -737.260254, -190.394745, -24.879320},
		{"8b50df8cf5f3520a5e378f4c8f8d92d5", -51.673828, -146.398087, -22.330986},
		{"9972b20d377518e130f307ba463073e8", -307.673828, -146.398087, -22.330986},
		{"b48007c68f881e6487e33470a75d30f5", -307.673828, 109.601913, -22.330986},
		{"dce11b8fb3b1b4e59d5dc6597f60f7f4", -64.540840, -85.031731, -6.201970},
		{"279e629e8da6f6d2687d86031caf0c94", -684.469543, -377.503235, 28.920925},
		{"ad8dc9415bf81aa0f10f468edcc7a2c7", -556.235046, 67.982033, 38.949036},
		{"dff5fbbc12c17745234331a1e949bebb", -471.016602, -226.893646, 39.893730},
		{"d0563ef59c47d38987f3cdfe99dfdb46", -215.016602, -482.893646, 39.893730},
		{"038a20a6fca44aac4f51a9e23cce2e33", -215.016602, -226.893646, 39.893730},
		{"201c53b1217782751a131ded8aa318f9", -471.016602, -482.893646, 39.893730},
		{"16d8003f07d9e902c943b815874cd5ed", -621.049866, -205.127655, 44.393684},
		{"31a07152023421789a81d65c342c3f6e", -493.175079, -311.688202, 44.493656},
		{"67045d326419c4274b2bf53e712c2fa7", -416.663391, -237.284836, 44.493809},
		{"ef2547e3e2d9e0bacdbde9bf91bb9067", -1086.064331, 101.304214, 76.227348},
		{"27e22c653efd213e0c091d9c1a7f1976", -1086.064331, 357.304214, 76.227348},
		{"d1050ee304148748efac35448a8c403e", -830.064331, 357.304214, 76.227348},
		{"d0488a1c90305af802e30c2717b80833", -830.064331, 101.304214, 76.227348},
		{"b5592aba9f4cee15488f654a33cd9ee0", -975.526062, -124.659172, 80.897087},
		{"ef8b02baac222de79f755d5c8cd233e1", -803.150391, -63.856251, 88.853699},
		{"c34fbb6f200de3863d00939a32d24936", -447.428375, -86.570778, 96.369690},
	},
	["The Eye"] = {
		{"7a4b41dd709ebaaddc36d22e9a55e3f2", -519.750854, -82.778732},
		{"3ad656117ef2cb827caf53cb5ee1f148", -263.750854, -82.778732},
		{"db823e312df337a0a849fa513d02909c", -7.750854, -82.778732},
		{"c6bd5e566f0a0b726c8484691d6f196c", -1737.741455, -164.410873},
		{"4f36febd5c42cd8f141c00ee20bf6f4c", -1737.741455, 91.589127},
		{"6c6e0cf044b0c70c840630af2935c036", -1481.741455, -164.410873},
		{"338feec4d306286673cd3e26739f646f", -1481.741455, 91.589127},
		{"b87ab69423b543836ea139ce830d4768", -1225.741455, -164.410873},
		{"47196febb5d595f53f92b1d5ab742584", -910.116638, -240.999466},
		{"5dcf26c41b290ba937aadf258b931822", -910.116638, 15.000534},
		{"23829ace9c30c3eeaad8a61e60f0b10c", -654.116638, -240.999466},
		{"21ade45724dd35de50afa65c7d24a8fb", -654.116638, 15.000534},
		{"5d5f12833e02d50562f9e444108f5947", -1363.457642, 84.571495},
		{"efa471119464e5a1ff8c16b3c79c7fb7", -1107.457642, 84.571495},
		{"31fceeaa990a4b081225e884e5d891a1", -1103.475220, 93.353699},
		{"2be365f29befa51394de2420ec95ec6b", -1103.475220, 349.353699},
		{"5f45789b1baf8f3e03ab31b96585e983", -847.475220, 93.353699},
		{"a95e636c5226ebdf2a8c89c3e509ff70", -1363.457275, -312.244019},
		{"065e9f8a368f9dd7ffd5efb05d2a9423", -1107.457275, -312.244019},
		{"16aa7d8d5a583a8112c88034f53a5475", -1103.474854, -567.888367},
		{"9192af90ffa7180b58fa4ce1ae8ccbc6", -1103.474854, -311.888367},
		{"edd88951b03ce129b1e048031136b5c2", -847.474854, -311.888367},
		{"2439e6d71f6f345683ac1afaeeb6a9be", -1114.564575, 497.707977},
		{"4b468193b4b52551567c4d0991740e87", -1114.564575, 753.707977},
		{"e1d32bdd56a9a843abeaf3850e82caa5", -858.564575, 497.707977},
		{"b4cb14be86fd661e27ff8836fe0acc4b", -858.564575, 753.707977},
		{"ab86ebcc371cca02448ccf7f0823c5e1", -1121.724365, -990.922546},
		{"b6e2c16477babeb764d2cb85076f6e88", -1121.724365, -734.922546},
		{"1c0c81e44499e889819912aeed9a00d2", -865.724365, -990.922546},
		{"c75215a5905a901596e16ea27a7beaac", -865.724365, -734.922546},
	},
	["The Temple of Atal'Hakkar"] = {
		{"68ad7e1c5bdb2e0c205e41d65b3fa1d2", 1055.109192, -335.240204, -379.515015},
		{"16a8717f17adb9cbe245817fa51d6da1", 799.109192, -335.240204, -379.515015},
		{"ca4aee04137d53a6820842fea04b5fb2", 799.109192, -79.240204, -379.515015},
		{"7e0ca2448c819567dfe967187da66963", 678.745667, -219.489929, -346.359619},
		{"4eb08460af498345d8c8beb21e163fb4", 555.675537, -273.037628, -346.061523},
		{"8b96613272f9a977c4b239ed85372fcb", 620.778564, -207.157715, -346.043396},
		{"dd7cbcc1fac093f60e7d3585f4de3e08", 570.287598, -332.751770, -345.985718},
		{"47f9701ab7bb3977125c0b925acc51e3", 599.717407, -338.973724, -338.509644},
		{"bab999a197b9f0a96c1f3e5694994c41", 571.343506, -327.387512, -323.556152},
		{"3c9b4616aa2bafcff96b57335a79a37f", 751.551514, -374.995056, -298.632629},
		{"906df5ce6246aba886b9acbb3e418be4", 675.386414, -304.927490, -297.930145},
		{"d7e8211345562d5dadb89f21b4264453", 716.583984, -299.173370, -297.834991},
		{"6ec7c09f8bf7bd108130b16d954a2836", 831.276855, -405.056854, -297.818939},
		{"159b6a0ff16e32e75e81889be6341c2a", 751.175537, -102.808815, -297.787506},
		{"060830deea29611b0f3b2d0fbbe7d725", 1086.745483, -385.213654, -297.757111},
		{"83b7092544d1dd85a5e1f5835e882eb5", 770.850769, -165.583740, -297.740234},
		{"f5e6f9ea6bd78a2bc3afe09479af9fad", 764.128418, -185.509583, -297.740234},
		{"2847e436baeb77d7a19e8184120204b4", 713.195923, -59.493134, -297.738983},
		{"291bfc157bffb928b50ce495427df3c6", 1021.068604, -106.112816, -297.669312},
		{"e298933f5ba35368cb427f0243ba5d92", 1089.061157, -295.019165, -297.665405},
		{"19f8637f41a3ecc34805fe339e261914", 1083.866943, -233.620941, -297.665405},
		{"d33b7a463239c7e30970a371dcc230e6", 1053.474121, -254.766144, -297.665314},
		{"0d4f9a8e1c94b576ca3bec7afd0b74df", 802.374084, -311.031769, -297.661957},
		{"ce560c8be88c74e99792957540e83be6", 814.907715, -336.106049, -297.661896},
		{"22b267c652ba95e75afad9095d041a6d", 938.772278, -405.898163, -297.661194},
		{"a1232975d22118ca49ae63a21520b09e", 952.225403, -359.510498, -297.660278},
		{"c72c5f6776d67f56198a441b96151bc2", 974.830627, -353.145599, -297.660217},
		{"669cef78f36b263809a70e832cce5ef2", 1020.094849, -81.646729, -297.660187},
		{"03d88d81e4bde67d354fb5deed1cfc21", 931.953369, -34.540539, -297.660156},
		{"765435d5ce34c0054b76b0ea60c72fbe", 1134.256348, -142.970123, -297.660156},
		{"ababbf7dad288d4a90b93f4a751ea857", 1023.391846, -98.630943, -297.660156},
		{"10a7ad38cd0bed99a421469c454d9c36", 1091.289551, -188.590683, -297.660156},
		{"caf427162706bf791452882eda8df553", 827.091309, -36.244389, -297.660126},
		{"04c7aace77f6fa892462a10688eb0856", 719.388123, -194.269501, -297.660095},
		{"e704feddd21e8bb292d973c70611ff26", 1027.580566, -374.667511, -297.660095},
		{"61dedba3592a0b0b18fd13795d3dda81", 888.267517, -71.411430, -297.544922},
		{"ae844a312d4518018b557fa323dae1ae", 707.166809, -329.137970, -297.522400},
		{"f1ac2f036aee2c7f95e451ab4fc93658", 1116.140137, -332.643066, -297.349457},
		{"3aabf5f28c7a0944987160caf47b7f61", 716.854126, -116.455406, -297.331238},
		{"e3dee3b60b059681edc39f82017da400", 856.269409, -52.756557, -297.254700},
		{"3fd5088a898b77e492ae0c073d3c9adf", 1095.897827, -94.550034, -297.252380},
		{"826bcfc2e0632bcf3d647700bf3288ae", 592.389526, -339.030640, -286.172211},
		{"d9fcf5d4921f9fb17828db69e17f1f50", 490.332306, -211.492508, -265.396515},
		{"1e0576984a415143d41ff78818fb3bd3", 753.166321, -364.870697, -264.415802},
		{"d8834c47a7e3770c5bc21297ceb4dbfc", 759.274841, -319.036469, -263.806274},
		{"f81da85d5f24f45bfe00d8bed5f19a1d", 646.687439, -148.227631, -263.795990},
		{"8433359621005fa758cd2ab8d0387a12", 721.642212, -194.420044, -263.793793},
		{"2957cf0d70534a6d5b09d21c6596f3e2", 693.638245, -146.697952, -263.793793},
		{"21a3bc515d08d4a598370a7e9e519efb", 715.500427, -286.606934, -263.773712},
		{"e91597a89f38becebe72e08ca746847b", 624.411377, -286.364319, -263.772827},
		{"8bed667b88f7838daad025cec0c2fbe5", 608.496155, -88.890144, -261.324127},
		{"b5c65086249c35a399d9ca65e5e29ab3", 694.664185, -358.694366, -257.873016},
		{"e3d62c79e0deb75bb1d05832b23ec4e6", 1147.830444, -329.253815, -257.700043},
		{"1883c7f8b4a572cdbfbaefa1f6b559dd", 1113.840820, -270.136780, -257.700043},
		{"297674e6252207f76bf027b50cc290ff", 685.007446, -121.128082, -257.681854},
		{"26a0d54e7312817aa7f905ef025371bb", 1108.114868, -64.795280, -257.602875},
		{"d29853204781e86594d8fd5d312dfcee", 1075.025024, -72.915886, -257.602875},
		{"fd63ffea373a62218f40daf2bfb8f56a", 573.404663, -121.003883, -248.994827},
		{"2a34c9021ee726b9e6acc8a040e3f561", 582.965515, -147.272339, -234.040344},
		{"d29f0ca237a883c99e1086328fc563ef", 635.713928, -132.942535, -219.086533},
		{"27422d6b7d0bd703fe8c49e020c61c04", 672.309753, -339.861328, -218.210648},
		{"68d77df6e9f8d64c7f139ace5b55ff41", 705.912842, -329.012238, -218.183121},
		{"c7fd9c957842ff96d643303c0b0cebbd", 1123.158203, -360.917511, -218.037643},
		{"baa04aa6bbcc806afb2d2057dd469267", 682.736755, -58.519676, -218.019440},
		{"f42c475cebcd414cc891a18119bd0cdf", 1116.608765, -333.632294, -218.010117},
		{"4b21b73371058dcb9f7e4a229257424f", 716.812317, -116.000015, -217.991898},
		{"3c7c04231fd47bd32571a40ff7920329", 1153.839233, -98.953079, -217.940536},
		{"4f60d74cbd2a6f6a859f850071ed7933", 1096.323975, -95.945793, -217.913132},
		{"c2063d71670db5690839b67333dc7137", 569.647949, -116.963150, -201.510117},
		{"9f05f3b3868fee160d297b0c0953b221", 757.789185, -106.197723, -199.445084},
		{"9c240e6c65ca708b1df84c0ca875f2f6", 757.789185, -362.197723, -199.445084},
		{"db83f64cf2cf0ca9e3aee0c948180afd", 1013.789185, -362.197723, -199.445084},
		{"1b388ed71d479535e57c4a7df6b7d688", 1013.789185, -106.197723, -199.445084},
		{"915765d60521de7463a8b9179819a50d", 742.395813, -72.293091, -188.254364},
		{"65b4cefa902514b137f54bfbc05ab4f8", 554.336243, -206.535446, -183.280563},
		{"95de2a8304f35ec576db24ad2402a20b", 616.661438, -216.904541, -183.000961},
		{"8625883de0f4d32450d5959859d5f12c", 1225.039551, -73.737968, -182.530609},
		{"cbc9c2cbea998eb3e49040b1ff16c066", 815.845276, -648.192444, -182.515442},
		{"09d5c27328fff7e5575dcb82608bf6ae", 834.261597, 75.220505, -182.515289},
		{"a737f0714d32e5d7569308ce2628ba76", 978.845398, -485.426147, -181.881287},
		{"8792eea1b455e15156abb82691b58f7e", 1093.980469, -233.203079, -181.843216},
		{"d74cd0cc101c8b96b686646931148ac3", 740.244690, -485.487518, -181.842377},
		{"7b67aec5828a9ee9cd4f9031cf075011", 978.678101, -71.772331, -181.824158},
		{"205356a3d4570a7f4b36ff691ef08dd9", 1052.088257, 66.136742, -181.821686},
		{"6edd07426b25b5bc8339cc0cf52850f6", 716.013062, -608.320374, -181.821625},
		{"857c72346c9864ac478d9416fb30be3f", 1052.234375, -608.320374, -181.821609},
		{"b3a1cd9a9a1974eda4b888e2bf6927be", 1251.759644, -304.806305, -181.821609},
		{"9e85a5ccb27bdd2c39560aecf0392c2e", 753.148865, -362.888123, -178.540237},
		{"620b4e1fcb6428c355ba7dff7df8c0ef", 694.949951, -358.740021, -178.540237},
		{"33b95ac723d9395471b3f7d2dffe34bd", 1147.697998, -328.865143, -178.367279},
		{"d1706bff9157a572744cf67ff7f6e0fc", 1113.903076, -270.594025, -178.367264},
		{"50d92c60860e870fdcb6ce21bd3cfb97", 685.148560, -121.123116, -178.349045},
		{"47fd21ad75525c1c69552ff6acc27e97", 693.640320, -147.665985, -178.349045},
		{"7bbff6661b42428464659d4a98c981e0", 1108.308228, -64.412079, -178.270157},
		{"e94353bf7a973e86babc587d7429ea5f", 1075.450806, -73.094231, -178.270020},
		{"6ca354fbb2ff15a912182f0d7c4a28c4", 672.443787, -270.344910, -140.743896},
		{"b45703460fdb1ac86b943c0792f5a6b8", 1065.696411, -385.727753, -140.570923},
		{"a1d6d8c60ce761af5dce8f5447988022", 740.938049, -30.560961, -140.552826},
		{"61f2dc575b27138e86cf2d80c9d49b6c", 1149.190186, -164.725143, -140.473816},
		{"bdad447c40eabc11a2d1c0a827b12353", 692.667847, -306.167114, -139.031326},
		{"a8079cacadbddb726c037369c317d71b", 641.361084, -345.844452, -139.031326},
		{"0042ddb2ce7fbc616d2be1062094a346", 709.755432, -275.232941, -139.031296},
		{"3da00060b84be03f02fb0dd0a8da279e", 1121.107422, -403.675537, -138.858368},
		{"b63db772b009abe0b1115f6eabf12270", 1051.380981, -350.223846, -138.858322},
		{"565dc2cc3f51976e58514e6cca7fc352", 1097.422119, -352.852570, -138.858322},
		{"3a73a5bdf1e14c303cfc1cbc217c60de", 666.358826, -58.050850, -138.840179},
		{"290beb5e1048ab25f8d331ce440817d6", 716.867737, -78.683060, -138.840179},
		{"aac906b479c0db4735e5d3ef409dfcf6", 751.839172, -91.577080, -138.840134},
		{"494c797ef95f51d9ebed99f2ee5ed566", 1167.123291, -126.288849, -138.761246},
		{"869db83b9885dbd73f5a273e72a1fbf9", 1121.312256, -110.217270, -138.761230},
		{"c24f83467fddd979d85cf0b3913ab1cf", 1079.057617, -145.102066, -138.761200},
		{"af4d71925e65ea8d4ea02a13d8434290", 748.951050, -373.749176, -132.341660},
		{"d34233d4d2993225d3353bd4c8fee7c7", 967.119141, -63.348785, -132.331360},
		{"5a817ec291ebe603bccbede5b62b5c0f", 892.372375, -357.970734, -130.755951},
		{"7bb3df8b90a8028238ab27c9d95f6fd0", 953.140015, -38.796333, -130.745605},
		{"7121bb5b2593a9b6c0809be24f1be2e2", 1021.135742, -374.112946, -108.246483},
		{"8888731a3a53eaadf8c1d9d2b9847448", 711.298767, -294.081909, -108.178772},
		{"c36650a935916d0879d3e7a5c9c362fc", 1011.025940, -66.690521, -108.085274},
		{"a135fbd009eced8dd1c835e6901742e4", 749.277832, -97.704521, -108.066933},
		{"2c37718c52360e0a444d5824901d5120", 1089.403687, -193.338318, -107.948303},
		{"8de515e748f23d0538008b4840e051d2", 1025.085327, -101.897972, -107.948303},
		{"404feca9bdffe3a8a7d2c6d203dc0d08", 824.793335, -406.091705, -107.948250},
		{"6659ba029fa4be36c6749787e119c6d6", 1088.957031, -298.200531, -107.948242},
		{"ceafcc2d997e5bf55942fc4e1858703c", 828.926697, -33.549198, -107.948242},
		{"eaf5485c6825c8e534eda3960c55570e", 929.676697, -404.010101, -107.948242},
		{"8d4d4b57276b9bc3bd84033b3229921b", 936.604614, -33.993641, -107.948235},
		{"7464a5ec38b8698e5912c8d21aea556f", 718.867920, -186.519424, -107.948235},
	},
	["The Botanica"] = {
		{"112ae4cdd4ad23ee1c32a3675ea0bbe9", 114.120941, -783.303223, -603.206482},
		{"3d4b7e7ca60cfce2c7cd3eeac8c59e8f", 114.120941, -1039.303223, -603.206482},
		{"293c1142b201ed3eb1cc0baac6747380", -397.879059, -1039.303223, -603.206482},
		{"9405e9e3482e2c868d43d125ae82afdc", -397.879059, -783.303223, -603.206482},
		{"88ca3cdf3d353a937a86a33aaa0fffee", -141.879059, -1039.303223, -603.206482},
		{"c8c9561ca09aa7eabfd5e362b0633672", -141.879059, -783.303223, -603.206482},
		{"7de5efc41bacc2559b878ee1250b2cbb", -103.377487, -444.639404, -194.398590},
		{"fd57041d565d6589aa1736f01e5836c5", -103.377487, -700.639404, -194.398590},
		{"e3a275fda8cc3e953e53151e79af4750", 152.622513, -700.639404, -194.398590},
		{"5e0f50581e50e1c4f064e17895d21c7a", -141.656677, 147.651276, -51.704067},
		{"73a5facbc442595b1a50e14a0d9569e4", -141.656677, -108.348724, -51.704067},
		{"f7b21c0ed5b18e0cd94936ba8165d22f", -141.656677, -364.348724, -51.704067},
		{"412744887bed2a408415edda3d46db82", 114.343323, -108.348724, -51.704067},
		{"26b3221f03c0ecf778030af2ce822eac", 321.472626, -1272.317139, -50.423374},
		{"c9fcce903640ddf93e643c5bd6e29c26", 321.472626, -760.317139, -50.423374},
		{"7b12e8ce29ee260ee5e657767b9735e4", 321.472626, -1016.317139, -50.423374},
		{"c4bf656bcfc5216503276895aabdecda", 65.472626, -1016.317139, -50.423374},
		{"1e93a1c29ff572045af526d39e61013d", 65.472626, -760.317139, -50.423374},
		{"65bd038b5cdd216e9ee92cec8fbc1613", -190.527374, -1016.317139, -50.423374},
		{"57c8a2b7c5bf12c7399ae76817d54ab2", 65.472626, -1272.317139, -50.423374},
		{"1f36a75a559dd05a097c33693ed2fed8", -190.527374, -1272.317139, -50.423374},
		{"6198c5189d4e3af81a37fbf10104e3c9", -199.815521, -1071.371704, -42.988136},
		{"275c4050c8146a10ff6737425957a8f1", -455.815521, -1071.371704, -42.988136},
		{"04767e9f25e4d1bbdfa0557b64914b37", -455.815521, -815.371704, -42.988136},
		{"6dc30f7c855a4af6314a9a3eb57c21de", -199.815521, -569.703308, -42.988041},
		{"7243d15c202991be7e2e254da348059e", -455.815521, -569.703308, -42.988041},
		{"9e5961743ef2a85578a755be2bd78f3d", -199.815521, -825.703308, -42.988041},
		{"78ef1590aacaf58bead3aee1da7c8fcc", -455.815521, -825.703308, -42.988041},
	},
	["The Deadmines"] = {
		{"48391476676da0249606f99cf32ec356", -37.615776, -131.877747, -46.987022},
		{"86df045ed2e3b667a31522aebdce2252", 11.547643, -85.658669, -35.839390},
		{"4bf791ef9f430b322768b7c73c2e1bc0", 52.733494, -119.214317, -35.182228},
		{"f9ba5565d2cc56fce70bbf60c5dec228", 109.314079, -65.488937, -26.836327},
		{"6738bb214d1017d1c22aa9cdcebfba77", 67.629257, 23.007463, -21.217581},
		{"a828e50e7a44e10bfc529e39a081c8fc", -347.117096, -165.540054, 18.262430},
		{"5187e56aecd5e9986b52718eb7ac2f5b", 63.624538, 248.248993, 32.694668},
		{"380b63b65a59817c91c07d309a75935d", 305.131042, 121.620590, 33.834869},
		{"dea525f305818f23860699e63a9bedc8", 126.479248, 242.565216, 33.922356},
		{"54f281d5f983da821be43e83b79ea9d0", 220.931580, 218.899338, 35.711426},
		{"e021c27e3714daad81225e53167f988a", 252.507080, 100.795197, 35.738350},
		{"c4959ba08b22d08d5fb6734f439da670", 216.805588, -25.503174, 37.554195},
		{"f405cbf65dbdb81fef59e8940641bc7b", 90.526123, 171.927063, 39.091282},
		{"f3d722fe643880035771b530ac85d39d", 394.289703, -112.883392, 40.708019},
		{"13b9c1d880c4c181981471ed6ac085c0", 270.737030, 43.129215, 43.304020},
		{"f795ca31e5fd49cbbed8ef2192e5a185", 353.137878, 36.787910, 43.601082},
		{"f9895e19ba90a186c9f97ca87daec396", 270.844391, -8.249385, 44.875732},
		{"430f47b91523836508278dd2e0e6ea9d", 477.953400, -227.584885, 46.117268},
		{"5361f4ad01887325857959bece3d8c90", 579.198120, -191.154999, 47.648174},
		{"4ef6bc731a532c88c4ed535962cce522", 458.566254, 20.914680, 48.880680},
		{"8cf347b92ab4745b73be49f5ac7ad153", 512.735596, -294.380188, 50.332615},
		{"3336ca47cde9c036c8b89effc495b63a", 482.372192, -15.067723, 52.326027},
		{"9f7f9ad87b765f9e454666dd5e5fa7eb", 474.370361, -143.723587, 52.710560},
		{"c3e73cdbc8e50970c38ddc39309bf91b", 392.355743, -344.586243, 65.451981},
		{"b4c502bf72a863b3a934fbbaf007d123", 401.925354, -297.859772, 65.451981},
		{"796a823279dd565c02ddbcb91636eca3", 528.559937, -203.686066, 72.097626},
		{"b50840df8f56545ec92fc3c111ee3b75", 340.712921, -262.039551, 82.567551},
		{"b539ee6cb969df3b6cb8c799fbdd1b10", 303.490082, -210.640961, 83.623802},
	},
	["The Mechanar"] = {
		{"66dba5d8915c5d7d4d78e237044f4013", -557.933472, -211.171753, -48.518627},
		{"1aba6bf7b715b4cd7ddc968cc4f525cd", -301.933472, -211.171753, -48.518627},
		{"de63a2ecc9978c5b70bad897233651c0", -557.933472, 300.828247, -48.518627},
		{"1a96fc404d8ce217e12f23ab32bd412a", -557.933472, 44.828247, -48.518627},
		{"a8395924d376264c9d7661a2a240be54", -301.933472, 44.828247, -48.518627},
		{"c0bea4e2aa6d3f150c2041c0fe597fd2", -301.933472, 300.828247, -48.518627},
		{"418382d59d9ce61c4d19530e0313840a", -388.637451, -411.207550, -46.989010},
		{"324adca5e8b192ea76a68207a29e801a", 67.435951, -68.369606, -11.000019},
		{"f72eb98030998ac3c768660eec44b30f", -112.181572, -89.577499, -8.961505},
		{"33cc89803f5b3f5a8e268f73497fbee0", -531.211487, -119.625046, -3.756578},
		{"f2b9786c948262e25c0d1157adeb3d41", -79.458366, -140.289978, -0.055562},
		{"073e276e6c0ea8e4d2dde065e480c7ed", -79.458282, 81.667564, -0.055559},
		{"12920ec498e8535721bcd58208f662fd", -97.994499, -128.843735, 0.270569},
		{"871b6774def12488305f2116a3eec723", -97.994980, 103.185562, 0.270569},
		{"920287df8b33cff8ca780e81641d2b91", -699.972351, 65.929688, 12.136138},
		{"44fe3c958555b4d8680acb4bd9e6c07d", -699.972351, -190.070312, 12.136138},
		{"d0e8da3697aad1e01b864e792c0af7e2", -156.482635, -367.532410, 43.786301},
		{"99ac200108ec93f001783e17c0e839c9", -534.736755, 25.809828, 52.601219},
		{"c47a3269e065aa46e1bbeda20c6c6e72", -295.963867, -230.174622, 52.691021},
		{"b62394a21cb1b7cb5941ea2b9386eb0d", -547.036926, -198.646606, 187.981171},
		{"9e8eebca16d6dd2423f2db3e8e1d3ff2", -291.036926, 313.353394, 187.981171},
		{"71748f2710ec25c216f6aef0fb065488", -291.036926, -198.646606, 187.981171},
		{"3775ef56c64aa380bbaca739330fc69e", -547.036926, 313.353394, 187.981171},
		{"2c40aef3bb33dc88988e01581926e2a4", -547.036926, 57.353394, 187.981171},
		{"c196c01c69518500c5a4b136955f65c2", -291.036926, 57.353394, 187.981171},
	},
	["The Shattered Halls"] = {
		{"f94b790ee084c9dd9c74efccaac896e0", -459.110840, -456.304077, -98.816093},
		{"6b89c9b3168d96219d80c6558e5f893a", -279.151398, -550.683472, -94.505424},
		{"aa23942b64efcf5c391dfe5f0730ae19", -436.118225, -622.210205, -44.223709},
		{"57655abed220b37c34de2346d28d8602", -436.118225, -366.210205, -44.223709},
		{"965e6c209c18084ec584a507cb4ffdff", -585.567139, 286.549036, -33.125683},
		{"86a27c42d521e78dc3d086fe9b85f4b9", -585.567139, 30.549036, -33.125683},
		{"72def93d0b5bd041e87b858ae3d363aa", -329.567139, 30.549036, -33.125683},
		{"c5529b669f95d582454ad21ea4d2797f", -217.063324, -592.074585, -30.922852},
		{"dbf2937b65a362d1b670a8b631915419", -217.063324, -336.074585, -30.922852},
		{"2a136a1203238619c1d6bad5020c15dd", -174.862717, -80.830841, -26.506414},
		{"020f278033fbf1913287f11e29282157", -585.649719, -668.293213, -26.504034},
		{"4151c31043e77dc568de40720fe693f4", -1154.834229, -298.912476, -23.367483},
		{"681286dfc94fe5dee3f6156edd83b135", -1154.834229, -554.912476, -23.367483},
		{"9d3d64d0c772e8954f3e6db65bc0806a", -898.834229, -298.912476, -23.367483},
		{"59a2852c2775ceab23bfff89497e8fc9", -874.519592, 2.515244, -16.217787},
		{"e7f8793216f66c70b0d5a3eee59223c2", -618.519592, -253.484756, -16.217787},
		{"6ecdd50234090a102dd1de85b49c5772", -874.519592, -253.484756, -16.217787},
		{"5cfbf34b75bfe6ad753938c7374aa1f0", -618.519592, 2.515244, -16.217787},
		{"bf029cb02a43ad9bfd4c0e6787086241", -840.893921, -703.507202, -0.642905},
		{"9f592cfd72b25036cf60a311350e2027", -1096.893921, -703.507202, -0.642905},
	},
	["The Slave Pens"] = {
		{"b8b4b04bcb6155b17e296c98b126b86b", 464.201355, 944.031372, -123.071793},
		{"f9e6c0de0475015d160a129e08f6bd15", -47.798645, 944.031372, -123.071793},
		{"65e8749c1e32eacc77091b769aae09f7", -47.798645, 1200.031372, -123.071793},
		{"4454cc381e32995bce3e7a8a5981e40d", -47.798645, 688.031372, -123.071793},
		{"302bacf4f47d967980313c65a6a4d3da", -47.798645, 432.031372, -123.071793},
		{"f36cbbcfa7e3cba2e3a16503494c35a1", -47.798645, 176.031372, -123.071793},
		{"a5a0c63aecf360fca48809470e0270ca", 208.201355, 176.031372, -123.071793},
		{"5b353e3a7407dac27a820559d9e33a47", 208.201355, 688.031372, -123.071793},
		{"17d1ed72497a0b5de5871106d947dbfa", 464.201355, 432.031372, -123.071793},
		{"ce5a4601263e7130add0a3492694c0f9", 208.201355, 432.031372, -123.071793},
		{"7b56d58604ca36e3ee8aa30d157e12fd", 208.201355, 1200.031372, -123.071793},
		{"b8dc5563d87117d76c6655a256388843", 208.201355, 944.031372, -123.071793},
		{"9d268cdd050d431d6039faaf6530c3d9", 464.201355, 688.031372, -123.071793},
		{"f02b5fe7ba8194b15c5fb278d916a85d", -303.798645, 944.031372, -123.071793},
		{"8461fe827f4c7fc53d408a72a9113e66", -303.798645, 432.031372, -123.071793},
		{"463a5436d1b1a4cef34cb1e39172a7c4", -303.798645, 176.031372, -123.071793},
		{"6a921612f5b80e719e145a38c85680cd", -303.798645, 688.031372, -123.071793},
		{"d96d8b3de8db1182a19bd6d54a621bd8", 160.364700, -16.365501, -20.014641},
		{"72476667c20c96edea8c170095bdfefb", -54.163116, 178.131813, -16.366081},
		{"d0e31986107e5611e9921ffebed7db29", -310.163116, 178.131813, -16.366081},
		{"ebef13e5c936c743705400bfad80b698", -54.163116, -77.868187, -16.366081},
		{"914c16cbd752d4e2b4d54a57563ed760", -310.163116, -77.868187, -16.366081},
		{"9651b2d9e2e08aec180a11f3071c4cfe", 499.271408, 1251.187012, 16.487837},
		{"4db80e871119d22a537c305ca75be258", 243.271408, 1507.187012, 16.487837},
		{"12423ed74f986ecdc1b801ecd621c378", 243.271408, 1251.187012, 16.487837},
		{"904943b1656b6d28a98cd2816663938f", 127.031219, 1328.282104, 52.496243},
	},
	["The Steamvault"] = {
		{"ea83e4ef56a3ee9d4b0ad324a2ac74ae", -257.133362, -60.384701, -186.795563},
		{"e8672edbf599402b9f52221aee3aa0d2", -1.133362, 451.615299, -186.795563},
		{"36d2812d9d89bb06b48183e98db35057", -1.133362, 707.615299, -186.795563},
		{"52b871dc2ebada942a0159af6524235f", 254.866638, 451.615299, -186.795563},
		{"d52515d61ee40a7a369cc479b45e04a2", -1.133362, 195.615299, -186.795563},
		{"1dd46a422d08501f915f01fdf40fbddb", 254.866638, 707.615299, -186.795563},
		{"e9e290a2ed11f71330ddfd1f56fafd6b", -257.133362, 707.615299, -186.795563},
		{"ef50f14682a7cc73bde0b0e6a262ec6a", -257.133362, 195.615299, -186.795563},
		{"01a23e58859f25a5b79adfd8bf54a939", -1.133362, -60.384701, -186.795563},
		{"e33871ef5d99aae51b1f6a41f17688fa", -257.133362, 451.615299, -186.795563},
		{"f9035c9e3d70b948ffddb8508f1edcce", 369.197723, 132.043793, -135.337692},
		{"941e4f8b6cbfb7fd6c5512a2ba72fd4b", 369.197723, 388.043793, -135.337692},
		{"ad2363e0e97bdb1dfeecfd6ac8dd5320", 625.197723, 132.043793, -135.337692},
		{"9e72b32ecbf0664ce83dfea24e74ac6d", 393.075897, 588.844421, -135.337692},
		{"3145820c655be65b5916f8c1e16c1548", 625.197723, 388.043793, -135.337692},
		{"71dce19acd4ea74b83844efa3687a360", 255.152419, 891.865662, -43.024471},
		{"08eaee3ace468964fa00014e432b7f2f", 255.152419, 1147.865662, -43.024471},
		{"f01281a8efa0de66e1ca10abc53ca539", -0.847581, 891.865662, -43.024471},
		{"25b5dd99863ee8397ce01ffa1db88031", -0.847581, 1147.865662, -43.024471},
		{"91f3d1674be2e8c00f50656da4e098c2", 279.830200, 441.246857, -15.860577},
	},
	["The Stockade"] = {
		{"86e8fc44325184152a162e960f85fa33", -251.059738, -119.216599, -71.357964},
		{"fe7c41ed4d860bd76d9c0ba547886956", -330.067993, -104.649124, -71.357964},
		{"28c4a0dd3711773b29eb9e8d65a36b8b", -278.418274, -172.998383, -71.357964},
		{"1815dd5b6f95c6f963b9a807ec8b31e3", -246.177765, 59.520699, -71.357964},
		{"782246bd935fd0d3991c03a60ab20963", -318.344452, 117.284950, -71.357964},
		{"d2b4133e90410e66415784e2a6883373", -326.185120, 71.391045, -71.357964},
		{"6fbe22493487cf7d416bfaf9405898e9", -240.011810, 99.437943, -71.357956},
		{"ab6cf7d875f7f7322064a55f1ab7d5c0", -338.731934, -145.598145, -71.357956},
		{"be7ef9750468eeb15ea0b266f70c1205", -245.642227, 176.843307, -70.434692},
		{"5412fd3e957575f6ed59962bfbe48d74", -341.654541, -250.699432, -70.434692},
		{"60ecc3bba638a6f9e3a93c43ed0ae84a", -299.158447, -189.157700, -69.768028},
		{"426026727cbd94ad9d2553678188a905", -269.378387, 42.897472, -69.768028},
		{"f274fa50bf212fb70b965ece7607f936", -283.576538, -272.814850, -69.524628},
		{"fc7c41d8360bc96bd7a9add91157f75b", -363.769958, -303.642395, -69.524628},
		{"13bddcd361da2a06c73c107ff60ee6ee", -298.585205, 213.758759, -69.524628},
		{"3dafa4d865f20ca6399be37e890887e5", -208.726761, 234.921310, -69.524628},
		{"e3ebaf6f5027d5b2870bcd42301fb08a", -394.597504, -213.783966, -69.524628},
		{"24a5f2fa9843468e1d73f4760b61b2d8", -187.564240, 154.727875, -69.524628},
		{"4077c4e6767c801b85b9b78901f4b09e", -291.850555, -45.991348, -59.620087},
		{"d4f775fd7f7bf1c5c52065faf9580656", -186.625397, 9.831894, -54.691296},
		{"51e26a54611be6094ff50109fbf768d9", -231.052750, -70.119522, -54.691292},
		{"5e76419a9780a783f888f22d14f9a618", -231.052750, 9.831894, -54.691292},
		{"b7411bf11a78bdb3d930127ff1f921fb", -186.625397, -70.119522, -54.691288},
		{"206ddf3da27334779d3030bb680ea3b1", -191.600647, -14.062093, -53.101360},
		{"cdd5dc09ecb19157dda8b3ebcd2a3be5", -348.692657, -18.828871, -51.333706},
		{"03d4f00485cd0b1f493bd88a9ec89939", -120.023209, -69.706444, -44.762123},
	},
	["The Underbog"] = {
		{"2e00d63cda4859ce1e01c79d6e3b498e", -847.469177, 140.061401, -85.690819},
		{"7016eb0b3bf51dfe3fa8bcebfb804dba", -79.469177, -115.938599, -85.690819},
		{"66ca40c060b703193feb73edef17c9f3", -79.469177, 140.061401, -85.690819},
		{"df736b7e5ece885eea46554aea369cc7", -79.469177, -371.938599, -85.690819},
		{"241aaf46937dc91a94bbc77019e4214f", -335.469177, 652.061401, -85.690819},
		{"cfc3310cb7bdf13dbe63903c8e4cb2ae", -335.469177, 908.061401, -85.690819},
		{"8f51a9c23d613513a8955dc55cda1099", -335.469177, 396.061401, -85.690819},
		{"0c04ff5343055c5d37a2c486c9a4bc15", -79.469177, 396.061401, -85.690819},
		{"58f0720a69c4650466bf1136dd5ebdef", -79.469177, 908.061401, -85.690819},
		{"1ca64bc1195f3fbaeadef0ca7cff49b8", 176.530823, 140.061401, -85.690819},
		{"a64c7de5f6c53432fc6c72997587065d", -79.469177, 652.061401, -85.690819},
		{"30e4abd761b2a0cb2a0306740380f764", 176.530823, -115.938599, -85.690819},
		{"5eb24bd7d67b2a162541c54631d6b574", 176.530823, -371.938599, -85.690819},
		{"183936a3f5750c2fb52952fe6bb3828e", 176.530823, 396.061401, -85.690819},
		{"7ae97e2145fbaa392f91c16cdcd519fd", -335.469177, 140.061401, -85.690819},
		{"01788135dd3385657f8504802dc3c93c", -335.469177, -371.938599, -85.690819},
		{"795c2fc87b2e041b5859b646329e2a2d", -847.469177, 1164.061401, -85.690819},
		{"e887c53d27ce67aab73dde70995d4d6b", -591.469177, -371.938599, -85.690819},
		{"6db1744efd6926fc19b7e732c0021597", -847.469177, 908.061401, -85.690819},
		{"b397d78c6f13a4f346778d1584aee0d2", -847.469177, 396.061401, -85.690819},
		{"13bb749bf0ee437fc20c6c6310cfb18b", -847.469177, 652.061401, -85.690819},
		{"1a80cc5788d78f365c688265d61d80f8", -335.469177, -115.938599, -85.690819},
		{"9e799c29d3485abef31534d7b78a3e26", -591.469177, -115.938599, -85.690819},
		{"2958d326b14657349114889af77bdacb", -591.469177, 396.061401, -85.690819},
		{"690748442281ed935517fd26939bf983", -591.469177, 1164.061401, -85.690819},
		{"1e84a27b917a8b116d7ce9ff45d4396c", -591.469177, 140.061401, -85.690819},
		{"43e0ac688432cbf08c61c57718f77511", -591.469177, 908.061401, -85.690819},
		{"32500717e6e7eb12f6187b257d0e298e", -591.469177, 652.061401, -85.690819},
		{"e7dcc8525074ccf2d67059386bcbe014", 176.530823, 652.061401, -85.690819},
	},
	["Uldaman"] = {
		{"2b178d8a65591c816bd793ca09279748", 631.742188, -310.820435, -112.708160},
		{"81218489cb91ab78980b4036ca3a63cc", -233.676895, -459.635040, -110.019699},
		{"37a63d7360bd7f3e74e4e62147ae1349", 313.785034, -668.288147, -108.988808},
		{"f4b325435169729bbf0e117bf536eade", 233.014893, -602.873718, -108.960083},
		{"c1c577bb370bf3eb8a6f00606493174c", -149.632965, -545.823975, -108.621475},
		{"5f4fea4ed3e17babd78cff47c4f694a0", 213.274704, -496.659607, -105.113762},
		{"3c0e16365821e517221fe4c117275641", -352.192322, -640.332092, -104.532494},
		{"48d89c8f46c70ea9f4a97512e584a8f9", -283.649994, -620.015747, -104.464806},
		{"ace673cd5fdd24e7c64f58d31e6eaa18", 366.556793, -84.530571, -104.015617},
		{"2ec9c708c8dbb0a175228a5dfa1871e6", 75.201828, -781.249756, -103.896599},
		{"2511d5ba5901efcd6278d565031c93ff", 147.824203, -686.629089, -102.734222},
		{"7e4ebcb611565fedf8042822cc2fdb38", 375.533020, -597.547729, -102.380234},
		{"2b4e63fba865268f5fcae273922770cf", 62.359360, -493.700134, -101.938293},
		{"63edfd93cce1886d16ac33a1c8f9e90d", 237.849960, -690.247559, -101.648323},
		{"a5af17bb143892b7505b0abe2a6e646f", 281.447632, -462.127167, -101.241341},
		{"c963fe22b1024618dce10c0d62d0aef5", 48.883423, -567.190125, -100.949921},
		{"8e4d5b7eb931871a61a20676c75d8402", -3.298375, -582.904236, -100.295837},
		{"ec0c4725e9f05f6f4e2db9a3e12e1da8", 403.590240, -297.407593, -100.146362},
		{"fda310911803f6317592bbbc30cb68d7", 302.367523, -203.931641, -100.009689},
		{"418f732a3b9706500a0db5744a0097f3", 141.300705, -596.496094, -99.483551},
		{"6a4ef5b3949427d2795edd1eaa57f0c3", 331.283936, -356.366699, -98.480011},
		{"9bd857310de21193c709b32e9976395e", 507.308441, -200.472977, -97.686455},
		{"537632138b607274ac677b44c488fa44", 197.342178, -735.184509, -97.664970},
		{"320c751f8af2fe2a17aadf4a1f7bd9dc", 590.897705, -275.356567, -97.332870},
		{"ffd961425aa104f1af45e45591278113", -16.721334, -723.718323, -96.556091},
		{"30d5129bed25644f75ddf8b0ee8b0d0a", -60.876759, -854.800232, -96.476830},
		{"53f9b2f159a9be785ba385e5f6cbc0dc", 404.432007, -156.679825, -96.262665},
		{"da5209a393247852afadae74b1bfd691", 507.308441, -356.368683, -95.592216},
		{"9755db4866ffc9d35977e08a04fdf076", 428.735321, -664.914001, -95.250694},
		{"fef8f8ba603cbd29971c944173f490e7", 13.856285, -633.547180, -95.018990},
		{"eb639ab56acca0a1533b205fd6a3b34c", 404.432007, -374.330048, -93.484634},
		{"e8bae133785fd92b2014eba62263f8fc", 515.382141, 45.282951, -91.386688},
		{"5aefe4fdae85161cd812b1989d028c77", -30.429771, -766.165283, -88.438202},
		{"f44c7ff1f92c8c81652ff37bf91d6eed", -159.016907, -796.985046, -87.726799},
		{"b8cd6e8f148cb3decabeff4ce6a3eb41", -124.754494, -680.383179, -87.244156},
		{"398c30542bb75e2fa79352d29de8bcfd", 250.896133, -820.367981, -85.511925},
		{"1ccb250983553b45ed03e9b0dc9b720a", -280.364838, -473.226288, -85.042419},
		{"77af292cd327ecf43f2cf97242b6952b", -368.612579, -545.392761, -85.037361},
		{"f0babd7aef32abb3e45fdb0aefd8a9ce", -170.386902, -932.667419, -84.478302},
		{"26a5f6446d395f8c6765438c0e7f89ad", 412.234650, -747.911316, -81.672325},
		{"ce9c5f0bb8544b4e2d147d04e5066023", -64.523674, -602.209167, -81.388916},
		{"54724773cac5f24dda245a72edf05c92", 369.811646, -822.870117, -81.315819},
		{"d3c5a87bd701774202bd16ea48c79a41", -202.202301, -837.672241, -80.749802},
		{"a593c55cfd3249e8423b97feb6de9352", 457.093597, -767.183899, -79.559334},
		{"abbd598e39cd34084c5aa8fc801b4046", 498.729523, -803.441895, -75.223900},
		{"84c4e3738ec088b29a4fc3b93369e601", -120.306847, -533.935120, -72.577919},
		{"08029e21254d020cde062bd1e0e9118f", 358.199738, 14.556746, -72.512154},
		{"870a238a901a32866e51e078f57f65d7", -333.300201, -631.580933, -57.388382},
		{"a6822fdf1da1bb579822b075bdd34339", -149.653946, -533.172302, -53.231693},
		{"05da19b448fcb24b77165efbe89406c3", -283.670929, -616.515198, -53.231689},
	},
	["Upper Blackrock Spire"] = {
		{"fc9ff71f21b38409e256fcc8eb40d342", 189.011688, 4.158981, -193.590271},
		{"faa9d96f76ce998a7c268924bfdb03e2", -66.988312, -251.841019, -193.590271},
		{"c034d5fa3a5506abf11ef0402c363a4a", -322.988312, -251.841019, -193.590271},
		{"fb0406e2448a73266ededa381c1bb428", -322.988312, 4.158981, -193.590271},
		{"af81996ba669f132479dc25ea7638ba8", -66.988312, 4.158981, -193.590271},
		{"03f1714e0f7d021a20b03089be944b3a", -333.601196, 146.224060, -193.202881},
		{"87a842e2c8f473401d74c38a14dae1ae", 178.398804, 146.224060, -193.202881},
		{"e3f75bd56d7e17799a2077cf121ea85a", -333.601196, 402.224060, -193.202881},
		{"2e8b82e308783f92b28061f3776561ee", -77.601196, 146.224060, -193.202881},
		{"63adb9969c34ef9e6ff8892f6d03ae91", -77.601196, 402.224060, -193.202881},
		{"82b9acdceb856293b1c242daaafd9718", -236.307617, 630.086548, -74.449341},
		{"fae7417f2232152259304b3d7a267782", 19.692383, 630.086548, -74.449341},
		{"e0f4e14027611497e6dc6ebc2748880a", -236.307617, 886.086548, -74.449341},
		{"a685c3de2b9c0c272151bf2208a99094", 19.692383, 886.086548, -74.449341},
		{"c7a1d4f5865145ee2aa7fe29cbb66f08", 275.692383, 630.086548, -74.449341},
		{"d09b19ee6ac2182aacbd4b8801932a0f", 195.375397, 953.309937, -39.802979},
		{"95c1de6a7022b77fd45bcadb990505bf", -14.196160, 935.895935, -39.062637},
		{"bf56e9502b4cd2741ed4f1f956385d3a", -203.969040, 983.345703, -38.507187},
		{"bca54ba0291cd0a96f3a57af56412c2a", 52.030960, 983.345703, -38.507187},
		{"02bfe50e633ac83a02bbe1a900664d49", 13.467258, 885.935303, -38.006378},
		{"88260e537a5e67c56a70ccab8ab46660", -11.060133, 1128.645020, -37.777786},
		{"5ac57926cd3fb936a62554753ee61320", 106.667763, 886.412537, -37.344105},
		{"adcdd0608efe8e53b7fc025ea0965c3e", 60.806705, 886.016418, -37.344097},
		{"0ab1088f60dbe0a80bb339f335b99417", 251.128098, 872.921204, 16.565821},
		{"c6bb29547d854ce6f5c15952b1edf0f1", -109.548271, 549.381775, 19.132927},
		{"d2943cb4470da1d0bab32624781225f7", 16.142115, 887.185913, 31.892982},
		{"a7ee1eeb19e078132c5e7171505d3c3e", 122.720810, 950.400635, 32.449440},
		{"61bc03e21a0cb668c325b6dc32e3effd", -96.214142, 573.227234, 43.523010},
		{"faf7ef29c03cdc2ff835cd1e7a1f5226", 168.917465, 933.907471, 48.195702},
		{"58d0764e19e4745fe23cc034d6c5d061", 60.253368, 886.382812, 58.380165},
		{"b710d126aed7e9220522aee021870dbd", 17.988508, 586.214417, 61.041565},
		{"f916329e23e5ab27a1e6e24d72fe3da3", 41.675167, 720.753357, 63.021755},
		{"a733ae8fed153f69b34e06ed59206e1f", -114.428955, 497.524109, 78.916817},
		{"b50f88c5c7e6488cd137259dadf970b3", -55.896702, 512.709229, 84.348595},
		{"789f61c5e0a3560ede3cbf05752c3e6f", -51.506157, 473.146606, 84.492737},
		{"fc0cd7fa9cf8ee73c8e006a1aee819dd", -167.122421, 407.706085, 88.237007},
		{"93a2d9405daf65feb940689e02d1fd5f", -55.858444, 679.818970, 96.340248},
		{"e9e46f8394c0c9ba6dc25108b0d1e43d", -88.962494, 683.413025, 97.249809},
		{"6e4e7a90bf2feb85dd285f9f55ababa1", -174.414185, 445.802917, 99.203812},
		{"931c6f35b811dd366e451566c988d744", -127.894966, 603.138550, 107.439415},
		{"8fc1f216ea09874cca845dcdbd93595d", -223.470215, 602.564819, 107.439415},
		{"f490cfe218f375a104aa2f6d4caf6021", -223.470215, 639.396790, 107.728210},
		{"317846b047e0aa4d3f5f4c12257a87ea", -127.894966, 639.402771, 107.770958},
		{"7d8bdda718265b5a6057430ca0935d4b", -218.112396, 508.502228, 107.785072},
		{"d9e6bf58bcb72b21210905eebdf4991a", 196.319733, 623.113586, 112.927155},
		{"83fdd7d1c619e965a3799d6d5046137f", 268.621338, 727.770081, 115.858017},
		{"5b7d465eb80cb0b2ed08b26702975191", -201.711548, 680.926147, 120.478485},
		{"063e28d7309a76ea3f390157b1df6247", 353.596710, 586.582153, 127.525848},
		{"ab00390b24b03209dab5b8b31be31730", 316.495422, 626.621216, 128.477951},
		{"ac9fc7066c6195cceb46a906fab3e266", 316.495422, 882.621216, 128.477951},
		{"944fcaad34951d1e8876f6d903f13994", 270.448822, 676.778381, 128.762955},
		{"d8ed3cc109faaa77789a13dab02c7884", -247.035324, 623.550354, 130.867859},
		{"57cd6e8347c115d1e56f54efc8de383b", 83.774292, 566.655884, 133.086197},
		{"9be79e522cdccf834eba2872c4e66c7b", -221.913940, 496.504639, 141.622467},
		{"457438d5d0fdecdfc0dc5b6a00832174", -477.913940, 496.504639, 141.622467},
		{"e2b2a5730be2389b6b1c50b92703929d", 94.781311, 694.587463, 141.648209},
		{"d3542f41e19ae3d94f3d072192547138", -467.054413, 531.188660, 153.721954},
		{"de55dee81a111b56621c667e9593aee9", -9.978590, 877.046936, 155.074051},
		{"74fc722af57ebcd6b16fa0239a2cbf95", -430.649780, 502.827393, 164.122421},
		{"f4de92bdc4559830c5e5c1e77daebf4c", -461.303375, 507.604340, 164.122421},
		{"da257ce85eb189559ca4ceb106bf0a7a", 360.124329, 889.059509, 174.724899},
		{"2cb8904c389ad5341392e20fe6fe516e", -225.060471, 463.272919, 177.218094},
		{"1f85384dc1ea2173e58f2229984f108b", -88.041603, 610.565002, 181.482758},
		{"0c1c7462d764ce66a19fcf8d8e87bd31", -352.912201, 456.619598, 182.321228},
		{"6c2cf3ba1dc40348795acdad3e8f0ced", -261.533630, 504.899872, 212.815552},
		{"1c968761f5f6bccdf515b243532b788c", -261.406281, 610.209961, 212.815552},
		{"cdb7294ded1226330500519b6f5d0d71", -345.555573, 478.022430, 213.312393},
		{"c5a4f93de7eadfe3dae674ec2732f3ca", -298.453613, 1000.630432, 213.639145},
		{"2b4676e59c7735d2c53fe74cbc7e677c", -42.453613, 1000.630432, 213.639145},
		{"898f40c852c56ef5f76ceae2644ccf95", -217.502930, 809.432312, 219.730469},
		{"b83f1e5aaa7915a198f6bc9430dda4b5", -450.668884, 719.268738, 220.888992},
		{"8b54e7997276fb6074340977060bb7e3", -84.896538, 711.662659, 221.199661},
		{"62ef876e99af5eefa65eeea3e22a7d5e", -154.640305, 938.558960, 221.722961},
		{"034850edef9d80f52e7d0c07c21b9a52", -196.435028, 871.859009, 221.722961},
		{"335a00a9b808aba03a28d63043c5bf60", -196.422867, 763.237793, 221.722961},
		{"987feb550a3cc0554da1dfaff511a83b", -108.445801, 878.870117, 221.778580},
		{"78a5975bee9819163bf0b906060330fd", -88.806473, 603.492554, 221.801682},
		{"f5aa4363573667defa92e74beea0204f", -88.863556, 494.914093, 221.830917},
		{"0d3345ea38fe71f39787d96fdea1b1c2", -439.521088, 933.426758, 232.024384},
		{"3d31a44b43fca5984716f18ddafb8700", -389.504913, 720.120239, 232.440979},
		{"dd47e0b2d93a39337605c796dc982ca2", -154.645966, 719.901550, 232.440979},
		{"462f35bce8181855e03885d177e9d079", -217.066742, 918.053650, 232.441025},
		{"8d14256101481c1408136505978d2da9", -217.072601, 702.381104, 233.429367},
		{"66b6b851786c4b5b4c26835c97b339df", -251.300995, 721.467224, 233.552734},
		{"dde85729b05685793aa0765f12e6c942", -251.295135, 938.644775, 233.629257},
		{"bc3b295f634eb1d41934f7f9cbe4e8f5", -668.795593, 835.832458, 248.717880},
	},
	["Wailing Caverns"] = {
		{"59dc2defac3d195f688735372684903b", 629.142853, 69.717331, -389.827576},
		{"fccee2fe2a0bf03aaf4e6272b245bcb4", 562.668266, 55.047882, -389.827576},
		{"da2f307028e5e8b5d353e9e7f755d293", 562.668266, -200.952118, -389.827576},
		{"4e14a9e0f179e66ead79bad2d49588ec", 306.668266, 55.047882, -389.827576},
		{"26991cd7841897d92014965f5fd9135f", 306.668266, -200.952118, -389.827576},
		{"dd1210b173ed8b0cb9bc82f8793ca2aa", 373.142853, -671.337341, -389.827576},
		{"23432274d400da5c07579abd17daaa42", 629.142853, -186.282669, -389.827576},
		{"fcc8f3f3ad9ac99aeba2f58a3b102a12", 629.142853, 325.717331, -389.827576},
		{"54a31a5bb447f5822c780d2467ac856a", 373.142853, 325.717331, -389.827576},
		{"c754169fcb68f495b056cb22748739b4", 373.142853, 69.717331, -389.827576},
		{"428a641f821bc7cb6c8aac2a14142a40", 50.668266, 55.047882, -389.827576},
		{"0e455ed2e6d048cfc371027d21feb183", 373.142853, -415.337341, -389.827576},
		{"072048141d7700745f71820d3addd009", 50.668266, -200.952118, -389.827576},
		{"79486a44579b75c626032f485ac29a31", 295.171082, -418.577942, -389.827576},
		{"52c6279dca0fffe7d8aaac833e29b099", 295.171082, -674.577942, -389.827576},
		{"621e7467c67b507054584ee9911aad5d", 373.142853, -186.282669, -389.827576},
		{"89514ebfddac408da70ad43278f11435", 629.142853, -671.337341, -389.827576},
		{"55e93fe98ae4d0ed0570bfc6e43253e6", 629.142853, -415.337341, -389.827576},
		{"361eca800f7eb88acc3b97c825a5facf", -102.895569, -61.847534, -238.376602},
		{"e2a2c250ac9cc5069c728f1cd3c848f2", -102.895569, -317.847534, -238.376602},
		{"aaa663859d07c68ac58e8136967faed4", 153.104431, -317.847534, -238.376602},
		{"43ac71bfe8fbcecdbbc6cac42a29c6c2", -142.786057, -662.781433, -218.098709},
		{"e5c37c1ba6d29a11fbb08576f7305e2d", -375.007843, -354.311951, -218.098709},
		{"3deaa5a10a94029a1f6427d8d8df35b0", -375.007843, -610.311951, -218.098709},
		{"23dda06d6ab6e5f4a2a2648165d26a0f", 113.213943, -662.781433, -218.098709},
		{"4c0516a385070a434092cbb77b9797d5", -161.008026, -852.722412, -216.034882},
		{"8aafe3de02b25bbe5abf712a8d697fc5", 94.991974, -852.722412, -216.034882},
		{"835ba3a000957578d8ae76c2bbd3ce13", -161.008026, -1108.722412, -216.034882},
		{"4dbc57bc257b10c3b27b15bfe6d377d3", 94.991974, -1108.722412, -216.034882},
		{"3ca7fb93b05b4aa0c3bf50c6dddfb118", 111.495514, -738.127441, -213.930359},
		{"18e002d44ae790c78c498de9eea9b20d", 193.558044, -170.444275, -213.418411},
		{"24381f64e5f050912ab8c35c61f18353", 124.717239, -474.089935, -212.762527},
		{"7de11e29e6325904b2bf0bddaf814232", -131.282761, -474.089935, -212.762527},
		{"c13243bbbda89d2dff25266ebb8f5e87", 117.983734, -522.263611, -191.791153},
		{"387dc5f2ba358b1477181ef50aaa85a2", 195.497620, -313.519653, -180.301834},
		{"25dff18f108e6ce666aabb24c880e578", 148.852211, 254.403000, -175.747925},
		{"ab36780e6bbe1fb7aab6d1584568ebab", -107.147789, 254.403000, -175.747925},
		{"38287a85c8835f6843a3c3acf6214cfe", -107.147789, 510.403000, -175.747925},
		{"e2039b7d3f9ebaca29483f855b666d8d", -167.110931, 205.266129, -161.078659},
		{"1c78503c02d32dd7116e654448d66106", 88.889069, 205.266129, -161.078659},
		{"2d5ab9f8c467bc7114159dda03d715e0", 347.533630, 356.796501, -159.917618},
		{"620e325ac857ebc832bb57faa6209bc1", 91.533630, 100.796501, -159.917618},
		{"9cb55ea823394d611efcee49c59949a3", 91.533630, 356.796501, -159.917618},
		{"d0b1b4653e591346d3fae501396ff3a4", 347.533630, 100.796501, -159.917618},
		{"28615f2750b5452c6f02f687706a984d", 280.837677, 341.410461, -146.944550},
		{"1bb26b72bf715a065a1393f5a3349ef8", 172.327820, 472.769653, -144.776993},
		{"c8ccc04829163b3b8835b1ac955004f2", 172.327820, 728.769653, -144.776993},
		{"0ebfd059dfc46ffd5e0d45f5bf39af65", 428.327820, 472.769653, -144.776993},
		{"fd21aae822e23b1dd4f9d5d05118063a", 364.165405, 456.045929, -144.164612},
		{"210f69504d387e1e8636439d2274915d", -24.107286, 29.210423, -143.167206},
		{"c71c3e3755bf8572d4aefe6042b006de", 214.635925, 410.471710, -141.891159},
		{"294016725bbcda7dfc4010ef190e63a8", 19.047853, 353.535950, -139.094025},
		{"9e236c69aa39aeff93c64486048a27e9", 443.118408, 277.707733, -130.852417},
		{"aa6d56ec7521f4b6ee680204146c7d3b", 443.118408, 533.707733, -130.852417},
	},
	["Zul'Aman"] = {
		{"be37c84de9e61ce25194fea9139baa57", 7168.000000, -7936.000000},
		{"5c0684367dee711e7f2ffc5b23359ea5", 7168.000000, -8192.000000},
		{"92f99ed013017e7dc457b045b975a5be", 7424.000000, -7936.000000},
		{"ec52bd41fd5bc120f576555d3e6dcac2", 7424.000000, -8192.000000},
		{"f73f417f86713eea85f5b181899da736", 7680.000000, -7936.000000},
		{"74532cc3ebe1a30476c5554e10a395c3", 7680.000000, -8192.000000},
	},
	["Old Hillsbrad Foothills"] = {
		{"6092ab342a1be0b93bfc508f03194415", 6912.000000, -6400.000000, 0},
		{"52320bb963829eb8a861bb227f77a3bf", 6912.000000, -6656.000000, 0},
		{"3c9fc962c49ec82111224d86c9174c2f", 6912.000000, -6912.000000, 0},
		{"a6aa8cf0f5ac5f4671a5fab3a6d66d13", 6912.000000, -7168.000000, 0},
		{"113fb068548c02ee340bea7a30054b89", 6912.000000, -7424.000000, 0},
		{"1092dfa284ce5ba184b6ab0932f8fd7a", 6912.000000, -7680.000000, 0},
		{"59dc5c42a8b36b0923a89e7e8de41be1", 7168.000000, -6400.000000, 0},
		{"2cc63d475728d25edf94a06073c8bf99", 7168.000000, -6656.000000, 0},
		{"4a92fa8c427dd41d7ea7c0b7f14ac775", 7168.000000, -6912.000000, 0},
		{"d02edb4c853eeb2a5002c23be8d87687", 7168.000000, -7168.000000, 0},
		{"81a113696e15c3c9b1c8a7acc4a76836", 7168.000000, -7424.000000, 0},
		{"135b7a2c998c7fed49722d5b219eab8b", 7168.000000, -7680.000000, 0},
		{"900726f631a7f3bb2043fb2eff263f1a", 7424.000000, -6400.000000, 0},
		{"780c8848314f84e96e4d452f13eda1a6", 7424.000000, -6656.000000, 0},
		{"5150ce0996a09dc49b74f3cec8c9c9b3", 7424.000000, -6912.000000, 0},
		{"5d23ab189cc80d90667de61ae16c8364", 7424.000000, -7168.000000, 0},
		{"fe37f3035d6ce489f67b9ce4565bde61", 7424.000000, -7424.000000, 0},
		{"7534a65d9e4bd1996a59460408eb3a0d", 7424.000000, -7680.000000, 0},
		{"06df975df04b3d937e0a4951d30752e9", 7680.000000, -6400.000000, 0},
		{"77ccc2dc234dc60e0062c3dc1cc8d185", 7680.000000, -6656.000000, 0},
		{"a312ca0bdeb9b96efc64b48a484a2954", 7680.000000, -6912.000000, 0},
		{"0e8282ef3205028c699b80ed05ef97ee", 7680.000000, -7168.000000, 0},
		{"d05d38f1c0304e33cb02b3e16efc5131", 7680.000000, -7424.000000, 0},
		{"46d1f4daa2a719c3e2c230037e25d991", 7680.000000, -7680.000000, 0},
		{"83318dae12f1f67ba0819b1cedce623c", 7936.000000, -6400.000000, 0},
		{"f742d8d10442442a913aaaba8de35f75", 7936.000000, -6656.000000, 0},
		{"9abed58920ee008d4579f2109147f157", 7936.000000, -6912.000000, 0},
		{"55c883ed58416d275a0503386271f117", 7936.000000, -7168.000000, 0},
		{"9e0266c911556c326ee53d8faabed651", 7936.000000, -7424.000000, 0},
		{"3cdc81f0fc2c2dbc864243a45e3175f4", 7936.000000, -7680.000000, 0},
		{"77698d791e0e5bc21532d569b644ad03", 8192.000000, -6400.000000, 0},
		{"b471d27186dac8eeac337a3594c67ee0", 8192.000000, -6656.000000, 0},
		{"87d0c35c1333ce0ceba244b3de897fac", 8192.000000, -6912.000000, 0},
		{"deb4fedd139df1d60ca41ae449f25aa8", 8192.000000, -7168.000000, 0},
		{"340d32aa6bad21275a8fa04706072caa", 8192.000000, -7424.000000, 0},
		{"4e271a5b63a672a724590391cd4f7f51", 8192.000000, -7680.000000, 0},
	},
	["The Battle for Mount Hyjal"] = {
		{"bd49d4ad48a3cc613ac95c7769d3adf9", 8704.000000, -5120.000000, 0},
		{"f92bab3a68dc8fc13a445a639fcee116", 8704.000000, -5376.000000, 0},
		{"47bb035996a526314ecfd5cfbe2b126c", 8704.000000, -5632.000000, 0},
		{"f4c569b32fd893b6f123e138594c0e79", 8704.000000, -5888.000000, 0},
		{"0ce288f20f98a2ba66c16753e8072201", 8704.000000, -6144.000000, 0},
		{"f6947efd74dee4fba56bf3230564d936", 8960.000000, -5120.000000, 0},
		{"507ffba9364fc4034a811a5e28bf8de3", 8960.000000, -5376.000000, 0},
		{"f87459cd7978fb9da6c5634dbab1e6fa", 8960.000000, -5632.000000, 0},
		{"2dc51ca2da35e5d288c84234b22fe432", 8960.000000, -5888.000000, 0},
		{"483b49806337fd4f1641bd3aa459ce1e", 8960.000000, -6144.000000, 0},
		{"30e9df92e0ee8227998167d5331d5c44", 9216.000000, -5120.000000, 0},
		{"2e8f4475a99c8cf042c8ffa1f52f8547", 9216.000000, -5376.000000, 0},
		{"85a00161dc85a33e0344a672b0b16465", 9216.000000, -5632.000000, 0},
		{"239614f5a29ce747ef63938fd92f10d0", 9216.000000, -5888.000000, 0},
		{"15407c95b83c74d3edf738b8f3106048", 9216.000000, -6144.000000, 0},
		{"ca604eee77d1a2e4aecca78c760745d2", 9472.000000, -5120.000000, 0},
		{"1ad19013b97c56bc0cdcc8d9879c64ab", 9472.000000, -5376.000000, 0},
		{"7d82034b5a375c1b6a9f859eb2a6bd1a", 9472.000000, -5632.000000, 0},
		{"4c9399c192a73d50ecbe5de6018ba181", 9472.000000, -5888.000000, 0},
		{"e15a3f471fbfeb180c90457b12f722c8", 9472.000000, -6144.000000, 0},
		{"68597d04c51e7a2e3682147a436137e0", 9728.000000, -5120.000000, 0},
		{"7f3ba2f2e9799ceae25bc1d911d01af2", 9728.000000, -5376.000000, 0},
		{"026afd0269a03eaf6fe546dbd5870f24", 9728.000000, -5632.000000, 0},
		{"132b561d3e5bd5229d662000c8ee2537", 9728.000000, -5888.000000, 0},
		{"00d94beb455627e68e525d7dee5d035c", 9728.000000, -6144.000000, 0},
		{"b08c90f4abe183ee4a57a64d534053a1", 9984.000000, -5120.000000, 0},
		{"dc3207823081cfe6bd62281356b043b8", 9984.000000, -5376.000000, 0},
		{"6d3aa16c17587ce952cdbc5f8bef56ea", 9984.000000, -5632.000000, 0},
		{"c8d9fd4931fe0f760f59cd1278b3b3df", 9984.000000, -5888.000000, 0},
		{"ff44968a16d23f5e2c561ce995d70264", 9984.000000, -6144.000000, 0},
	},
	["The Black Morass"] = {
		{"4136cea20d8bcde1fa56559bd8691417", 4352.000000, -8704.000000, 0},
		{"55a9d669a4e12a75226d265e70103ff8", 4352.000000, -8960.000000, 0},
		{"3466a3101b2154b1a108e36984780a52", 4352.000000, -9216.000000, 0},
		{"c84d58df7c341e9e924d5c4d9312da97", 4608.000000, -8704.000000, 0},
		{"2ace9c07321bddcc30a847b358efd123", 4608.000000, -8960.000000, 0},
		{"b4cbd1dfee9fcfe09d11551d0f2bee0c", 4608.000000, -9216.000000, 0},
		{"97e37fd73ef5520307c79706880128ab", 4864.000000, -8704.000000, 0},
		{"0ce258db21cdd80a178147051174541d", 4864.000000, -8960.000000, 0},
		{"cb9368075873d65060100d68640c22fe", 4864.000000, -9216.000000, 0},
	},
}
